#
# spec file for package perf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# A bug in dwz leaves temporary trace-*.debug.#dwz#.* on 64 bits in place
# It was long ago fixed in OpenSUSE but somehow is now occuring on SLE15-SP6
# https://sourceware.org/bugzilla/show_bug.cgi?id=26645
# https://bugzilla.suse.com/show_bug.cgi?id=1180984

# perf does not link with LTO
%define _lto_cflags %{nil}

%define _find_debuginfo_dwz_opts %{nil}

Name:           perf
VCS: https://src.suse.de/SLFO-pool/perf#cb2ca3f2805fa8185f656234bbbe968f07bff87e80ab8163c73ffdf66cb63cdf
Version:        6.12.0.git3456.f82da74913
Release:        160000.2.4
Summary:        Performance Monitoring Tools for Linux
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
Url:            https://perf.wiki.kernel.org/
Source0:	%{name}-%{version}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  audit-devel
BuildRequires:  binutils-devel
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  libdw-devel
BuildRequires:  libelf-devel
BuildRequires:  libtraceevent-devel
BuildRequires:  llvm
BuildRequires:  OpenCSD-devel
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  newt-devel
BuildRequires:  openssl-devel
BuildRequires:  xmlto
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
BuildRequires:  rubygem(asciidoctor)

%ifarch aarch64 ia64 x86_64 ppc64 ppc64le ppc %sparc
BuildRequires:  libnuma-devel
%endif

%ifarch s390x s390
%define         _perf_unwind NO_LIBUNWIND=1
%else
%define         _perf_unwind %{nil}
BuildRequires:  libunwind-devel
%endif

%{perl_requires}
%{?libperl_requires}

# upstream patches
# non upstream patches

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package provides a userspace tool 'perf', which monitors performance for
either unmodified binaries or the entire system. It requires a Linux kernel
which includes the Performance Counters for Linux (PCL) subsystem (>= 2.6.31).
This subsystem utilizes the Performance Monitoring Unit (PMU) / hardware
counters of the underlying cpu architecture (if supported).

%package devel
Summary:        Development headers for perf
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}

%description devel
Development headers for perf. 

%package gtk
Summary:        Gtk browser for perf-report
Group:          Development/Tools/Other
Requires:       %{name} = %{version}

%description gtk
A GTK2 frontend for perf-report. (Use `perf report --gtk`.)

%package bash-completion
Summary:        Bash completion for perf
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
bash command line completion support for perf.

%prep
%setup -q
chmod +x tools/perf/util/generate-cmdlist.sh

# don't error out on deprecated definitions in gtk2.h
sed -i 's@ignored "-Wstrict-prototypes"@&\n#pragma GCC diagnostic ignored "-Wdeprecated-declarations"@' tools/build/feature/test-gtk2.c

# skip info-from-txt generation (it's the same as man anyway)
sed -i.old 's@\(all: .*\)info@\1@' tools/perf/Documentation/Makefile

# BPF_SKEL=1 requires clang, enable when we resolve CLANG in SLE issue
%define perf_options LIBTRACEEVENT_DYNAMIC=1 CORESIGHT=1 GTK2=1 PYTHON=python3 ASCIIDOC8=1 USE_ASCIIDOCTOR=1 EXTRA_CFLAGS="%{optflags}" prefix=/usr libdir=%{_libdir} perfexecdir=lib/%{name}-core tipdir=share/doc/packages/perf %{_perf_unwind}

%build
cd tools/perf
export WERROR=0
# PASS rpm optflags as EXTRA_FLAGS,  passing as CFLAGS overrides and breaks build

# Specifying "all doc" as one invocation when using -f Makefile.perf doesn't 
# work and all is deferred to later %install; so seperate into two 

make %{?_smp_mflags} -f Makefile.perf \
	V=0 VF=0 \
	%{perf_options} \
	all	

make %{?_smp_mflags} -f Makefile.perf \
	V=0 VF=0 \
	%{perf_options} \
	doc

%install
cd tools/perf
export WERROR=0

make -f Makefile.perf \
	%{perf_options} \
	DESTDIR=%{buildroot} \
	install install-doc

mkdir -p %{buildroot}%{_datadir}/bash-completion/completions/
mv %{buildroot}%{_sysconfdir}/bash_completion.d/perf %{buildroot}%{_datadir}/bash-completion/completions/

%fdupes %{buildroot}/%{_prefix}/lib/%{name}-core

%files
%defattr(-, root, root)
%attr(0644, root, root) %doc COPYING CREDITS README tools/perf/design.txt
%attr(0644, root, root) %doc %{_docdir}/perf/tips.txt
%{_bindir}/perf
%{_bindir}/trace
%{_prefix}/lib/%{name}-core
%{_datadir}/%{name}-core
%{_mandir}/man1/perf*

%files devel
%dir %{_includedir}/perf/
%attr(0644, root, root) %{_includedir}/perf/*.h

%files gtk
%{_libdir}/libperf-gtk.so

%files bash-completion
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/perf

%changelog
* Sat Mar  1 2025 tonyj@suse.com
- Drop "Requires: libebl" on ppc64.  This requirement no longer exists,
  neither does (in SLE-16) the package.
* Sat Feb  8 2025 tonyj@suse.de
- perf annotate: Use an array for the disassembler preference
  (git-fixes).
  [kernel-source commit e8b27c535a]
* Sat Feb  8 2025 tonyj@suse.de
- perf test: Fix parallel/sequential option documentation
  (git-fixes).
  [kernel-source commit aa58438efe]
* Sat Feb  8 2025 tonyj@suse.de
- perf test stat: Avoid hybrid assumption when virtualized
  (git-fixes).
  [kernel-source commit e5915c4b0e]
* Sat Feb  8 2025 tonyj@suse.de
- perf symbol: Prefer non-label symbols with same address
  (git-fixes).
  [kernel-source commit 38e475dd1d]
* Sat Feb  8 2025 tonyj@suse.de
- perf stat: Fix trailing comma when there is no metric unit
  (git-fixes).
  [kernel-source commit 5c91748718]
* Sat Feb  8 2025 tonyj@suse.de
- tools features: Don't check for libunwind devel files by default
  (git-fixes).
  [kernel-source commit 3090a5cc4b]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix uninitialized variable
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d7ab8b5c94]
* Fri Feb  7 2025 tonyj@suse.de
- libperf: evlist: Fix --cpu argument on hybrid platform
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1b8658a8c0]
* Fri Feb  7 2025 tonyj@suse.de
- perf test expr: Fix system_tsc_freq for only x86
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d32367ee84]
* Fri Feb  7 2025 tonyj@suse.de
- perf test hwmon_pmu: Fix event file location
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d637bca6fa]
* Fri Feb  7 2025 tonyj@suse.de
- perf hwmon_pmu: Use openat rather than dup to refresh directory
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 18158f747e]
* Fri Feb  7 2025 tonyj@suse.de
- perf ftrace: Fix undefined behavior in cmp_profile_data()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2e32d15293]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix precise_ip fallback logic
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6bc6a14464]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix build error on generated/fs_at_flags_array.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b2725eb4b4]
* Fri Feb  7 2025 tonyj@suse.de
- perf machine: Initialize machine->env to address a segfault
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 51c95e1c11]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Don't signal all processes on system when
  interrupting tests (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2737fe965f]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix build-id event recording
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7d25710a5f]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Fix hwmon parsing with PMU name test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fc3f4beb25]
* Fri Feb  7 2025 tonyj@suse.de
- perf hwmon_pmu: Ensure hwmon key union is zeroed before use
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit af52369238]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests hwmon_pmu: Remove double evlist__delete()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 46aedf64dc]
* Fri Feb  7 2025 tonyj@suse.de
- perf/test: fix perf ftrace test on s390
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 573e663ca8]
* Fri Feb  7 2025 tonyj@suse.de
- perf bpf-filter: Return -ENOMEM directly when pfi allocation
  fails (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2c108a69cf]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Correct hwmon test PMU detection
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9beb706745]
* Fri Feb  7 2025 tonyj@suse.de
- perf: Remove unused del_perf_probe_events()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b639100c54]
* Fri Feb  7 2025 tonyj@suse.de
- perf pmu: Move pmu_metrics_table__find and remove ARM override
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 4ec85e3f4f]
* Fri Feb  7 2025 tonyj@suse.de
- perf jevents: Add map_for_cpu()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 099b884dcb]
* Fri Feb  7 2025 tonyj@suse.de
- perf header: Pass a perf_cpu rather than a PMU to get_cpuid_str
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5a3572145d]
* Fri Feb  7 2025 tonyj@suse.de
- perf header: Avoid transitive PMU includes
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1b214c9769]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm64 header: Use cpu argument in get_cpuid
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ed2e5644ab]
* Fri Feb  7 2025 tonyj@suse.de
- perf header: Refactor get_cpuid to take a CPU for ARM
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 07665789de]
* Fri Feb  7 2025 tonyj@suse.de
- perf header: Move is_cpu_online to numa bench
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2c51a6f561]
* Fri Feb  7 2025 tonyj@suse.de
- perf jevents: fix breakage when do perf stat on system metric
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a450c4cf7d]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add missing __exit calls in tool/hwmon tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 68186e71c2]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Make leader sampling test work without branch event
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 507e65d31f]
* Fri Feb  7 2025 tonyj@suse.de
- perf util: Remove kernel version deadcode
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ad4cbe68db]
* Fri Feb  7 2025 tonyj@suse.de
- perf test shell trace_exit_race: Use --no-comm to avoid cases
  where COMM isn't resolved (perf-sle16-v6.13-userspace-update).
  [kernel-source commit cffb33a17f]
* Fri Feb  7 2025 tonyj@suse.de
- perf test shell trace_exit_race: Show what went wrong in
  verbose mode (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 0ffe38ddc1]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Add test for trace output loss
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 831bf87809]
* Fri Feb  7 2025 tonyj@suse.de
- perf trace: Avoid garbage when not printing a syscall's
  arguments (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fe4fe540de]
* Fri Feb  7 2025 tonyj@suse.de
- perf trace: Do not lose last events in a race
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 775f368b81]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Introduce quotation marks support
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit aa966fac9b]
* Fri Feb  7 2025 tonyj@suse.de
- perf string: Add strpbrk_esq() and strdup_esq() for escape
  and quote (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3f0baf273f]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Accept FUNC@* to specify function name explicitly
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e965e770da]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix to ignore escaped characters in --lines option
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b723d01497]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix error message for failing to find line range
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 91d1468441]
* Fri Feb  7 2025 tonyj@suse.de
- perf trace: Fix tracing itself, creating feedback loops
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ee591ec694]
* Fri Feb  7 2025 tonyj@suse.de
- perf timechart: Remove redundant variable assignment
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 832e1eca4c]
* Fri Feb  7 2025 tonyj@suse.de
- perf list: Fix topic and pmu_name argument order
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ab4d173519]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix typos Muliplier -> Multiplier
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3b9cbd27a1]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Allow configuring what disassemblers to use
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit af91964fd0]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Define stubs for the LLVM and capstone
  disassemblers (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 139cd2582a]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Introduce symbol__disassemble_objdump()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a5e6f2fd24]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Remove PERF_HAVE_DWARF_REGS
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1f2b7b6630]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Remove get_arch_regstr code
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 848d4b5719]
* Fri Feb  7 2025 tonyj@suse.de
- perf xtensa: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 95c22e8f34]
* Fri Feb  7 2025 tonyj@suse.de
- perf sparc: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c66dd15b4e]
* Fri Feb  7 2025 tonyj@suse.de
- perf sh: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit cf16856306]
* Fri Feb  7 2025 tonyj@suse.de
- perf s390: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a223ec966c]
* Fri Feb  7 2025 tonyj@suse.de
- perf riscv: Remove dwarf-regs.c and add dwarf-regs-table.h
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2c823027cb]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Move powerpc dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 52dc2be6d3]
* Fri Feb  7 2025 tonyj@suse.de
- perf mips: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f44c87d3f1]
* Fri Feb  7 2025 tonyj@suse.de
- perf loongarch: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f07a5dd4ec]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Move csky dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2f592b32bf]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ec15c7dbc4]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm64: Remove dwarf-regs.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c393dcf0eb]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Move x86 dwarf-regs out of arch
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 22d51f9678]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Pass ELF flags to get_dwarf_regstr
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 266d4ad38b]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Pass accurate disassembly machine to
  get_dwarf_regnum (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1ca186f7e4]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Add e_machine/e_flags to struct arch
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9c5f65dcef]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Add EM_HOST and EF_HOST defines
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1f163cb610]
* Fri Feb  7 2025 tonyj@suse.de
- perf dwarf-regs: Remove
  PERF_HAVE_ARCH_REGS_QUERY_REGISTER_OFFSET
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 01399c6c04]
* Fri Feb  7 2025 tonyj@suse.de
- perf docs: Document tool and hwmon events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d736e5a35f]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add hwmon "PMU" test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 84ee1fb92d]
* Fri Feb  7 2025 tonyj@suse.de
- perf pmu: Add calls enabling the hwmon_pmu
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5a56ca0221]
* Fri Feb  7 2025 tonyj@suse.de
- perf hwmon_pmu: Add a tool PMU exposing events from hwmon in
  sysfs (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b1708ce49a]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add hwmon filename parser test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fd53adfb24]
* Fri Feb  7 2025 tonyj@suse.de
- perf hwmon_pmu: Add hwmon filename parser
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 16aa2d5ea7]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Include libtraceevent headers directly indicated
  by pkg-config (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6c45337e58]
* Fri Feb  7 2025 tonyj@suse.de
- perf script python: Adjust objdump start/end per map pgoff
  parameter (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3e4ae53a15]
* Fri Feb  7 2025 tonyj@suse.de
- perf script cs_etm: Add map_pgoff to python dictionary
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 57805dc915]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Expand metric+unit buffer size
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9b80b538be]
* Fri Feb  7 2025 tonyj@suse.de
- perf: event: Remove deadcode
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9583c0cf9e]
* Fri Feb  7 2025 tonyj@suse.de
- perf trace: avoid garbage when not printing a trace event's
  arguments (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 8c6d5b7777]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Fix ftrace test with regex patterns
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a923abd635]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Remove dangling CFLAGS for removed attr.o object
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e466330845]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Add missing cflags when building with custom
  libtraceevent (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7d56e0cfca]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Remove cpu-list BPF cgroup counter test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 72323907e0]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Make libunwind opt-in rather than opt-out
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 8aa7eb8f6f]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Use sqrtloop workload to test bperf event
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5d8632ac4a]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Support inherit events during fork() for bperf
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 184f14c1a4]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Use old behavior when opening old SPE files
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e8e275e58d]
* Fri Feb  7 2025 tonyj@suse.de
- perf ftrace latency: Fix unit on histogram first entry when
  using --use-nsec (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 034faa7648]
* Fri Feb  7 2025 tonyj@suse.de
- perf, riscv: Wire up perf trace support for RISC-V
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c1c99c4c3a]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix retrieval of source files from a debuginfod
  server (perf-sle16-v6.13-userspace-update).
  [kernel-source commit dc194280e3]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Update --itrace help text
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 14f29a7b3c]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Correctly set sample flags
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3c796a6488]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Use ARM_SPE_OP_BRANCH_ERET when synthesizing
  branches (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 51012688d6]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Set sample.addr to target address for instruction
  sample (perf-sle16-v6.13-userspace-update).
  [kernel-source commit adb3291159]
* Fri Feb  7 2025 tonyj@suse.de
- perf vendor events arm64: Add i.MX91 DDR Performance Monitor
  metrics (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9cf3da0614]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Sort tests placing exclusive tests last
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 69689c8374]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add a signal handler to kill forked child processes
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 82866cf96a]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Make parallel testing the default
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b476456c33]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Run parallel tests in two passes
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit bf3ca60a9d]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add a signal handler around running a test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a2ffbfbd41]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Tag parallel failing shell tests with "(exclusive)"
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 4bb548da3e]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Avoid list test blocking on writing to stdout
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 4462ae032d]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Reduce scope of parallel variable
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit cd0865ddb0]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Display number of active running tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7fbff0e74c]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Fix not cleaning up disasm_line in
  symbol__disassemble_raw() (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a1ee8c9901]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Use disasm_line__free() to properly free
  disasm_line (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 73354532f3]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Use disasm_line__free() to properly free
  disasm_line (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3a8e106f33]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add precise_max subtest to the perf record shell test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3f1d0606a9]
* Fri Feb  7 2025 tonyj@suse.de
- perf record: Just use "cycles:P" as the default event
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 50b05f1096]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Check fallback error and order
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit af00d1d6ac]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Move x86__is_amd_cpu() to util/env.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5b56c06457]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Detect missing kernel features properly
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit cc8b178da2]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Do not set exclude_guest for precise_ip
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3a05479000]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Simplify evsel__add_modifier()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1d772308d2]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Don't set attr.exclude_guest by default
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 38d7278184]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Add fallback for exclude_guest
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6f3cd921f0]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: sched-pipe bench: add (-n) nonblocking benchmark
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2582519b59]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Document the -w/--workload option
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 60f85f63e2]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Introduce --list-workloads to list the available
  workloads (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 46c1e80511]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Introduce workloads__for_each()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit eaf68a8427]
* Fri Feb  7 2025 tonyj@suse.de
- perf vendor events amd: Update Zen 5 data cache fill events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5139f363e4]
* Fri Feb  7 2025 tonyj@suse.de
- perf vendor events amd: Add Zen 5 data fabric metrics
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d6abb05c00]
* Fri Feb  7 2025 tonyj@suse.de
- perf vendor events amd: Add Zen 5 data fabric events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9d2288cda2]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Fix perf test case 84 on s390
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5687e359b4]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Update all metrics test like metricgroups test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 96d65f32fe]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Rename CONFIG_DWARF to CONFIG_LIBDW
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit bb5ff5a587]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Rename HAVE_DWARF_SUPPORT to HAVE_LIBDW_SUPPORT
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1a26c0fb86]
* Fri Feb  7 2025 tonyj@suse.de
- perf libdw: Remove unnecessary defines
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b6547e128a]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Move elfutils support check to libdw check
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f72a9a0061]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Combine test-dwarf-getcfi into test-libdw
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b2f922633e]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Combine test-dwarf-getlocations into test-libdw
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 71b4cef85f]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Combine libdw-dwarf-unwind into libdw feature tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 4b98ecb12b]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Rename test-dwarf to test-libdw
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 545303a09d]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Remove defined but never used variable
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 07c79e3873]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Rename NO_DWARF to NO_LIBDW
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 00effe0667]
* Fri Feb  7 2025 tonyj@suse.de
- perf build: Fix LIBDW_DIR (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3f271d165c]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Move attr files into shell directory where they
  are used (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c970a2ef60]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Remove C test wrapper for attr.py
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9af031a69a]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add a shell wrapper for "Setup struct
  perf_event_attr" (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f5507374ca]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Correct demangled symbols in C++ program
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 273d08edba]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Disable metric thresholds for CSV and JSON
  metric-only mode (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7e76e2c4a0]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Add metric-threshold to json output
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 21a0d9ca24]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Change color to threshold in print_metric
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 856bfbd713]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Drop metric-unit if unit is NULL
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 006b0d9196]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Display "none" for NaN with metric only json
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6159a689a8]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Fix/add parameter names for print_metric
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 77662a0fdf]
* Fri Feb  7 2025 tonyj@suse.de
- perf color: Add printf format checking and resolve issues
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 54305fe85e]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Fix libdw memory leak
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5706a02432]
* Fri Feb  7 2025 tonyj@suse.de
- perf disasm: Fix capstone memory leak
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d0d20a6de0]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf/powerpc/util: Add support to handle compatible mode
  PVR for perf json events (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9aa97c1f70]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf/pmu-events/powerpc: Add support for compat events
  in json (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 4dec6fa2da]
* Fri Feb  7 2025 tonyj@suse.de
- perf dso: Fix symtab_type for kmod compression
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 749e575fb7]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Improve log for long event name failure
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 61e88be185]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Check group string length
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7aaee69d87]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Use the MAX_EVENT_NAME_LEN macro
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7edea68b1c]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Speed up some tests using perf list
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e23139d6fa]
* Fri Feb  7 2025 tonyj@suse.de
- perf x86/topdown: Refine helper arch_is_topdown_metrics()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d72e7807c4]
* Fri Feb  7 2025 tonyj@suse.de
- perf x86/topdown: Make topdown metrics comparators be symmetric
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fa4c305e3d]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Remove duplicate io.h header
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit dcc3a616a9]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Add Cortex CPUs to common data source encoding
  list (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1e56d397f4]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Add Neoverse-V2 to common data source encoding
  list (perf-sle16-v6.13-userspace-update).
  [kernel-source commit bd406d5531]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Remove the unused 'midr' field
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1c09a16e7d]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Use metadata to decide the data source feature
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3d71214043]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Introduce arm_spe__is_homogeneous()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 17e4ec3c04]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Rename the common data source encoding
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ee3cb32ec9]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Rename arm_spe__synth_data_source_generic()
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 8cae8f9f33]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel: Fix missing inherit + sample read check
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f44d303b28]
* Fri Feb  7 2025 tonyj@suse.de
- perf sched timehist: Add pre-migration wait time option
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2378863e06]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Remove unnecessary parentheses
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9868f58192]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix possible compiler warnings in hashmap
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 2edf592ca5]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Fix compiler error in util/tool_pmu.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f9bbe4202b]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf/tests: Remove duplicate evlist__delete in
  tests/tool_pmu.c (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9c41393438]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf/tests: Fix compilation error with strncpy in
  tests/tool_pmu (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 02ad1fcd45]
* Fri Feb  7 2025 tonyj@suse.de
- perf report: Display columns Predicted/Abort/Cycles in
  - -branch-history (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 78e00a0764]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Add tool PMU test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 15d7303675]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Switch to standard pmu functions and json
  descriptions (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f59c9b4645]
* Fri Feb  7 2025 tonyj@suse.de
- perf jevents: Add tool event json under a common architecture
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1676ee7802]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Move expr literals to tool_pmu
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5efde676c1]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Rename perf_tool_event__* to tool_pmu__*
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a13c5c07c8]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Rename enum perf_tool_event to tool_pmu_event
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ec7d957b06]
* Fri Feb  7 2025 tonyj@suse.de
- perf tool_pmu: Factor tool events into their own PMU
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 263c1cceac]
* Fri Feb  7 2025 tonyj@suse.de
- perf parse-events: Expose/rename config_term_name
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d1dfd4eae4]
* Fri Feb  7 2025 tonyj@suse.de
- perf pmu: Allow hardcoded terms to be applied to attributes
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ef8a802871]
* Fri Feb  7 2025 tonyj@suse.de
- perf pmu: Simplify an asprintf error message
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit cab9e84ddb]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: Remove unused color_fwrite_lines
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6a5bf63e42]
* Fri Feb  7 2025 tonyj@suse.de
- perf test x86: Fix typo in intel-pt-test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6aca3688d7]
* Fri Feb  7 2025 tonyj@suse.de
- perf probe: Remove unused add_perf_probe_events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit b7ed4e1ed1]
* Fri Feb  7 2025 tonyj@suse.de
- perf test attr: Add back missing topdown events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 378fc74e0a]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Dump metadata with version 2
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1a1124730f]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Support metadata version 2
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a73dd39afb]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Save per CPU information in metadata
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c050ca574d]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Calculate meta data size
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 21c0e5566b]
* Fri Feb  7 2025 tonyj@suse.de
- perf arm-spe: Define metadata header version 2
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f2c6cfc6c3]
* Fri Feb  7 2025 tonyj@suse.de
- perf list: update option desc in man page
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit ce82ef0279]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Restore sample rate for perf_event_attr
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a077996446]
* Fri Feb  7 2025 tonyj@suse.de
- perf trace: Keep exited threads for summary
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9e1ba1e003]
* Fri Feb  7 2025 tonyj@suse.de
- perf/test: perf test 86 fails on s390
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 13bed83158]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf: Allow inherit + PERF_SAMPLE_READ when opening events
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f76a751780]
* Fri Feb  7 2025 tonyj@suse.de
- tools/perf: Correctly calculate sample period for inherited
  SAMPLE_READ values (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3c917acf14]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Skip not fail syscall tp fields test when
  insufficient permissions (perf-sle16-v6.13-userspace-update).
  [kernel-source commit a8f4b4eda4]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Skip not fail tp fields test when insufficient
  permissions (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e08f602d4d]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Fix memory leaks on event-times error paths
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 925a92a033]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Fix affinity memory leaks on error path
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fbe899d3b4]
* Fri Feb  7 2025 tonyj@suse.de
- perf jevents: Don't stop at the first matched pmu when searching
  a events table (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 3ff6343381]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Add more topdown events regroup tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 33011ce264]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Add topdown events counting and sampling tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 972f543f21]
* Fri Feb  7 2025 tonyj@suse.de
- perf tests: Add leader sampling test in record tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit bb0c00f8a5]
* Fri Feb  7 2025 tonyj@suse.de
- perf x86/topdown: Don't move topdown metric events in group
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6478266b9f]
* Fri Feb  7 2025 tonyj@suse.de
- perf x86/topdown: Correct leader selection with sample_read
  enabled (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 72fa8a0e9c]
* Fri Feb  7 2025 tonyj@suse.de
- perf x86/topdown: Complete topdown slots/metrics events check
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit fd578a2a8f]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel: Reduce a variables scope
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9df7ae981d]
* Fri Feb  7 2025 tonyj@suse.de
- perf vender events arm64: Use "Topdown" as topdown metric
  group name (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 66d0882e94]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Use ARRAY_SIZE for array length
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f21e807484]
* Fri Feb  7 2025 tonyj@suse.de
- perf/test: Speed up test case perf annotate basic tests
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 11ad08a0c7]
* Fri Feb  7 2025 tonyj@suse.de
- perf mem: Fix printing PERF_MEM_LVLNUM_{L2_MHB|MSC}
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 255a2ed81c]
* Fri Feb  7 2025 tonyj@suse.de
- perf sched replay: Remove unused parts of the code
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 828562b42a]
* Fri Feb  7 2025 tonyj@suse.de
- libperf: Explicitly specify install-html dependencies
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 758121f5f5]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Add a test for default perf stat command
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 5d915fa81a]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Make stat test work on DT devices
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 6adc38fd4e]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel: Remove pmu_name (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f8fe28552b]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel x86: Make evsel__has_perf_metrics work for legacy
  events (perf-sle16-v6.13-userspace-update).
  [kernel-source commit dbbeec175d]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Remove evlist__add_default_attrs use strings
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 19dcf8ac31]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Uniquify event name improvements
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit f96edd6459]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel: Add alternate_hw_config and use in evsel__match
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit d836e6e89a]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Ignore security failures in all PMU test
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit e92ec7dc5a]
* Fri Feb  7 2025 tonyj@suse.de
- perf symbol: Do not fixup end address of labels
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 412661be9b]
* Fri Feb  7 2025 tonyj@suse.de
- perf vendor events arm64: imx95: add
  imx95_bandwidth_usage.lpddr4x metric
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 1d45302dce]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Stop repeating when ref_perf_stat() returns -1
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 05f4c2c21d]
* Fri Feb  7 2025 tonyj@suse.de
- perf stat: Close cork_fd when create_perf_stat_counter() failed
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7e38d3d1ec]
* Fri Feb  7 2025 tonyj@suse.de
- perf evsel: display dmesg command of showing a hardcoded path
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7ec34c0d8c]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: cs-etm: Test Coresight disassembly script
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 086405fa1b]
* Fri Feb  7 2025 tonyj@suse.de
- perf scripts python cs-etm: Add start and stop arguments
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 02159dac15]
* Fri Feb  7 2025 tonyj@suse.de
- perf scripts python cs-etm: Improve arguments
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 60b5bfad6f]
* Fri Feb  7 2025 tonyj@suse.de
- perf scripts python cs-etm: Update to use argparse
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 65045b5e72]
* Fri Feb  7 2025 tonyj@suse.de
- perf scripting python: Add function to get a config value
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 9c66d5c3b3]
* Fri Feb  7 2025 tonyj@suse.de
- perf cs-etm: Use new OpenCSD consistency checks
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 41fe0e7803]
* Fri Feb  7 2025 tonyj@suse.de
- perf cs-etm: Don't flush when packet_queue fills up
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 7b08a74124]
* Fri Feb  7 2025 tonyj@suse.de
- perf test: Be more tolerant of metricgroup failures
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit c427007fc4]
* Fri Feb  7 2025 tonyj@suse.de
- perf tools: update expected diff for lib/list_sort.c
  (perf-sle16-v6.13-userspace-update).
  [kernel-source commit 092fd2a283]
* Fri Feb  7 2025 tonyj@suse.de
- Rebase to SLE-16 SLFO kernel sources (perf v6.12)
- Disable link time optimization (-flto)
* Thu Jan  9 2025 tonyj@suse.de
- perf arm-spe: Add Neoverse-V2 to common data source encoding
  list (jsc#PED-11188).
  [kernel-source commit ef12247022]
* Thu Jan  2 2025 tonyj@suse.de
- perf vendor events amd: Update Zen 5 data cache fill events
  (jsc#PED-11774).
  [kernel-source commit 072043dcfa]
* Thu Jan  2 2025 tonyj@suse.de
- perf vendor events amd: Add Zen 5 data fabric metrics
  (jsc#PED-11774).
  [kernel-source commit e9e3934051]
* Thu Jan  2 2025 tonyj@suse.de
- perf vendor events amd: Add Zen 5 data fabric events
  (jsc#PED-11774).
  [kernel-source commit 1377c676f8]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace: Fix undefined behavior in cmp_profile_data()
  (git-fixes).
  [kernel-source commit f402063ac6]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Fix build-id event recording (git-fixes).
  [kernel-source commit 868cfa0f1b]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Return -ENOMEM directly when pfi allocation
  fails (git-fixes).
  [kernel-source commit bdd8afa672]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Fix printing PERF_MEM_LVLNUM_{L2_MHB|MSC} (git-fixes).
  [kernel-source commit 5e45bcfab5]
* Thu Jan  2 2025 tonyj@suse.de
- perf cap: Add __NR_capget to arch/x86 unistd
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d203039890]
* Thu Jan  2 2025 tonyj@suse.de
- perf python: Fix up the build on architectures without
  HAVE_KVM_STAT_SUPPORT (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9f5c7e9efd]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Handle perftool-testsuite_probe failure due to
  broken DWARF (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bf868497f2]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Fix non-listed archs in the syscalltbl routines
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5f0945d32b]
* Thu Jan  2 2025 tonyj@suse.de
- perf build: Change the clang check back to 12.0.1
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7978494339]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace augmented_raw_syscalls: Add more checks to pass
  the verifier (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 193cac0c07]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace augmented_raw_syscalls: Add extra array
  index bounds checking to satisfy some BPF verifiers
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ab07fbe99d]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: The return from 'write' isn't a pid
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4f0bfbf92f]
* Thu Jan  2 2025 tonyj@suse.de
- perf cs-etm: Fix the assert() to handle captured and unprocessed
  cpu trace (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7dbbd5160c]
* Thu Jan  2 2025 tonyj@suse.de
- perf build: Fix build feature-dwarf_getlocations fail for old
  libdw (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6a78f22473]
* Thu Jan  2 2025 tonyj@suse.de
- perf build: Fix static compilation error when libdw is not
  installed (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ab578d8c62]
* Thu Jan  2 2025 tonyj@suse.de
- perf dwarf-aux: Fix build with !HAVE_DWARF_GETLOCATIONS_SUPPORT
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7b1597a0aa]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Cope with differences for lib/list_sort.c copy
  from the kernel (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d3f443217d]
* Thu Jan  2 2025 tonyj@suse.de
- tools check_headers.sh: Add check variant that excludes some
  hunks (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 73b95aeff3]
* Thu Jan  2 2025 tonyj@suse.de
- perf vdso: Missed put on 32-bit dsos
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 41819df0d8]
* Thu Jan  2 2025 tonyj@suse.de
- perf symbol: Set binary_type of dso when loading
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ffdcd7bce5]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Mark the 'head' arg in the set_robust_list syscall
  as coming from user space (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c2ef7b853f]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Mark the 'rseq' arg in the rseq syscall as coming
  from user space (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a708e993b8]
* Thu Jan  2 2025 tonyj@suse.de
- perf env: Find correct branch counter info on hybrid
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0945e40fc7]
* Thu Jan  2 2025 tonyj@suse.de
- perf evlist: Print hint for group
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6b685ca882]
* Thu Jan  2 2025 tonyj@suse.de
- tools: Drop nonsensical -O6 (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 340e8041d8]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmu: To info add event_type_desc
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4cd1ac0f51]
* Thu Jan  2 2025 tonyj@suse.de
- perf evsel: Add accessor for tool_event
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 974c32cfe5]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmus: Fake PMU clean up (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5756b7d1c1]
* Thu Jan  2 2025 tonyj@suse.de
- perf list: Avoid potential out of bounds memory read
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 84eadbd064]
* Thu Jan  2 2025 tonyj@suse.de
- perf help: Fix a typo ("bellow")
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0cea9ec523]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace: Detect whether ftrace is enabled on system
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a8a266ccb6]
* Thu Jan  2 2025 tonyj@suse.de
- perf test shell probe_vfs_getname: Remove extraneous '='
  from probe line number regex (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ac08131f9b]
* Thu Jan  2 2025 tonyj@suse.de
- perf build: Require at least clang 16.0.6 to build BPF skeletons
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5677f91ba5]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: If a syscall arg is marked as 'const', assume it
  is coming _from_ userspace (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e7a6d2490a]
* Thu Jan  2 2025 tonyj@suse.de
- perf parse-events: Remove duplicated include in parse-events.c
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 765c82e602]
* Thu Jan  2 2025 tonyj@suse.de
- perf callchain: Allow symbols to be optional when resolving
  a callchain (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 34b3f101c0]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Lazy build-id mmap2 event insertion
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 574e228b8c]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Add new mmap2-buildid-all option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d2d4ff56ad]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Fix build ID injection
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d24e71d0c2]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add pr_debug_scope()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit aa3ea27e4f]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Treat 'call' instruction as stack operation
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 25216a7bc8]
* Thu Jan  2 2025 tonyj@suse.de
- perf build: Autodetect minimum required llvm-dev version
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bc1b3135f4]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Mark the rlim arg in the prlimit64
  and setrlimit syscalls as coming from user space
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7f70bc5f87]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Support collecting 'union's with the BPF augmenter
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3aedcc2ca7]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Add --force-btf for debugging
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 17816fef75]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Collect augmented data using BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a73b3af3be]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Pretty print buffer data
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 13d7485359]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Pretty print struct data
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ad9b37fb22]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Add trace__bpf_sys_enter_beauty_map() to prepare
  for fetching data in BPF (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d988b873ae]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Mark bpf's attr as from_user
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6ddc55abb7]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Introduce SCA_TIMESPEC_FROM_USER() to set .from_user
  = true (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b7e886fa8f]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Introduce SCA_SOCKADDR_FROM_USER() to set .from_user
  = true (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 79b8428ff9]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Introduce SCA_PERF_ATTR_FROM_USER() to set
  .from_user = true (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 648de0b1d9]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Mark which syscall arguments go from user space
  to kernel space (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6072e3285f]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Use a common encoding for augmented arguments,
  with size + error + payload (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 11d7acd685]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace augmented_syscalls.bpf: Move the renameat aumenter
  to renameat2, temporarily (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 428a9759f4]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Fix the wrong reference in parse_record_events()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a4b67fdf95]
* Thu Jan  2 2025 tonyj@suse.de
- perf script python: Avoid buffer overflow in python PEBS
  register interface (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8e55b6556c]
* Thu Jan  2 2025 tonyj@suse.de
- perf jevents: Ignore sys when determining a model directory
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ee504abe1a]
* Thu Jan  2 2025 tonyj@suse.de
- perf check: Fix inconsistencies in feature names
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 266c41835d]
* Thu Jan  2 2025 tonyj@suse.de
- perf tests probe_vfs_getname.sh: Update to use 'perf check
  feature' (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 113c398a7b]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools test_task_analyzer.sh: Update to use 'perf check
  feature' (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 82379d7b22]
* Thu Jan  2 2025 tonyj@suse.de
- perf version: Update --build-options to use 'supported_features'
  array (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 26b56d1443]
* Thu Jan  2 2025 tonyj@suse.de
- perf jevents: Add cpuid to model lookup command
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d5970e236d]
* Thu Jan  2 2025 tonyj@suse.de
- perf check: Introduce 'check' subcommand
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bca9d1f9b9]
* Thu Jan  2 2025 tonyj@suse.de
- libsubcmd: Don't free the usage string
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3b447983a3]
* Thu Jan  2 2025 tonyj@suse.de
- perf parse-events: Vary default_breakpoint_len on i386 and arm64
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3387ec7395]
* Thu Jan  2 2025 tonyj@suse.de
- perf parse-events: Add default_breakpoint_len helper
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bc75379083]
* Thu Jan  2 2025 tonyj@suse.de
- perf parse-events: Pass cpu_list as a perf_cpu_map in
  __add_event() (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9f5e635a4e]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmu: Merge boolean sysfs event option parsing
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit dd0910d713]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Add --prio option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a7b93e1157]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Add --show-prio option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ca8f4f8580]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Remove redundant BUG_ON in
  timehist_sched_change_event() (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c9461ebaa0]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Skip print non-idle task samples when
  only show idle events (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1387916074]
* Thu Jan  2 2025 tonyj@suse.de
- perf record offcpu: Constify control data for BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cbabbba1c0]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock contention: Constify control data for BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5fb63a9ca5]
* Thu Jan  2 2025 tonyj@suse.de
- perf kwork: Constify control data for BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 2ee8c708bf]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace latency: Constify control data for BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit feefe0675a]
* Thu Jan  2 2025 tonyj@suse.de
- perf stat: Constify control data for BPF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1e364e7e4b]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Make watchpoint data 32-bits on i386
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6f7b26870d]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Skip uprobe test if probe command isn't present
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 887af70632]
* Thu Jan  2 2025 tonyj@suse.de
- perf time-utils: Fix 32-bit nsec parsing
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e30669cb8f]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmus: Fix name comparisons on 32-bit systems
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 49a3c4104d]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: LLVM-based disassembler
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 67f1a9ce2d]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Split out read_symbol()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f0cc160371]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Support LLVM for addr2line()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 67b61f2ba7]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Build x86 32-bit syscall table
  from arch/x86/entry/syscalls/syscall_32.tbl
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ef35876aa4]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Fixed timestamp error when unable to
  confirm event sched_in time (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 41e38a26d4]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock contention: Do not fail EEXIST for update
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bbb8d8db33]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock contention: Simplify spinlock check
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4b57269b81]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock contention: Handle error in a single place
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 88295f3861]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Additional pipe tests with pipe output written to
  a file (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cd1bdd6a84]
* Thu Jan  2 2025 tonyj@suse.de
- perf header: Remove repipe option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0e09da2048]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Overhaul handling of pipe files
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 56b027575a]
* Thu Jan  2 2025 tonyj@suse.de
- perf header: Allow attributes to be written after data
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 44c5cb15d4]
* Thu Jan  2 2025 tonyj@suse.de
- perf header: Fail read if header sections overlap
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 17c42bb895]
* Thu Jan  2 2025 tonyj@suse.de
- perf header: Add kerneldoc to 'struct perf_file_header'
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fbe0843f3d]
* Thu Jan  2 2025 tonyj@suse.de
- perf session: Document 'struct perf_session' and constify its
  'auxtrace' member (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 542725dbe6]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Print queue number in raw trace dump
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 62fca2b77e]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Support version 0.1 of HW_ID packets
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 54419d6db4]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Only save valid trace IDs into files
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 56fe601fab]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Create decoders based on the trace ID mappings
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8cad062684]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Move traceid_list to each queue
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4f9db63387]
* Thu Jan  2 2025 tonyj@suse.de
- perf: cs-etm: Allocate queues for all CPUs
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 15ee44ee66]
* Thu Jan  2 2025 tonyj@suse.de
- perf cs-etm: Create decoders after both AUX and HW_ID search
  passes (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e239142dc5]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add 'perf record cgroup' filtering test
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit abb480b058]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Support filtering on cgroups
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ecad24fb77]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Add build dependency to header files
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e51bf33a18]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Fix segfault when 'sym' sort key is not used
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6ab4a4e1bb]
* Thu Jan  2 2025 tonyj@suse.de
- perf test trace_btf_enum: Fix shellcheck warning
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b0cb483503]
* Thu Jan  2 2025 tonyj@suse.de
- perf auxtrace: Remove unused 'pmu' pointer from struct
  auxtrace_record (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cd3fca91b3]
* Thu Jan  2 2025 tonyj@suse.de
- perf auxtrace: Use evsel__is_aux_event() for checking AUX event
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bc8a8860f0]
* Thu Jan  2 2025 tonyj@suse.de
- perf vendor events arm64: Move Yitian 710 DDR PMU into T-Head
  directory (perf-sp7-v6.12-userspace-update).
  [kernel-source commit dc679e2bf2]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Pass the richer 'struct syscall_arg' pointer to
  trace__btf_scnprintf() (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 41c2332aea]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Fix perf trace -p <PID>
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3b14d9e953]
* Thu Jan  2 2025 tonyj@suse.de
- perf evlist: Introduce method to find if there is a bpf-output
  event (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a98e49b5eb]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Name events in stats for pipe mode
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 751694cee9]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite: Install perf-report tests in
  the 'make install-tests -C tools/perf' target
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 55fb7801ed]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite report: Add test case for perf report
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8cdc3526ea]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite report: Add test for perf-report basic
  functionality (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 00da7aaf20]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite: Add common output checking helper
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6736e095a3]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite probe: Add test for line semantics
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8c8efb8f91]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite probe: Add test for invalid options
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 2399b9aff7]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite probe: Add test for basic perf-probe options
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7cbef6ba9c]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite probe: Add test for blacklisted kprobes handling
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a714d12276]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite: Fix shellcheck warnings
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit af3ff8b9db]
* Thu Jan  2 2025 tonyj@suse.de
- perf testsuite: Merge settings files for shell tests
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 23069175f2]
* Thu Jan  2 2025 tonyj@suse.de
- perf tests shell: Skip base_* dirs in test script search
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bc28dde0e5]
* Thu Jan  2 2025 tonyj@suse.de
- perf test vfs_getname: Look for alternative line where to
  collect the pathname (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 045f032cd5]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Update sample filtering tests with multiple events
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 201103803e]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Print lost samples due to BPF filter
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 597358ea5f]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Support multiple events properly
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4b7f1fe05c]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Support external tests for separate objdir
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 2beb55aab6]
* Thu Jan  2 2025 tonyj@suse.de
- perf python: Disable -Wno-cast-function-type-mismatch if
  present on clang (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 518b07940e]
* Thu Jan  2 2025 tonyj@suse.de
- perf python: Allow checking for the existence of warning
  options in clang (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fa7679f1d0]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Copy back variable types after move
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4c272333d2]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Update stack slot for the store
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 2ec412b2b0]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Update debug messages
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 50d85bf365]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add 'typecln' sort key
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a8334e1d4f]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Show offset and size in hex
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 80754234eb]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf: Remove redundant check that map is NULL
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e534c30514]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Fix percpu pointer check
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 574dcc1756]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Prefer struct/union over base type
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cb6a35332d]
* Thu Jan  2 2025 tonyj@suse.de
- perf cap: Tidy up and improve capability testing
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1d18bd22fe]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Set bitfield member offset and size properly
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 61f5490e2a]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add cgroup sampling test
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7dd4155feb]
* Thu Jan  2 2025 tonyj@suse.de
- perf record: Fix sample cgroup & namespace tracking
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6f401cbe8c]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Combine mmap and mmap2 handling
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 670d02fe7e]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Combine different mmap and mmap2 functions
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0b3132f0f9]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Combine build_ids and build_id_all into enum
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9e1751f3f3]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Expand pipe/inject test
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5b57b2e0cc]
* Thu Jan  2 2025 tonyj@suse.de
- perf evsel: Constify evsel__id_hdr_size() argument
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8dc655f8f3]
* Thu Jan  2 2025 tonyj@suse.de
- perf dso: Constify dso_id (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1da1fb9903]
* Thu Jan  2 2025 tonyj@suse.de
- perf jit: Constify filename argument
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 406c06b8ed]
* Thu Jan  2 2025 tonyj@suse.de
- perf map: API clean up (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8124ba6c74]
* Thu Jan  2 2025 tonyj@suse.de
- perf synthetic-events: Avoid unnecessary memset
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e2a516e93c]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Update type stat at the end of
  find_data_type_die() (perf-sp7-v6.12-userspace-update).
  [kernel-source commit dc67977f08]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Check variables in every scope
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 16f914a868]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add is_better_type() helper
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit dc66104de6]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add is_pointer_type() helper
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8ffa91f267]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Change return type of find_data_type_block()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit bf748ea7ca]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add variable_state_str()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6ea8823d23]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Add 'enum type_match_result'
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 604d18a364]
* Thu Jan  2 2025 tonyj@suse.de
- perf stat: Display iostat headers correctly
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b9bf2b24db]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched timehist: Fix missing free of session in
  perf_sched__timehist() (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 084448cd30]
* Thu Jan  2 2025 tonyj@suse.de
- perf hist: Update hist symbol when updating maps
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3ef2b331ca]
* Thu Jan  2 2025 tonyj@suse.de
- perf test record.sh: Raise limit of open file descriptors
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ea27d19151]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add new test cases for the branch counter feature
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 851161e2f1]
* Thu Jan  2 2025 tonyj@suse.de
- perf script: Add branch counters (jsc#PED-10244,
  perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7b5a268275]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Display the branch counter histogram
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit cfa49f53be]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Display the branch counter histogram
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7031c03ab0]
* Thu Jan  2 2025 tonyj@suse.de
- perf evsel: Assign abbr name for the branch counter events
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6df064eb03]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Save branch counters for each block
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 948148610f]
* Thu Jan  2 2025 tonyj@suse.de
- perf evlist: Save branch counters information (jsc#PED-10244,
  perf-sp7-v6.12-userspace-update).
  [kernel-source commit 86542bdf07]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Remove the first overflow check for branch counters
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4c95e5bd98]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Fix --total-cycles --stdio output error
  (jsc#PED-10244, perf-sp7-v6.12-userspace-update).
  [kernel-source commit bdf6f7cba3]
* Thu Jan  2 2025 tonyj@suse.de
- perf test annotate: Dump trapping test in trap handler
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e5533f0c1d]
* Thu Jan  2 2025 tonyj@suse.de
- perf disasm: Fix memory leak for locked operations
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f8f140f907]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Inject build ids for entire call chain
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 33a4fb3935]
* Thu Jan  2 2025 tonyj@suse.de
- perf callchain: Add a for_each callback style API
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 32840db837]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add test for Intel TPEBS counting mode
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 36ebd454f4]
* Thu Jan  2 2025 tonyj@suse.de
- perf Document: Add TPEBS (Timed PEBS(Precise Event-Based
  Sampling)) to Documents (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8e47f00da4]
* Thu Jan  2 2025 tonyj@suse.de
- perf stat: Add command line option for enabling TPEBS recording
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9036383ea4]
* Thu Jan  2 2025 tonyj@suse.de
- perf vendor events intel: Add MTL metric JSON files
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f973cc266c]
* Thu Jan  2 2025 tonyj@suse.de
- perf stat: Fork and launch 'perf record' when 'perf
  stat' needs to get retire latency value for a metric
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fc5eb0830b]
* Thu Jan  2 2025 tonyj@suse.de
- perf data: Allow to use given fd in data->file.fd
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c43b77b90e]
* Thu Jan  2 2025 tonyj@suse.de
- perf parse-events: Add a retirement latency modifier
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ab135fd4ce]
* Thu Jan  2 2025 tonyj@suse.de
- perf session: Constify tool (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 74912ad1de]
* Thu Jan  2 2025 tonyj@suse.de
- perf tool: Remove perf_tool__fill_defaults()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d742bfb78d]
* Thu Jan  2 2025 tonyj@suse.de
- perf kwork: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 87acd94d53]
* Thu Jan  2 2025 tonyj@suse.de
- perf test event_update: Ensure tools is initialized
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1d5cf6d8e2]
* Thu Jan  2 2025 tonyj@suse.de
- perf data convert ctf: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d8e538f2ba]
* Thu Jan  2 2025 tonyj@suse.de
- perf data convert json: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fcb9f15f5a]
* Thu Jan  2 2025 tonyj@suse.de
- perf diff: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 272fa90318]
* Thu Jan  2 2025 tonyj@suse.de
- perf timechart: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5f05f0e03a]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 04d5efabf8]
* Thu Jan  2 2025 tonyj@suse.de
- perf sched: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9db9b504ae]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e7b3c939fb]
* Thu Jan  2 2025 tonyj@suse.de
- perf stat: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4cdbbea6d0]
* Thu Jan  2 2025 tonyj@suse.de
- perf report: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 3991a3821f]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c4dc1c40d5]
* Thu Jan  2 2025 tonyj@suse.de
- perf script: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 187b203a01]
* Thu Jan  2 2025 tonyj@suse.de
- perf c2c: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c2458353dc]
* Thu Jan  2 2025 tonyj@suse.de
- perf record: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 34ed3e883a]
* Thu Jan  2 2025 tonyj@suse.de
- perf evlist: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e420fda95c]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fb087bc512]
* Thu Jan  2 2025 tonyj@suse.de
- perf kvm: Use perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 770cb3ee78]
* Thu Jan  2 2025 tonyj@suse.de
- perf buildid-list: Use perf_tool__init
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a2e671c456]
* Thu Jan  2 2025 tonyj@suse.de
- perf kmem: Use perf_tool__init
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9c20e791e6]
* Thu Jan  2 2025 tonyj@suse.de
- perf tool: Add perf_tool__init()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8017acd84a]
* Thu Jan  2 2025 tonyj@suse.de
- perf tool: Move fill defaults into tool.c
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e74dca00e8]
* Thu Jan  2 2025 tonyj@suse.de
- perf tool: Constify tool pointers
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ce9408c379]
* Thu Jan  2 2025 tonyj@suse.de
- perf s390-cpumsf: Remove unused struct
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b648781d07]
* Thu Jan  2 2025 tonyj@suse.de
- perf auxtrace: Remove dummy tools
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 505fba54f0]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Fix leader sampling inserting additional samples
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f6c1bc73bd]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Show first-level children by default in TUI
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7d77bc2973]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Implement folding in TUI browser
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4635e0c24a]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Support folding in TUI browser
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 52b66a658e]
* Thu Jan  2 2025 tonyj@suse.de
- perf lock contention: Change stack_id type to s32
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a7d6d7aff5]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Fix a buffer overflow in TUI browser
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 81f31cefdc]
* Thu Jan  2 2025 tonyj@suse.de
- perf docs: Refine the description for the buffer size
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 1ac64c963d]
* Thu Jan  2 2025 tonyj@suse.de
- perf script: add --addr2line option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fec794c543]
* Thu Jan  2 2025 tonyj@suse.de
- perf tests pmu: Initialize all fields of test_pmu variable
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit daf51b9e73]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Support --skip-empty option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 9e465493c8]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Fix --group behavior when leader has no samples
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cb178ab67b]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Create source symlink in perf object dir
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 00090c42be]
* Thu Jan  2 2025 tonyj@suse.de
- perf debuginfo: Fix the build with !HAVE_DWARF_SUPPORT
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b4f454deae]
* Thu Jan  2 2025 tonyj@suse.de
- perf script python: Add the 'ins_lat' field to event handler
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6122a3668c]
* Thu Jan  2 2025 tonyj@suse.de
- perf test shell lbr: Support hybrid x86 systems too
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f903f45686]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add set of perf record LBR tests
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e8327ddfde]
* Thu Jan  2 2025 tonyj@suse.de
- perf callchain: Fix stitch LBR memory leaks
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7b98442211]
* Thu Jan  2 2025 tonyj@suse.de
- perf tests ftrace: Add pattern check for time, count
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e18af1e788]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add a new shell test for perf ftrace
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ae9f8dd7b0]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate-data: Show typedef names properly
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit c36e2798b5]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Cache debuginfo for data type profiling
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 663e49c45f]
* Thu Jan  2 2025 tonyj@suse.de
- perf hist: Fix reference counting of branch_info
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7c1084f5f3]
* Thu Jan  2 2025 tonyj@suse.de
- perf jevents.py: Ensure event names aren't duplicated
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 97209cb71f]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmu-events: Remove duplicated ampereone event
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fc55350d5d]
* Thu Jan  2 2025 tonyj@suse.de
- perf pmu-events: Change dependencies for empty-pmu-events.c test
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d8e6918733]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add build test for JEVENTS_ARCH=all
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f24c62b447]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Add --skip-empty option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0af230c672]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Set al->data_nr using the notes->src->nr_events
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e28d69c745]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Use annotation__pcnt_width() consistently
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fe81e98aa2]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Set notes->src->nr_events early
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6d569c237d]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Use al->data_nr if possible
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 63a68f2214]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Update documentation for new options
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit d2ce9da817]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Add -T/--data-type option to report subcommand
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 31fc5fda02]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Add -s/--sort option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 79feda61bc]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Add mode argument to sort_help()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 91513a516f]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Rework command option handling
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4510fce7d1]
* Thu Jan  2 2025 tonyj@suse.de
- perf mem: Free the allocated sort string, fixing a leak
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b5c8a3eb27]
* Thu Jan  2 2025 tonyj@suse.de
- perf hist: Correct hist_entry->mem_info refcounts
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit b6519b832a]
* Thu Jan  2 2025 tonyj@suse.de
- perf jevents: Autogenerate empty-pmu-events.c
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4d2daae3a6]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Update sample filtering test
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit a58f1ffded]
* Thu Jan  2 2025 tonyj@suse.de
- perf record: Add --setup-filter option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 428361a770]
* Thu Jan  2 2025 tonyj@suse.de
- perf record: Fix a potential error handling issue
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 976ad2af9f]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Support separate lost counts for each filter
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit fe6b82a130]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Support pin/unpin BPF object
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4d5cc5b099]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Split per-task filter use case
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit eae528d434]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Pass 'target' to perf_bpf_filter__prepare()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 0ef975d93e]
* Thu Jan  2 2025 tonyj@suse.de
- perf bpf-filter: Make filters map a single entry hashmap
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit af83e703c8]
* Thu Jan  2 2025 tonyj@suse.de
- perf jevents: Use name for special find value
  (PMU_EVENTS__NOT_FOUND) (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ab48e84db9]
* Thu Jan  2 2025 tonyj@suse.de
- perf list: Give clues if failed to open tracing events directory
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit edfb274087]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Fix wrong message when running "make JOBS=1"
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit cbb395e447]
* Thu Jan  2 2025 tonyj@suse.de
- perf arm-spe: Support multiple Arm SPE events
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 017870c511]
* Thu Jan  2 2025 tonyj@suse.de
- perf arm-spe: Extract evsel setting up
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 6e0446f6fb]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: make metric validation test return early
  when there is no metric supported on the test system
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit e66a7b4bb1]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace profile: Add -s/--sort option
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7ad2d353eb]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace: Add 'profile' command
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 71ac3690fa]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace: Factor out check_ftrace_capable()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5ce24cd56c]
* Thu Jan  2 2025 tonyj@suse.de
- perf ftrace: Add 'tail' option to --graph-opts
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit ae86885f64]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Enable evsel__is_aux_event() to work for S390_CPUMSF
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 8ee8a22a3d]
* Thu Jan  2 2025 tonyj@suse.de
- perf tools: Enable evsel__is_aux_event() to work for ARM/ARM64
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 4dab06eca1]
* Thu Jan  2 2025 tonyj@suse.de
- perf cs-etm: Output 0 instead of 0xdeadbeef when exception
  packets are flushed (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 569fbb06fb]
* Thu Jan  2 2025 tonyj@suse.de
- perf inject: Convert comma to semicolon
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 48aced31d0]
* Thu Jan  2 2025 tonyj@suse.de
- perf daemon: Convert comma to semicolon
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 27a284b5c6]
* Thu Jan  2 2025 tonyj@suse.de
- perf annotate: Convert comma to semicolon
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 446ab0d789]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Avoid python leak sanitizer test failures
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 7d0ddaa6b4]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Remove arg_fmt->is_enum, we can get that from the
  BTF type (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f6356d1c93]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Introduce trace__btf_scnprintf()
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 43e89d7924]
* Thu Jan  2 2025 tonyj@suse.de
- perf test trace_btf_enum: Add regression test
  for the BTF augmentation of enums in 'perf trace'
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit f1b7a90e2a]
* Thu Jan  2 2025 tonyj@suse.de
- perf test: Add landlock workload
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 5f24752643]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Filter enum arguments with enum names
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 51280cbb33]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: Augment non-syscall tracepoints with enum arguments
  with BTF (perf-sp7-v6.12-userspace-update).
  [kernel-source commit 92e25b7c18]
* Thu Jan  2 2025 tonyj@suse.de
- perf trace: BTF-based enum pretty printing for syscall args
  (perf-sp7-v6.12-userspace-update).
  [kernel-source commit db3e16d222]
* Fri Nov  8 2024 tonyj@suse.com
- Add BuildRequires:gcc-c++ (bsc#1231374)
  Kernel version v6.4 added the following change:
    commit dd317df072071903031ab5f91b4823858445c4a0
    perf build: Make binutil libraries opt in
  This means the following features which were previously selected are now
  deselected:
    libbfd
    libbfd-buildid
    libbfd-liberty
    libbfd-liberty-z
  This means c++ demangling no longer occurs.  Enable alternative support
  by adding the above BuildRequires.
* Sun Oct  6 2024 tonyj@suse.de
- perf mem: Fix missed p-core mem events on ADL and RPL
  (git-fixes).
  [kernel-source commit f1c255b12a]
* Sun Oct  6 2024 tonyj@suse.de
- perf mem: Check mem_events for all eligible PMUs (git-fixes).
  [kernel-source commit 57ac803ebc]
* Sun Oct  6 2024 tonyj@suse.de
- perf hist: Don't set hpp_fmt_value for members in --no-group
  (git-fixes).
  [kernel-source commit c1e99ea37a]
* Sun Oct  6 2024 tonyj@suse.de
- perf dwarf-aux: Handle bitfield members from pointer access
  (git-fixes).
  [kernel-source commit 0cc3fe6277]
* Sun Oct  6 2024 tonyj@suse.de
- perf annotate-data: Fix missing constant copy (git-fixes).
  [kernel-source commit 39f35f723e]
* Sun Oct  6 2024 tonyj@suse.de
- perf annotate-data: Fix off-by-one in location range check
  (git-fixes).
  [kernel-source commit ab2b27a883]
* Sun Oct  6 2024 tonyj@suse.de
- perf dwarf-aux: Check allowed location expressions when
  collecting variables (git-fixes).
  [kernel-source commit eabec0711f]
* Sun Oct  6 2024 tonyj@suse.de
- perf vendor events: SKX, CLX, SNR uncore cache event fixes
  (git-fixes).
  [kernel-source commit e1ec241aa8]
* Sun Oct  6 2024 tonyj@suse.de
- perf python: Remove PYTHON_PERF ifdefs (git-fixes).
  [kernel-source commit 5d15b94e9c]
* Sun Oct  6 2024 tonyj@suse.de
- perf bpf: Move BPF disassembly routines to separate file to
  avoid clash with capstone bpf headers (git-fixes).
  [kernel-source commit f25ce932fe]
* Sun Oct  6 2024 tonyj@suse.de
- perf test pmu: Remove unused test_pmus (git-fixes).
  [kernel-source commit c57a92c8d5]
* Sun Oct  6 2024 tonyj@suse.de
- perf scripts python cs-etm: Restore first sample log in verbose
  mode (git-fixes).
  [kernel-source commit 8add491284]
* Sat Oct  5 2024 tonyj@suse.de
- Update
  patches.suse/perf-beauty-Update-copy-of-linux-socket.h-with-the-k.patch
  to correct perf header differences check for socket.h
  [kernel-source commit 96e7f75ca0]
* Sat Oct  5 2024 tonyj@suse.de
- Switch to full upstream patch due to perf-sp7-v6.11-userspace-update.
  Update
  patches.suse/perf-arch-events-Fix-duplicate-RISC-V-SBI-firmware-event-name.patch
  (git-fixes, perf-sp7-v6.11-userspace-update).
  [kernel-source commit 916bf9a8a1]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Minimize "not reaching sample" for '-F
  +brstackinsn' (jsc#PED-10406).
  [kernel-source commit d396e21187]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Move PM_BR_MPRED_CMPL event for power10
  platform (jsc#PED-9888).
  [kernel-source commit 94b831ed2a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Move the JSON/events (jsc#PED-9888).
  [kernel-source commit 4a539d71d8]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-9888).
  [kernel-source commit 0c3fa1717c]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-9888).
  [kernel-source commit bc2cd95eac]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Set instruction name to be used with insn-stat
  when using raw instruction (jsc#PED-9879).
  [kernel-source commit 72e9426323]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to use libcapstone in powerpc
  (jsc#PED-9879).
  [kernel-source commit 39605ac6b9]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use capstone_init and remove open_capstone_handle
  from disasm.c (jsc#PED-9879).
  [kernel-source commit 625a78879a]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Make capstone_init non-static so that it can
  be used during symbol disassemble (jsc#PED-9879).
  [kernel-source commit b269ae0bd0]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update instruction tracking for powerpc
  (jsc#PED-9879).
  [kernel-source commit 278a31a891]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add more instructions for instruction tracking
  (jsc#PED-9879).
  [kernel-source commit 272ffea154]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add some of the arithmetic instructions to
  support instruction tracking in powerpc (jsc#PED-9879).
  [kernel-source commit a6a15cb7c0]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to identify memory instructions of
  opcode 31 in powerpc (jsc#PED-9879).
  [kernel-source commit 7871bdef8f]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add parse function for memory instructions in
  powerpc (jsc#PED-9879).
  [kernel-source commit e8a2994786]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update parameters for reg extract functions to
  use raw instruction on powerpc (jsc#PED-9879).
  [kernel-source commit 8de5429592]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to capture and parse raw instruction
  in powerpc using dso__data_read_offset utility (jsc#PED-9879).
  [kernel-source commit bcc731cdb9]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add disasm_line__parse() to parse raw instruction
  for powerpc (jsc#PED-9879).
  [kernel-source commit b088955725]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update TYPE_STATE_MAX_REGS to include max of
  regs in powerpc (jsc#PED-9879).
  [kernel-source commit 59ac334a8d]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add "update_insn_state" callback function to
  handle arch specific instruction tracking (jsc#PED-9879).
  [kernel-source commit 08b19f068e]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move the data structures related to register
  type to header file (jsc#PED-9879).
  [kernel-source commit 0c08dfc063]
* Sat Oct  5 2024 tonyj@suse.de
- perf daemon: Fix the build on more 32-bit architectures
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a51d61d9ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf python: include "util/sample.h"
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a42747caf1]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Fix spinlock and rwlock accounting
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit da1c71c2d9]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Set uninitialized PMU alias to null
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1bee504081]
* Sat Oct  5 2024 tonyj@suse.de
- perf daemon: Fix the build on 32-bit architectures
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3fd8596656]
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync uapi/sound/asound.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d63b66ebf9]
* Sat Oct  5 2024 tonyj@suse.de
- perf docs: Document cross compilation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 80f43bb357]
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Link lib 'zstd' for static build
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6e14c65335]
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Only link libebl.a for old libdw
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7cf8849672]
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Set Python configuration for cross compilation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a500364d18]
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Setup PKG_CONFIG_LIBDIR for cross compilation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit aac0143956]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Fix build when libunwind is enabled
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3cd638c298]
* Sat Oct  5 2024 tonyj@suse.de
- tools: Make pkg-config dependency checks usable by other tools
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ddcf80f4b3]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Warn if libtracefs is not found
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 35728a3a48]
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm: Add kvm-stat for loongarch64
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a22cf57614]
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm/riscv: Port perf kvm stat to RISC-V
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 66796e98d6]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Fix iteration of syscall ids in syscalltbl->entries
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9ccbc11e17]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Fix address sanitizer build
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eb45284ceb]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Warn if memory events are not supported on all CPUs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 82eaeedd39]
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe: Support multiple Arm SPE PMUs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3eddcac43c]
* Sat Oct  5 2024 tonyj@suse.de
- perf build x86: Fix SC2034 error in syscalltbl.sh
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d7577e3289]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Fix memset out-of-range error
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6c5415e802]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add --fuzzy-name option for fuzzy matching in
  task names (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c68043b6d1]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add support for multiple task names using CSV
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4a7392b218]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add task-name option to filter the output map
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3c3b975fb5]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Conditionally add feature check flags for
  libtrace{event,fs} (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff190dddce]
* Sat Oct  5 2024 tonyj@suse.de
- perf install: Don't propagate subdir to Documentation submake
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eeaa2ef123]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64:: Add i.MX95 DDR Performance Monitor
  metrics (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 11c8320fdc]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64:: Add i.MX93 DDR Performance Monitor
  metrics (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ed2974f155]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: When adding a dso into sorted dsos maintain the
  sort order (perf-sp7-v6.11-userspace-update).
  [kernel-source commit debeae8dc2]
* Sat Oct  5 2024 tonyj@suse.de
- perf comm str: Avoid sort during insert
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f4de814a36]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Calling available function for stats printing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit df06434352]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched replay: Fix -r/--repeat command line option for
  infinity (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 867e9cab87]
* Sat Oct  5 2024 tonyj@suse.de
- perf: pmus: Remove unneeded semicolon
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 64ede66753]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Use field separator in the metric header
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ab1a48b8a2]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Fix a segfault with --per-cluster --metric-only
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4c83a0e7a1]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Don't de-duplicate core PMUs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 03302465b7]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Restore full PMU name wildcard support
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6e69aa9ba4]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Display pregress bar on redirected pipe data
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4f04df7efe]
* Sat Oct  5 2024 tonyj@suse.de
- perf test stat_bpf_counter.sh: Stabilize the test results
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 19ea9a1e54]
* Sat Oct  5 2024 tonyj@suse.de
- perf python: Clean up build dependencies
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff424152e9]
* Sat Oct  5 2024 tonyj@suse.de
- perf python: Switch module to linking libraries from building
  source (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9a720ce3e9]
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Make util its own library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3c9194c877]
* Sat Oct  5 2024 tonyj@suse.de
- perf bench: Make bench its own library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1e6fd2edef]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Make tests its own library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 84c48d748c]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu-events: Make pmu-events a library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 74f11462b7]
* Sat Oct  5 2024 tonyj@suse.de
- perf ui: Make ui its own library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 25b57fc99f]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add '*.a' to clean targets
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1e8a5622f7]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Fix a segfault with NULL event->name
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dc0b170913]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix a compiler warning of NULL pointer
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9b15e08713]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol: Simplify kernel module checking
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6360752125]
* Sat Oct  5 2024 tonyj@suse.de
- perf unwind-libunwind: Add malloc() failure handling
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 005c72ca52]
* Sat Oct  5 2024 tonyj@suse.de
- util: constant -1 with expression of type char
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 982ec897bb]
* Sat Oct  5 2024 tonyj@suse.de
- perf: Timehist account sch delay for scheduled out running
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bb15663e65]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add APX and other new instructions to x86
  instruction decoder test (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2cf09384e0]
* Sat Oct  5 2024 tonyj@suse.de
- perf intel pt: Add new JMPABS instruction to the Intel PT
  instruction decoder (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 03c2e3257f]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Check output of the probe ... --funcs command
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1fc9efff1b]
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Fix parallel-perf python script to replace new
  python syntax ":=" usage (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b54e8fbc1d]
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Use is_perf_pid_map_name helper
  function to check dso's of pattern /tmp/perf-%%d.map
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 05cb321469]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Ensure libtraceevent and libtracefs versions have
  3 components (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 91ce9c8b15]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Use pkg-config for feature check for
  libtrace{event,fs} (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d5a28a39d3]
* Sat Oct  5 2024 tonyj@suse.de
- perf arm: Workaround ARM PMUs cpu maps having offline cpus
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ce9ed771c0]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereex counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 609f2428d8]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereep-sp counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e0762c6927]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereep-dp counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6184605707]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update tigerlake events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 30ff9f650d]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add snowridgex counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c5728e012f]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update skylakex events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7d2153d76b]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update skylake events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 26f6d4b7d6]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add silvermont counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ee9df2d5a6]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update sierraforest events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit df6374dce7]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update sapphirerapids events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d3a8c6b83b]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update sandybridge metrics add event
  counter information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 97860cffec]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update rocketlake events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e0fe1a1497]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add nehalemex counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 11cfc52212]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add nehalemep counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9486f144ad]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update meteorlake events and add counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 563868385f]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add lunarlake counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 47e25711ff]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add knightslanding counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 106648c4a3]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update jaketown metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 87d6e75572]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update ivytown metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0ce21cd0b4]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update ivybridge metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 945185bdec]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update icelakex events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 293e22ddcd]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update icelake events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 23049d3568]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update haswellx metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 279b041a48]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add haswell counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7566f68fcc]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update graniterapids events and add counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1bcf6d557a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update/add grandridge events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8e0d675bca]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add goldmontplus counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit deaa285be2]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add goldmont counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a4306f4f7b]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update emeraldrapids events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5c817f554c]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update elkhartlake events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 884932ba4a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update cascadelakex events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d54532fb88]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwellx metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 984d85f264]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwellde metrics add event
  counter information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6aca814883]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwell metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1b354c4787]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add bonnell counter information
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 36b44e0370]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update alderlaken events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4556e6f2f5]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update alderlake events/metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 405f65223e]
* Sat Oct  5 2024 tonyj@suse.de
- perf doc: Add AMD IBS usage document
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 661058f523]
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Handle perftool-testsuite_probe
  testcases fail when kernel debuginfo is not present
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2a27729da6]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Honor symbol_conf.skip_empty
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fd579b2b1f]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Add symbol_conf.skip_empty
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a4f05e5f15]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Simplify __hpp_fmt() using hpp_fmt_data
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a603d8dd37]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Factor out __hpp__fmt_print()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit db61d4f248]
* Sat Oct  5 2024 tonyj@suse.de
- perf: sched map skips redundant lines with cpu filters
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f0221f3329]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Warn don't fail for legacy mixed case event names
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 19306d7fa2]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Ensure space for lost samples
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b107d3d12d]
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Refactor tool events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0182d6f2e9]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Speed up test case 70 annotate basic tests
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d802399f11]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Choose the most disaggregate command line option
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 67fd3d0f5f]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Make options local (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 83f265a469]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add/use a sorted insert for fixup overlap and insert
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c02e56b58e]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce sorting for overlapping mappings
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bc684c7117]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Fix use after free in
  __maps__fixup_overlap_and_insert
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e3d70554c3]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: netdev-times: add location parameter to consume_skb
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 57c0c14ead]
* Sat Oct  5 2024 tonyj@suse.de
- perf: parse-events: Fix compilation error while defining
  DEBUG_PARSER (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7b52e9fa43]
* Sat Oct  5 2024 tonyj@suse.de
- perf hisi-ptt: remove unused struct 'hisi_ptt_queue'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 728d804d2c]
* Sat Oct  5 2024 tonyj@suse.de
- perf genelf: remove unused struct 'options'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d5791f64ca]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock info: Display both map and thread by default
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8320927f7f]
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Allow filters on events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b473bc785a]
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf filter: Add uid and gid terms
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0b3af20d7f]
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf filter: Give terms their own enum
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 702addc4b8]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Always show mmap prot even though PROT_NONE
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5becc3cbbe]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Always show param if show_zero is set
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ac851a8eab]
* Sat Oct  5 2024 tonyj@suse.de
- perf docs: Fix typos (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 66991e8715]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Fix the --no-desc option
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3092c779b4]
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe: Unaligned pointer work around
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ab9562aab9]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add some pmu core functionality tests
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit af6100edc0]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmus: Sort/merge/aggregate PMUs like mrvl_ddr_pmu
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5eccd4b962]
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Fix handling of minimal vmlinux.h file when
  interrupting the build (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 23cd469a8a]
* Sat Oct  5 2024 tonyj@suse.de
- Revert "perf record: Reduce memory for
  recording PERF_RECORD_LOST_SAMPLES event"
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1bd9321b6b]
* Sat Oct  5 2024 tonyj@suse.de
- Revert "perf parse-events: Prefer sysfs/JSON hardware events
  over legacy" (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 11b570b6a3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Ensure the number of type histograms
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7c02ee96fc]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix segfault on sample histogram
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f2f6a15571]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock: Avoid memory leaks from strdup()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c2043000ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Rename 'switches' column header to
  'count' and add usage description, options for latency
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 44bf0a0baf]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Ignore deleted cgroups
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 87b1df4ae7]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse: Allow tracepoint names to start with digits
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0372854607]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Add new 'fake_tp' parameter for tests
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0e84163b68]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: pass parse_state to add_tracepoint
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 78670af9af]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Update kcore map before merging in remaining
  symbols (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 305257e671]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Re-use __maps__free_maps_by_name()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 237e581c02]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Remove map from list before updating addresses
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 232bd4dd94]
* Sat Oct  5 2024 tonyj@suse.de
- perf tracepoint: Don't scan all tracepoints to test if one
  exists (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d3ce571feb]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Fix build with HAVE_DWARF_CFI_SUPPORT
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4d6d72dd9d]
* Sat Oct  5 2024 tonyj@suse.de
- perf comm: Fix comm_str__put() for reference count checking
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 272fe59d20]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Print array type name with ""
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dcd9b220c6]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Avoid 'struct hist_entry_iter' mem_info memory leak
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8d9334a368]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem-info: Add reference count checking
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c54a516854]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem-info: Move mem-info out of mem-events and symbol
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7c56c6d02e]
* Sat Oct  5 2024 tonyj@suse.de
- perf comm: Add reference count checking to 'struct comm_str'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f2b6a1bdef]
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Remove refcnt from 'struct cpu_aggr_map'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 653df4f698]
* Sat Oct  5 2024 tonyj@suse.de
- perf block-info: Remove unused refcount
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7d90765090]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix memory leak in annotated_source
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dd8398f01d]
* Sat Oct  5 2024 tonyj@suse.de
- perf probe: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2551e03e95]
* Sat Oct  5 2024 tonyj@suse.de
- perf auxtrace: Allow number of queues to be specified
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a1c1f23a7c]
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Print error for new PERF_RECORD_AUX_OUTPUT_HW_ID
  versions (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e5fed3d2b5]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix a comment about multi_regs in
  extract_reg_offset function (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bcc1cbd516]
* Sat Oct  5 2024 tonyj@suse.de
- perf kwork: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
  [kernel-source commit db5c021a37]
* Sat Oct  5 2024 tonyj@suse.de
- perf callchain: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 07870b454e]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e470772242]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Use container_of() to avoid a pointer in 'struct
  dso_data' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8ffb0c5457]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol-elf: dso__load_sym_internal() reference count fixes
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 22b0ac3a9d]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol-elf: Ensure dso__put()
  in machine__process_ksymbol_register()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 366d061769]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Add missing dso__put() in map__new()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a85563493b]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Add reference count checking and accessor functions
  (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/tools-perf-Fix-the-string-match-for-tmp-perf-PID.map-files-in-dso__load.patch.
  Relevant changes:
- Add patch: patches.suse/perf-dso-Add-reference-count-checking-and-accessor-functions.patch
  perf dso: Add reference count checking and accessor functions
  (perf-sp7-v6.11-userspace-update)
- Refresh patch: patches.suse/tools-perf-Fix-the-string-match-for-tmp-perf-PID.map-files-in-dso__load.patch
  tools/perf: Fix the string match for "/tmp/perf-$PID.map" files in
  (git-fixes, perf-sp7-v6.11-userspace-update)
  [kernel-source commit 61f87f1f34]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch hand crafted code to bsearch()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b72e7dccbc]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Remove __dsos__findnew_link_by_longname_id()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 214e52888a]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Remove __dsos__addnew()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ffd888114b]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch backing storage to array from rbtree/list
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 23884e7c3c]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 mapping
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4a9347c791]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 metrics
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c8b3a826ff]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 uncore events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eda5a8ae81]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 core events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dafc9094f7]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Disable syscall augmentation with record
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 79f3f27d47]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Test all sysfs PMU event names are the same case
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 691d5a4321]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Add an eagerly loaded event test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 62c95bf5ef]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Refactor format test and exposed test APIs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5d27a82992]
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu-events: Make it clearer that pmu-events tests
  JSON events (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e5bc240482]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Remove check_invariants() from maps__lock()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1dc779375e]
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Improve version detection and error reporting
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7cade0a660]
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Remove repeated fetches of the ETM PMU
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 273d30d7bc]
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Use struct perf_cpu as much as possible
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d62688c3bb]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check kind of stack variables
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ee6c6fdc6a]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle multi regs in find_data_type_block()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1d4b346b8e]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check memory access with two registers
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 83b67d5603]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle direct global variable access
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 540729df5a]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Collect global variables in advance
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f6fb97cbfb]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_collect_global_vars()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b02f57a1ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Reintroduce -p/--parallel and make -S/--sequential
  the default (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 63c6ac1ad1]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix data type profiling on stdio
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 619a8baf13]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Pretend scandirat is missing with msan
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d717574a55]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Fix comment misspellings
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff8b62ed6a]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update DSO binary type when trying build-id
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0ef34ca749]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fallback disassemble to objdump when capstone
  fails (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c48f784d9b]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check if 'struct
  annotation_source' was allocated on 'perf report' TUI
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4a3788168b]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add a new test for 'perf annotate'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 34b00a6645]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Tidy the setting of the default event name
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b56a7ac336]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Minor grouping tidy up
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 851001cfb0]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-event: Constify event_symbol arrays
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dc4e5e2785]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improvements to modifier parsing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 51767a6e35]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Inline parse_events_evlist_error
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a13e09cedc]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improve error message for bad numbers
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e4e2279c97]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Inline parse_events_update_lists
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit aa00f1b2c6]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Prefer sysfs/JSON hardware events over legacy
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a34cac8cbc]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Constify parse_events_add_numeric
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5658557eda]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Handle PE_TERM_HW in name_or_raw
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3b70649096]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Legacy cache names on all PMUs and lower
  priority (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 71609036af]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests parse-events: Use "branches" rather than
  "cache-references" (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0eadf074d9]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Refactor perf_pmu__match()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ea94239e2d]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Avoid copying an empty list
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 044704c87b]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Directly pass PMU to parse_events_add_pmu()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 675b5dc3ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Factor out '<event_or_pmu>/.../' parsing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ce7e49bdd0]
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python: Add a script to run instances of 'perf
  script' in parallel (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1e75c2cfc3]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests shell kprobes: Add missing description as used by
  'perf test' output (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7fb9a3af8e]
* Sat Oct  5 2024 tonyj@suse.de
- Revert "tools headers: Remove almost unused copy of uapi/stat.h,
  add few conditional defines" (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5df09e04c6]
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Better error message for a too-long probe name
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 15f35f81a5]
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Un-hardcode sizeof(buf)
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e9f19a0d17]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Add new field in stat_config to enable hardware
  aware grouping (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 382ce78e32]
* Sat Oct  5 2024 tonyj@suse.de
- perf genelf: Fix compiling with libelf on rv32
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 769afc93f2]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64: AmpereOne/AmpereOneX:
  Mark L1D_CACHE_INVAL impacted by errata
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7c9eb2c723]
* Sat Oct  5 2024 tonyj@suse.de
- perf test bpf-counters: Add test for BPF event modifier
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b4a614962d]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Enable configs required
  for test_uprobe_from_different_cu.sh
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5ca5e0e8ee]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add weight output fields
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a9f2f76a91]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Add weight fields to hist entry stats
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 01ab25fae7]
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Move histogram related code to hist.h
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3a8a56a1e8]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle RSP if it's not the FB register
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c603bfc459]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check variable address range properly
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 46be0f9df3]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check pointer offset when checking variables
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cffc424306]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Improve debug message with location info
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 00be595824]
* Sat Oct  5 2024 tonyj@suse.de
- perf bench uprobe: Add uretprobe variant of uprobe benchmarks
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8f28691428]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Add shellcheck to scripts
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 03b3db474c]
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add shellcheck to generate-cmdlist.sh
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ce4e03c461]
* Sat Oct  5 2024 tonyj@suse.de
- perf arch x86: Add shellcheck to build
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8f7bb7772c]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add shellcheck to tools/perf scripts
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9e204b439d]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Escape '\r' in JSON output
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c376983855]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch more loops to dsos__for_each_dso()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7a8b3fa836]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Move dso functions out of dsos.c
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e3097ee285]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Introduce dsos__for_each_dso()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 44d27e64a8]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Tidy reference counting and locking
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 48e010671d]
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Attempt to better abstract DSOs internals
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 244ebc29cc]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Skip DSOs not found
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3e49aea2bf]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Do not collect sample histogram unnecessarily
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit abf7b36db1]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add a menu item to annotate data type in TUI
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1918c5682f]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support event group display in TUI
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8a74edcd81]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add hist_entry__annotate_data_tui()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e5c6257177]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add hist_entry__annotate_data_tty()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6862d775e8]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Show progress of sample processing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2fa7daf461]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Skip sample histogram for stack canary
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bf2902432a]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Remove dependency on lscpu
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6aa63b5564]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Remove kernel map before updating start and end
  addresses (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 98cc3ae5e8]
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Remove the "No_group" metric group
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4a0947b1b9]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of symbol__ensure_annotate()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9be43612fa]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Do not delete non-asm lines
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1baf51eef4]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Fix global variable lookup
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 78740b90ad]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'start' field struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 40dd8bb681]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move nr_events struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b2cbb76c16]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'max_jump_sources' struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e983ebd65b]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'widths' struct to 'struct annotated_source'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 484751eeb3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of offsets array
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 57e8638575]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Check annotation lines more efficiently
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6ef2bb25b3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Introduce annotated_source__get_line()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4c97e484e7]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Staticize some local functions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b4fe45fef4]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Consolidate capstone print functions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 094057e68a]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Add capstone support for '-F +brstackdisasm'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2c9d060ebe]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Support 32bit code under 64bit OS with capstone
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9205354ea5]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Fix PAI counter names for s390 virtual machines
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c209e22bb0]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Initialize 'arch' variable not to trip some
  - Werror=maybe-uninitialized (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 711491f453]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add LIBTRACEEVENT_DIR build option
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 87c8576802]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Fix AT_EACCESS undeclared build error
  for system with kernel versions lower than v5.8
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 061fd89c0d]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add symbol name when using capstone
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 95a3f42f31]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use libcapstone to disassemble
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8ecfca745c]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Split out util/disasm.c
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 94347c0b52]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add and use ins__is_nop()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ae4164e154]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use ins__is_xxx() if possible
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6ad9998067]
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Use evsel__name_is() helper
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5cc364439d]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Honor output options with --data-type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fb0dd696d3]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/vhost.h copy out of the directory
  used to build perf (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a703288e32]
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Reorder members to save space in 'struct dso'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e9bfe3efc6]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Trim backtrace by skipping traceiter
  functions (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7ac1e9120c]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Remove info metrics erroneously in
  TopdownL1 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d76274fa2f]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update snowridgex to 1.22
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b653d978cf]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake to v58
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f5d8fd25db]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylakex to 1.33
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0b3b25d173]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sierraforest to 1.02
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cca8d2fbe2]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids to 1.20
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 163b8a84b3]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake to 1.08
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7159aa3474]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update lunarlake to 1.01
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7a17215d40]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex to 1.24
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b4bfce3032]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update grandridge to 1.02
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 18f03e3d7a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids to 1.06
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b933768c3a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex to 1.21
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 222df871c4]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Fix 'newfstatat'/'fstatat' argument pretty printing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9e3a1db389]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Beautify the 'flags' arg of unlinkat
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4b40a9798c]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce faccessat2 flags scnprintf routine
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 03fa46e316]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for the 'statx' syscall
  'mask' argument (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eaf8c60ee0]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for various fs syscalls
  'flags' arguments (perf-sp7-v6.11-userspace-update).
  [kernel-source commit adb9236656]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Run tests in parallel by default
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8e4cc80c5d]
* Sat Oct  5 2024 tonyj@suse.de
- perf help: Lower levenshtein penality for deleting character
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e59e5e376e]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Suggest inbuilt commands for unknown command
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9d9542bfd9]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Read child test 10 times a second rather than 1
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2222a9c8fe]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use a single fd for the child process out/err
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2b846973d9]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Stat output per thread of just the parent process
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7c4d9a0319]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Give more details about raw event encodings
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c34690fa2f]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Allow wordwrap to wrap on commas
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bace88fdf6]
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Drop "default_core" from alias names
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 71df427749]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add tracepoint encoding to detailed output
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 232ef81b41]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for 'clone' syscall
  'flags' argument (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 63ff8c5322]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Do not retry for invalid types
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 504d627654]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add a cache for global variable types
  (perf-sp7-v6.11-userspace-update).
- Update
  patches.suse/tools-perf-Fix-the-string-match-for-tmp-perf-PID.map-files-in-dso__load.patch
  (git-fixes, perf-sp7-v6.11-userspace-update).
  [kernel-source commit c0d968a3a3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add stack canary type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 50a288632a]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle ADD instructions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 964225e246]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support general per-cpu access
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fa8fd73247]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Track instructions with a this-cpu variable
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fb911536ce]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle this-cpu variables in kernel
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 376a0233fb]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Parse x86 segment register location
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9d7721b303]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check register state for type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ef9101883d]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Implement instruction tracking
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a67a85b961]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle call instructions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 18e0393186]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle global variable access
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 63e3420627]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add get_global_var_type()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b926e01da3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add update_insn_state()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8c059a0023]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Maintain variable type info
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 983f4db7c3]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add debug messages
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 55581a1187]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add annotate_get_basic_blocks()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7f41ee06bd]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Introduce 'struct data_loc_info'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 44bf56359c]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Add map__objdump_2rip()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 275e02aae0]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_func_rettype()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e664e726b5]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Handle type transfer for memory access
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c2eaa2950f]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_collect_vars()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 26fe07ca08]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Remove unused pc argument
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3b7e9f9021]
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Use perf_cpu_map__for_each_cpu when possible
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 82776bd3eb]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Remove duplicate cpus_map_matched function
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5f6922e93c]
* Sat Oct  5 2024 tonyj@suse.de
- perf arm64 header: Remove unnecessary CPU map get and put
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 467cabfd0c]
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Clean up use of
  perf_cpu_map__has_any_cpu_or_is_empty
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a7b448a02c]
* Sat Oct  5 2024 tonyj@suse.de
- perf intel-pt/intel-bts: Switch
  perf_cpu_map__has_any_cpu_or_is_empty use
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2f5d615e11]
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe/cs-etm: Directly iterate CPU maps
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d027c97ba7]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Ensure empty cpumap is NULL from alloc
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c56a36f895]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Add any, empty and min helpers
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f1695b2fb9]
* Sat Oct  5 2024 tonyj@suse.de
- perf docs arm_spe: Clarify more SPE requirements related to KPTI
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bab2d8034a]
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Remove almost unused copy of uapi/stat.h,
  add few conditional defines (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 793895a4b1]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Use the system linux/fcntl.h instead of a copy
  from the kernel (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2741aa13be]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Stop using the copy of uapi/linux/prctl.h
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 49805b28d6]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/usbdevice_fs.h copy out of the
  directory used to build perf (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 179e5988cc]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Don't include uapi/linux/mount.h, use sys/mount.h
  instead (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 68a2010d46]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Fix dependency of tables using uapi/linux/mount.h
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 831e34de2a]
* Sat Oct  5 2024 tonyj@suse.de
- perf c2c: Fix a punctuation (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 03c2a293fd]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Collect sys_nanosleep first argument
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 81684d0953]
* Sat Oct  5 2024 tonyj@suse.de
- bitops: make BYTES_TO_BITS() treewide-available
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f9980d74cb]
* Sat Oct  5 2024 tonyj@suse.de
- perf riscv: Fix the warning due to the incompatible type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e8c236f1fb]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Make sure to call symbol__annotate2() in TUI
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a4494ef505]
* Sat Oct  5 2024 tonyj@suse.de
- riscv: andes: Support specifying symbolic firmware and hardware
  raw events (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c4c7f30022]
* Sat Oct  5 2024 tonyj@suse.de
- net: remove {revc,send}msg_copy_msghdr() from exports
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fe3409e64b]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add comments in the data structures
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9f18c0ce17]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Remove sym_hist.addr array
  (perf-sp7-v6.11-userspace-update).
- Delete
  patches.suse/perf-local-check-alloc-histogram-return.patch.
  Relevant changes:
- Add patch: patches.suse/perf-annotate-Remove-sym_hist.addr-array.patch
  perf annotate: Remove sym_hist.addr[] array
  (perf-sp7-v6.11-userspace-update)
- Delete patch: patches.suse/perf-local-check-alloc-histogram-return.patch
  Detect memory allocation failure in  annotated_source__alloc_histograms
  (bsc#1227962)
  [kernel-source commit 11612fca8f]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Calculate instruction overhead using hashmap
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d8c722bc39]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add a hashmap for symbol histogram
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ef6a95d357]
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Reduce table size from 256 to 8
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8b600e38dc]
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Switch from rbtree to hashmap
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 63a42536f7]
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Move threads to its own files
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 211d6c7007]
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Move machine's threads into its own abstraction
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c489a22a7d]
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Move fprintf to for_each loop and a callback
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 684d19396a]
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Ignore thread hashing in summary
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 492fd60375]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Sort child tasks by tid
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ddd87ab7bb]
* Sat Oct  5 2024 tonyj@suse.de
- perf version: Display availability of OpenCSD support
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 72f37bbaf5]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Add umasks/occ_sel to PCU events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 111c5379e4]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Fix map reference count issues
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a46954a219]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Account contending locks too
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cb08f1756d]
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Fix segv for metrics with no events
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 35a19ad871]
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Fix metric matching
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f14340baab]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Fix spelling mistake "curent" -> "current"
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 628174f604]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use TEST_FAIL in the TEST_ASSERT macros instead of -1
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f97111881c]
* Sat Oct  5 2024 tonyj@suse.de
- perf data convert: Fix segfault when converting to json when
  cpu_desc isn't set (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0ffb75b583]
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Check that the minimal vmlinux.h installed is the
  latest one (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fd952d3e07]
* Sat Oct  5 2024 tonyj@suse.de
- treewide: remove meaningless assignments in Makefiles
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 02c0002149]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add option to run tests in parallel
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2535f0acac]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Run time generate shell test suites
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f37444d70f]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Use scandirat for shell script finding
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9826aa3b51]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Rename builtin-test-list and add missed header guard
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 159f3a9f3e]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Avoid fork in perf_has_symbol test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9a9eca5bf6]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add scandirat compatibility function
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e052f90a38]
* Sat Oct  5 2024 tonyj@suse.de
- perf thread_map: Skip exited threads when scanning /proc
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8b8e7325a3]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Fix metric-only aggregation index
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7ff16769e4]
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Compute unmerged uncore metrics individually
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5e1d8d8eeb]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Pass fewer metric arguments
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e343df506f]
* Sat Oct  5 2024 tonyj@suse.de
- perf: script: prefer capstone to XED
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cb74f1f324]
* Sat Oct  5 2024 tonyj@suse.de
- perf: script: add field 'disasm' to display mnemonic
  instructions (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9708c42472]
* Sat Oct  5 2024 tonyj@suse.de
- perf: util: use capstone disasm engine to show assembly
  instructions (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f6fef58c90]
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: introduce the libcapstone
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3f89b75b29]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: For metricgroup only list include description
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1754e78bf6]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fixup module symbol end address properly
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4150205ff0]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0b4ffc2dc7]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylakex TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 21a6bad844]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit da9c412799]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids TMA metrics
  to 4.7 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5673ea8bfe]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sandybridge TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0787b2124c]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update rocketlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit edeac0ee3f]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update jaketown TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 350eab449a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update ivytown TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 878f4184eb]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update ivybridge TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c2f01e72cb]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 52468a94a5]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2fe55ea974]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswellx TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7352ed37db]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswell TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1f3571188d]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex TMA metrics to
  4.7 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 95a8a8863f]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwellx TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3e1de0b483]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwellde TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fca758330b]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwell TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f20a7bf698]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8edecceca0]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake events to v1.15
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0950f5c600]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake events to v58
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit aff81bfdff]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sierraforst events to v1.01
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b30edacf1d]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update rocketlake events to v1.02
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 69c384366e]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake events to v1.07
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 22ad470b6e]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelake events to v1.21
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f99e7b6f1b]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswell events to v35
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9b5e7339a1]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update grandridge events to v1.01
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit afe6552bed]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids events to v1.03
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f11d0d93f8]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwell events to v29
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1e2960ea84]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlaken events to v1.24
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 256a040617]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake events to v1.24
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit de98637dcd]
* Sat Oct  5 2024 tonyj@suse.de
- perf augmented_raw_syscalls.bpf: Move 'struct timespec64'
  to vmlinux.h (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6be69b4458]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Install kprobe tests and common files
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8cb54e9d9c]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add test for kprobe handling
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9dcb054422]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common output checking helpers
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2077996cfb]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add test case for perf probe
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3717bc381c]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add initialization script for shell tests
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b13d44f334]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common setting for shell tests
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 45f63ec80a]
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common regex patters
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2f0aa296c8]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Enable Symbols test to work with a current module
  dso (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e4b5174fe3]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Cleanup perf register configuration
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f1cc88cd72]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-regs: Introduce a weak function
  arch__sample_reg_masks() (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9249cea1d6]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-regs: Always build perf register functions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9f36f40841]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Remove unused CONFIG_PERF_REGS
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bcc47bb79f]
* Sat Oct  5 2024 tonyj@suse.de
- perf expr: Allow NaN to be a valid number
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d1620301c7]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Locking tidy up of nr_maps
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5149292e13]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Hide maps internals
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3725249627]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find_next_entry
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 40e0ea59d2]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find_by_name
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 86680cbc33]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fb8183e97d]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Switch from rbtree to lazily sorted array for
  addresses (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 59df4a2143]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Support per-cluster aggregation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 665ad21daa]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Remove misleading comments on map functions
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8b7789253f]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move curr_pid and cpu_last_switched
  initialization to perf_sched__{lat|map|replay}()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1cba676ba3]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move curr_thread initialization to perf_sched__map()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 44ec584e75]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Fix memory leak in perf_sched__map()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c905a84621]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move start_work_mutex and work_done_wait_mutex
  initialization to perf_sched__replay()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ef6a20a3b2]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Skip metric w/o event name on arm64 in stat STD
  output linter (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a890916296]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Slightly improve module file executable section
  mappings (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 36dc7838fc]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Make it possible to see perf's kernel and module
  memory mappings (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 060e8f29aa]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Display data size on pipe mode
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 06742b1ec3]
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Print source line for each jump in brstackinsn
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 78d2b2aa68]
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm powerpc: Fix build (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a72f9c5d0a]
* Sat Oct  5 2024 tonyj@suse.de
- tools: perf: Expose sample ID / stream ID to python scripts
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0ddb218c3d]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Print all errors
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 64e2b3a880]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improve error location of terms cloned from
  an event (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e8d55d5834]
* Sat Oct  5 2024 tonyj@suse.de
- perf tsc: Add missing newlines to debug statements
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 36c0cde774]
* Sat Oct  5 2024 tonyj@suse.de
- perf Documentation: Add some more hints to tips.txt
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e51a7e4986]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Simplify metric value validation test final report
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0a52c8e043]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Prevent segfault with --no-parent
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ddcf901f2e]
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Rename get_states() to parse_task_states() and
  make it public (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c3737a831e]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add -H short option for --hierarchy
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 023e19b2fa]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Skip test_arm_callgraph_fp.sh if unwinding isn't
  built in (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 73103510f8]
* Sat Oct  5 2024 tonyj@suse.de
- perf version: Display availability of HAVE_DWARF_UNWIND_SUPPORT
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 87bb34fdc1]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_pmus__num_mem_pmus()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9cff7c9883]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__record_args()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fa98574e07]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up is_mem_loads_aux_event()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f614a0e2be]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_event__supported()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0b01d6ce43]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__name()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cf8ec42501]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__ptr()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6e782b26ed]
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Add mem_events into the supported perf_pmu
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 66dc45f98a]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Commit to evsel__taskstate() to parse task state
  info (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7ec66bf8de]
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add evsel__taskstate() to parse the task state info
  instead (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c7669a517e]
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add helpers to parse task state string from
  libtraceevent (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 18e4870337]
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Sync state char array with the kernel
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ba59deb57e]
* Sat Oct  5 2024 tonyj@suse.de
- perf data: Minor code style alignment cleanup
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit adcbdd75b4]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check allowed DWARF Ops
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fc3427a86b]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support stack variables
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5accf4e0aa]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_get_cfa()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3ab0bed973]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support global variables
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 3a537d9953]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle PC-relative addressing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 553327a6cc]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add stack operation pseudo type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9b2d0cc7c9]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle array style accesses
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 462e787976]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle macro fusion on x86
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 280cc98277]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Parse 'lock' prefix from llvm-objdump
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0960119968]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Check whether pkg-config is installed when
  libtraceevent is linked (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 31561238f5]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: raise limit to 20 percent for
  perf_stat_--bpf-counters_test (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 29fd3a5605]
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Update the copy of x86's mem{cpy,set}_64.S used
  in 'perf bench' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ee5f5790e9]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Alderlake/sapphirerapids metric fixes
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 25e65b720c]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix calloc() arguments to address error introduced
  in gcc-14 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 058afa7e1e]
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Remove needless malloc(0) call that triggers
  - Walloc-size (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 622f845e9c]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Make minimal shellcheck version to v0.6.0
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ccdb5ce0bc]
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell daemon: Make signal test less racy
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d303878064]
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell script: Fix test for python being disabled
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e3b8bcac8e]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Workaround debug output in list test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 38c4765623]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add output file option
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 70474c0599]
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Switch error message to pr_err() to respect debug
  settings (-v) (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f05a5396c1]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Fix 'perf script' tests on s390
  (perf-sp7-v6.11-userspace-update).
- blacklist.conf:
  [kernel-source commit 91dc4653b4]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: test case 'Setup struct perf_event_attr' fails on
  s390 on z/vm (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4e00d3ba4d]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add perf script test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 07d5177e93]
* Sat Oct  5 2024 tonyj@suse.de
- perf TUI: Don't ignore job control
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8bb949689d]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids events to v1.17
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 734fd42217]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex events to v1.23
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0b1d9dc368]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids events to v1.02
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 903548a2ed]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Alderlake/rocketlake metric fixes
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 856f482652]
* Sat Oct  5 2024 tonyj@suse.de
- perf x86 test: Add hybrid test for conflicting legacy/sysfs
  event (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bffa8360fa]
* Sat Oct  5 2024 tonyj@suse.de
- perf x86 test: Update hybrid expectations
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d4b57ccc47]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Reduce memory for
  recording PERF_RECORD_LOST_SAMPLES event
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f7bbafce30]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --insn-stat option for debugging
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8b81c8e662]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --type-stat option for debugging
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f3b94d3a9e]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Support event group display
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5cef258e33]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --data-type option
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7faf677b13]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'symoff' sort key
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 151f4c9830]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'typeoff' sort key
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ce2b031f67]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Update sample histogram for type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4a7b0a3327]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add member field in the data type
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6295d477a2]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Support data type profiling
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit aabd6de83d]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'type' sort key
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f4940fabee]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Implement hist_entry__get_data_type()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 893e05e88f]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add annotate_get_insn_location()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dc9cf85f0c]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Factor out evsel__get_arch()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5d3c3fd10f]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add dso->data_types tree
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 37c8265fd1]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add find_data_type() to get type from
  memory access (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 607468a666]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-regs: Add get_dwarf_regnum()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c568d4dae0]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Factor out die_get_typename_from_type()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f6a7d36813]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Fix up overlaps during fixup_end
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 460ed22ce8]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce scope of map_rb_node and maps internals
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 29fc0e25e9]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add find next entry to give entry after the given
  map (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0f052c32ef]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add maps__load_first()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1e039fd19a]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Rename clone to copy from
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6af11b8fa7]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Do simple merge if given map doesn't overlap
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 68e9332536]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Refactor maps__fixup_overlappings()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 135855af95]
* Sat Oct  5 2024 tonyj@suse.de
- perf debug: Expose debug file (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a8dc391e61]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add remove maps function to remove a map based on
  callback (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff35550d77]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce scope of maps__for_each_entry()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff2d05b93a]
* Sat Oct  5 2024 tonyj@suse.de
- perf vdso: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7919686ad6]
* Sat Oct  5 2024 tonyj@suse.de
- perf unwind: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d482564890]
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python arm-cs-trace-disasm.py: Do not ignore
  disam first sample (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e876d6c574]
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python arm-cs-trace-disasm.py: Set start vm addr
  of exectable file to 0 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d79ace71ee]
* Sat Oct  5 2024 tonyj@suse.de
- perf archive: Add new option '--unpack' to expand tarballs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7d0055a534]
* Sat Oct  5 2024 tonyj@suse.de
- perf archive: Add new option '--all' to pack perf.data with DSOs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c6271108f2]
* Sat Oct  5 2024 tonyj@suse.de
- perf thread: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 01906c93ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf synthetic-events: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4199317476]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bf8ab2bf2c]
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b52684e9f2]
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit f258b94779]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 20b6ec86c1]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit fd2b28bbd0]
* Sat Oct  5 2024 tonyj@suse.de
- perf events x86: Use function to add missing lock
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4ac9811d1a]
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add maps__for_each_map to iterate maps holding the
  lock (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 9655c32b38]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Improve map/unmap parameter names
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b8fbc9be0c]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Document perf_cpu_map__nr()'s behavior
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 840c138daa]
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Avoid repeated function calls to perf_cpu_map__nr()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5c5dd2280d]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Make DSO tests a suite rather than individual
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e343f078f6]
* Sat Oct  5 2024 tonyj@suse.de
- perf evlist: Move event attributes to after
  the / when uniquefying using the PMU name
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1471580bd3]
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Combine the -A/--no-aggr and --no-merge options
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b8c4dab24f]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Add for_each_cpu() that skips the "any CPU"
  case (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 587e9b4b80]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Replace usage of perf_cpu_map__new(NULL)
  with perf_cpu_map__new_online_cpus()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6b20ab8a56]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__empty()
  to perf_cpu_map__has_any_cpu_or_is_empty()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eff5ac4f94]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__default_new()
  to perf_cpu_map__new_online_cpus() and prefer sysfs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 76a3f215bf]
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__dummy_new() to
  perf_cpu_map__new_any_cpu() (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4e10ba1e8d]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of local annotation options
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit b1cdbeec88]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Remove remaining usages of local annotation
  options (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5360788f50]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Ensure init/exit for global options
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit e7644ebfc0]
* Sat Oct  5 2024 tonyj@suse.de
- perf ui/browser/annotate: Use global annotation_options
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c65d26868f]
* Sat Oct  5 2024 tonyj@suse.de
- perf thread: Add missing RC_CHK_EQUAL
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bdc1146526]
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Simplify map_ip/unmap_ip and make 'struct map'
  smaller (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1193720131]
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell diff: Skip test if test_loop symbol is missing
  in the perf binary (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 332ef6ec99]
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Parse NOTE segments until the build id is found
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4417654dcf]
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Be lazier in allocating lost samples buffer
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a2faaa06ea]
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Fallback to "task-clock" when not system wide
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2fbb999a2b]
* Sat Oct  5 2024 tonyj@suse.de
- perf bench sched-seccomp-notify: Fix spelling
  mistake "synchronious" -> "synchronous"
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 593a381ec0]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add basic 'perf diff' test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c71a35ec5f]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add basic 'perf list --json" test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 068026ddc3]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use common python setup library
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cb1e30937a]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Shellcheck support for OUTPUT directory
  (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/perf-bpf-Clean-up-the-generated-copied-vmlinux.h.patch.
  [kernel-source commit 86680ba434]
* Sat Oct  5 2024 tonyj@suse.de
- perf env: Cache the arch specific strerrno function in
  perf_env__arch_strerrno() (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ce9d845b3f]
* Sat Oct  5 2024 tonyj@suse.de
- perf env: Introduce perf_env__arch_strerrno()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 41f17c6f4c]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Don't use 'find ... -printf' as it isn't available
  in busybox (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cc9348fae2]
* Sat Oct  5 2024 tonyj@suse.de
- libperf: Lazily allocate/size mmap event copy
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 1acb17692c]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests sigtrap: Skip if running on a kernel with sleepable
  spinlocks (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 83a392105b]
* Sat Oct  5 2024 tonyj@suse.de
- perf test sigtrap: Generalize the BTF routine to reuse it in
  this test (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 5d81e68d8b]
* Sat Oct  5 2024 tonyj@suse.de
- perf mmap: Lazily initialize zstd streams to save memory when
  not using it (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 92e8a11b3a]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_variable_by_addr()
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8297a7d812]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add --debug-file option to redirect debug output
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a71674bd97]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Check if operand has multiple regs
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dbdb70c192]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use existing config value for objdump path
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c0aac775f4]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: add T-HEAD C9xx JSON file
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c4f60621d2]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add skx, clx, icx and spr upi bandwidth
  metric (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 07cfd8d826]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip branch stack sampling test if brstack_bench
  symbol is missing (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8fb3097f10]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip Arm64 callgraphs test if leafloop symbol is
  missing (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 51a1e2e055]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip record test if test_loop symbol is missing
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6959c5a1da]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Remove warning on missing raw data for s390
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 32c937ed35]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add perf binary dependent rule for shellcheck log
  in Makefile.perf (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/perf-bpf-Clean-up-the-generated-copied-vmlinux.h.patch.
  [kernel-source commit 62723f31dd]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: Add StarFive Dubhe-90 JSON file
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d6744ee6e7]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests coresight: Remove unused variables
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d0982eaeb6]
* Sat Oct  5 2024 tonyj@suse.de
- perf lock: if a strdup-ed string is NULL,the allocated memory
  needs freeing (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6a0c083948]
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Make legacy events lower priority than
  sysfs/JSON (perf-sp7-v6.11-userspace-update).
  [kernel-source commit eaa399c457]
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Enable itrace option 'T'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d13d558d12]
* Sat Oct  5 2024 tonyj@suse.de
- perf auxtrace: Add 'T' itrace option for timestamp trace
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 4589e78b55]
* Sat Oct  5 2024 tonyj@suse.de
- perf script perl: Fail check on dynamic allocation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ac17c86648]
* Sat Oct  5 2024 tonyj@suse.de
- perf script python: Fail check on dynamic allocation
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit a58dd0dfa8]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Address python 3.6 DeprecationWarning for string
  scapes (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d60dd870db]
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: Add StarFive Dubhe-80 JSON file
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 92c1374908]
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add s390 raw data interpretation for PAI counters
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 49c1b2f4a3]
* Sat Oct  5 2024 tonyj@suse.de
- perf probe: Convert to check dwarf_getcfi feature
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d221ab268e]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_variable_by_reg() helper
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0085b8715f]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_get_scopes() alternative to
  dwarf_getscopes() (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 57c60a825e]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Move #else block of #ifdef
  HAVE_DWARF_GETLOCATIONS_SUPPORT code to the header file
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6442b017be]
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Fix die_get_typename() for void *
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7917f676cf]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add util/debuginfo. files
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 90ea23191c]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move raw_comment and raw_func_start fields out of
  'struct ins_operands' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 40b60f1e77]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Pass "-l" option to objdump conditionally
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 392087da10]
* Sat Oct  5 2024 tonyj@suse.de
- perf header: Additional note on AMD IBS for max_precise pmu cap
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 7ee4fcdd10]
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Don't synthesize BPF events when disabled
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8d686313f1]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add support for setting objdump binary via perf
  config (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 839930e16a]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add option to change objdump binary
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 6b73d78bfd]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests offcpu: Adjust test case perf record offcpu profiling
  tests for s390 (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 8938b4cc92]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests attr: Fix spelling mistake "whic" to "which"
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit cb80087826]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move offsets array from 'struct annotation' to
  'struct annotated_source' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 15a37920e1]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move some source code related fields
  from 'struct annotation' to 'struct annotated_source'
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 22399b52fa]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move max_coverage from 'struct annotation' to
  'struct annotated_branch' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit dff36ea1b7]
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles info from 'struct
  annotation' (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 0fae5905df]
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Simplify "object code reading" test
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit c3d81b16bf]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix spelling mistake "parametrized" ->
  "parameterized" (perf-sp7-v6.11-userspace-update).
  [kernel-source commit d6dd2afcbe]
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Warn about missing libelf before warning about
  missing libbpf (perf-sp7-v6.11-userspace-update).
  [kernel-source commit ff822de9a1]
* Sat Oct  5 2024 tonyj@suse.de
- perf tests make: Remove the last egrep call, use 'grep -E'
  instead (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 2e65c2a50e]
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty socket/prctl_option: Cope with extended regexp
  complaint by grep (perf-sp7-v6.11-userspace-update).
  [kernel-source commit 294b94438d]
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Update tools's copy of socket.h header
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit bd1746ca65]
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Update copy of libbpf's hashmap.c
  (perf-sp7-v6.11-userspace-update).
  [kernel-source commit aad248b9b5]
* Wed Sep 11 2024 tonyj@suse.de
- perf arch events: Fix duplicate RISC-V SBI firmware event name
  (git-fixes).
  [kernel-source commit 4570763476]
* Wed Sep 11 2024 tonyj@suse.de
- perf tool: fix dereferencing NULL al->maps (git-fixes).
  [kernel-source commit 5e4751b021]
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix exclude_guest setting (git-fixes).
  [kernel-source commit e69b63b092]
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix aux_watermark calculation for 64-bit size
  (git-fixes).
  [kernel-source commit e3b3bcab5e]
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Fix condition in sort__sym_cmp() (git-fixes).
  [kernel-source commit c3e65ee4b6]
* Wed Sep 11 2024 tonyj@suse.de
- perf pmus: Fixes always false when compare duplicates aliases
  (git-fixes).
  [kernel-source commit 8eeac696c9]
* Wed Sep 11 2024 tonyj@suse.de
- tools/perf: Fix the string match for "/tmp/perf-$PID.map"
  files in dso__load (git-fixes).
  [kernel-source commit 9a7d0fbb14]
* Wed Sep 11 2024 tonyj@suse.de
- perf test: Make test_arm_callgraph_fp.sh more robust
  (git-fixes).
  [kernel-source commit 8d430e5991]
* Wed Sep 11 2024 tonyj@suse.de
- perf stat: Fix the hard-coded metrics calculation on the hybrid
  (git-fixes).
  [kernel-source commit 0fe606299c]
* Wed Sep 11 2024 tonyj@suse.de
- perf pmu: Assume sysfs events are always the same case
  (git-fixes).
- Refresh
  patches.suse/perf-pmu-Count-sys-and-cpuid-JSON-events-separately.patch.
  [kernel-source commit 0eb9b05500]
* Tue Sep 10 2024 tonyj@suse.de
- perf tools: Add/use PMU reverse lookup from config to name
  (git-fixes).
  [kernel-source commit 62632fc98b]
* Tue Sep 10 2024 tonyj@suse.de
- perf tools: Use pmus to describe type from attribute
  (git-fixes).
  [kernel-source commit 3dc616bb7e]
* Tue Sep 10 2024 tonyj@suse.de
- perf: script: add raw|disasm arguments to --insn-trace option
  (git-fixes).
- Refresh
  patches.suse/perf-script-Show-also-errors-for-insn-trace-option.patch.
  [kernel-source commit f716aa4425]
* Tue Sep 10 2024 tonyj@suse.de
- perf annotate: Use global annotation_options (git-fixes).
- Refresh
  patches.suse/perf-annotate-Fix-annotation_calc_lines-to-pass-correct-address-to-get_srcline.patch.
  [kernel-source commit b70a6bc1f2]
* Tue Sep 10 2024 tonyj@suse.de
- perf top: Convert to the global annotation_options (git-fixes).
  [kernel-source commit c12ae1d6aa]
* Tue Sep 10 2024 tonyj@suse.de
- perf report: Convert to the global annotation_options
  (git-fixes).
  [kernel-source commit e5bcc3a63c]
* Tue Sep 10 2024 tonyj@suse.de
- perf annotate: Introduce global annotation_options (git-fixes).
  [kernel-source commit b458961362]
* Tue Sep 10 2024 tonyj@suse.de
- perf maps: Move symbol maps functions to maps.c (git-fixes).
- Refresh
  patches.suse/perf-symbols-Fix-ownership-of-string-in-dso__load_vmlinux.patch.
  [kernel-source commit 93caf359b9]
* Tue Sep 10 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles information out of
  'struct annotation_line' (git-fixes).
  [kernel-source commit 733d4c0b1a]
* Tue Sep 10 2024 tonyj@suse.de
- perf machine thread: Remove exited threads by default
  (git-fixes).
  [kernel-source commit 3c4b0771a1]
* Tue Sep 10 2024 tonyj@suse.de
- perf record: Lazy load kernel symbols (git-fixes).
  [kernel-source commit 84efd43f43]
* Tue Sep 10 2024 tonyj@suse.de
- Detect memory allocation failure in
  annotated_source__alloc_histograms (bsc#1227962).
  [kernel-source commit 6424d7a699]
* Mon Aug  5 2024 tonyj@suse.de
- tools/perf: Fix timing issue with parallel threads in perf
  bench wake-up-parallel (bsc#1227747).
  [kernel-source commit 7bc1e4ff37]
* Mon Aug  5 2024 tonyj@suse.de
- tools/perf: Fix perf bench epoll to enable the run when some
  CPU's are offline (bsc#1227747).
  [kernel-source commit 6b131f18f7]
* Mon Aug  5 2024 tonyj@suse.de
- tools/perf: Fix perf bench futex to enable the run when some
  CPU's are offline (bsc#1227747).
  [kernel-source commit 37aca14064]
* Wed Jun  5 2024 tonyj@suse.de
- perf ui browser: Avoid SEGV on title (git fixes).
  [kernel-source commit 1578c2207e]
* Wed Jun  5 2024 tonyj@suse.de
- perf pmu: Count sys and cpuid JSON events separately (git
  fixes).
  [kernel-source commit a1f934056a]
* Wed Jun  5 2024 tonyj@suse.de
- perf stat: Don't display metric header for non-leader uncore
  events (git-fixes).
  [kernel-source commit be40e0bbb3]
* Wed Jun  5 2024 tonyj@suse.de
- perf daemon: Fix file leak in daemon_session__control
  (git-fixes).
  [kernel-source commit 6f01c969e9]
* Wed Jun  5 2024 tonyj@suse.de
- perf symbols: Fix ownership of string in dso__load_vmlinux()
  (git-fixes).
  [kernel-source commit aee1ecfdca]
* Wed Jun  5 2024 tonyj@suse.de
- perf thread: Fixes to thread__new() related to initializing comm
  (git-fixes).
  [kernel-source commit bf0f97be48]
* Wed Jun  5 2024 tonyj@suse.de
- perf report: Avoid SEGV in report__setup_sample_type()
  (git-fixes).
  [kernel-source commit ad916621c9]
* Wed Jun  5 2024 tonyj@suse.de
- perf ui browser: Don't save pointer to stack memory (git-fixes).
  [kernel-source commit 350d10e8b4]
* Wed Jun  5 2024 tonyj@suse.de
- perf bench internals inject-build-id: Fix trap divide when
  collecting just one DSO (git-fixes).
  [kernel-source commit 0fe194c3d8]
* Wed Jun  5 2024 tonyj@suse.de
- perf intel-pt: Fix unassigned instruction op (discovered by
  MemorySanitizer) (git-fixes).
  [kernel-source commit 63b4f3d779]
* Wed Jun  5 2024 tonyj@suse.de
- perf test shell arm_coresight: Increase buffer size for
  Coresight basic tests (git-fixes).
  [kernel-source commit 86c8a88044]
* Wed Jun  5 2024 tonyj@suse.de
- perf docs: Document bpf event modifier (git-fixes).
  [kernel-source commit 1f15e93e8d]
* Wed Jun  5 2024 tonyj@suse.de
- perf bench uprobe: Remove lib64 from libc.so.6 binary path
  (git-fixes).
  [kernel-source commit 3b426c63f0]
* Wed Jun  5 2024 tonyj@suse.de
- perf record: Fix debug message placement for test consumption
  (git-fixes).
  [kernel-source commit dccfc2bbba]
* Wed Jun  5 2024 tonyj@suse.de
- perf tests: Apply attributes to all events in object code
  reading test (git-fixes).
  [kernel-source commit ec739944c2]
* Wed Jun  5 2024 tonyj@suse.de
- perf tests: Make "test data symbol" more robust on Neoverse N1
  (git-fixes).
  [kernel-source commit e7f9dfdfd4]
* Wed Jun  5 2024 tonyj@suse.de
- perf annotate: Fix annotation_calc_lines() to pass correct
  address to get_srcline() (git-fixes).
  [kernel-source commit 8db95e1215]
* Wed Jun  5 2024 tonyj@suse.de
- perf stat: Do not fail on metrics on s390 z/VM systems
  (git-fixes).
  [kernel-source commit 9296325d90]
* Wed Jun  5 2024 tonyj@suse.de
- perf sched timehist: Fix -g/--call-graph option failure
  (git-fixes).
  [kernel-source commit 214f6070b6]
* Wed Jun  5 2024 tonyj@suse.de
- perf annotate: Get rid of duplicate --group option item
  (git-fixes).
  [kernel-source commit 5baa889f52]
* Wed Jun  5 2024 tonyj@suse.de
- perf probe: Add missing libgen.h header needed for using
  basename() (git-fixes).
  [kernel-source commit dd54471b2a]
* Wed Jun  5 2024 tonyj@suse.de
- perf record: Delete session after stopping sideband thread
  (git-fixes).
  [kernel-source commit 86dd10abd5]
* Wed Jun  5 2024 tonyj@suse.de
- perf auxtrace: Fix multiple use of --itrace option (git-fixes).
  [kernel-source commit 65d7baaa64]
* Wed Jun  5 2024 tonyj@suse.de
- perf script: Show also errors for --insn-trace option
  (git-fixes).
  [kernel-source commit 036484bcd2]
* Wed Jun  5 2024 tonyj@suse.de
- perf lock contention: Add a missing NULL check (git-fixes).
  [kernel-source commit 6c77e7d956]
* Wed Jun  5 2024 tonyj@suse.de
- perf vendor events amd: Fix Zen 4 cache latency events
  (git-fixes).
  [kernel-source commit 7261d423d8]
* Wed Jun  5 2024 tonyj@suse.de
- libperf evlist: Avoid out-of-bounds access (git-fixes).
  [kernel-source commit b9a39452f5]
* Wed Jun  5 2024 tonyj@suse.de
- perf pmu: Fix a potential memory leak in perf_pmu__lookup()
  (git-fixes).
  [kernel-source commit 00ff25aefe]
* Wed Jun  5 2024 tonyj@suse.de
- perf print-events: make is_event_supported() more robust
  (git-fixes).
  [kernel-source commit 5052041295]
* Wed Jun  5 2024 tonyj@suse.de
- perf list: fix short description for some cache events
  (git-fixes).
  [kernel-source commit e8dcca50a7]
* Wed Jun  5 2024 tonyj@suse.de
- perf metric: Don't remove scale from counts (git-fixes).
  [kernel-source commit e5678eb49a]
* Wed Jun  5 2024 tonyj@suse.de
- perf stat: Avoid metric-only segv (git-fixes).
  [kernel-source commit 9379989299]
* Wed Jun  5 2024 tonyj@suse.de
- perf expr: Fix "has_event" function for metric style events
  (git-fixes).
  [kernel-source commit cbf845af3b]
* Wed Jun  5 2024 tonyj@suse.de
- perf srcline: Add missed addr2line closes (git-fixes).
  [kernel-source commit a254d5df3a]
* Wed Jun  5 2024 tonyj@suse.de
- perf thread_map: Free strlist on normal path in
  thread_map__new_by_tid_str() (git-fixes).
  [kernel-source commit 7f3812f7ba]
* Wed Jun  5 2024 tonyj@suse.de
- perf bpf: Clean up the generated/copied vmlinux.h (git-fixes).
  [kernel-source commit 4216f09b80]
* Wed Jun  5 2024 tonyj@suse.de
- perf jevents: Drop or simplify small integer values (git-fixes).
  [kernel-source commit c97375e823]
* Wed Jun  5 2024 tonyj@suse.de
- perf evsel: Fix duplicate initialization of data->id in
  evsel__parse_sample() (git-fixes).
  [kernel-source commit f706bfe134]
* Wed Jun  5 2024 tonyj@suse.de
- perf pmu: Treat the msr pmu as software (git-fixes).
  [kernel-source commit 6a5be6946e]
* Wed Jun  5 2024 tonyj@suse.de
- perf record: Check conflict between '--timestamp-filename'
  option and pipe mode before recording (git-fixes).
  [kernel-source commit 999683bc9b]
* Wed Jun  5 2024 tonyj@suse.de
- perf record: Fix possible incorrect free in
  record__switch_output() (git-fixes).
  [kernel-source commit 706fd1acef]
* Wed Jun  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 4 memory controller events
  (git-fixes).
  [kernel-source commit 0062c8737f]
* Wed Jun  5 2024 tonyj@suse.de
- perf top: Uniform the event name for the hybrid machine
  (git-fixes).
  [kernel-source commit ea5a5d7758]
* Wed Jun  5 2024 tonyj@suse.de
- perf top: Use evsel's cpus to replace user_requested_cpus
  (git-fixes).
  [kernel-source commit 1f589571e3]
* Thu Mar 21 2024 tonyj@suse.de
- perf tests: Skip data symbol test if buf1 symbol is missing
  (bsc#1220045).
  [kernel-source commit c2fa164e2b]
* Thu Mar 21 2024 tonyj@suse.de
- perf tests: Make data symbol test wait for perf to start
  (bsc#1220045).
  [kernel-source commit ef2a3551de]
* Thu Mar  7 2024 tonyj@suse.de
- perf/pmu-events/powerpc: Update json mapfile with Power11 PVR
  (jsc#PED-7970 jsc#PED-8065).
  [kernel-source commit b9d5dfb433]
* Thu Mar  7 2024 tonyj@suse.de
- perf vendor events powerpc: Add PVN for HX-C2000 CPU with
  Power8 Architecture (jsc#PED-7970 jsc#PED-8065).
  [kernel-source commit b7e0015119]
* Fri Mar  1 2024 tonyj@suse.de
- perf vendor events: Update metric events for power10 platform
  (bsc#1220502 perf-v6.7).
  [kernel-source commit c37d66c4fd]
* Tue Feb 13 2024 svarbanov@suse.de
- perf vendor events arm64 AmpereOneX: Add core PMU events and metrics (jsc#PED-7859)
  [kernel-source commit 8763e5dbfc]
* Mon Feb 12 2024 tonyj@suse.de
- perf evlist: Fix evlist__new_default() for > 1 core PMU
  (git-fixes).
  [kernel-source commit a32b1b0992]
* Mon Feb 12 2024 tonyj@suse.de
- perf db-export: Fix missing reference count get in
  call_path_from_sample() (git-fixes).
  [kernel-source commit 9020d7fca5]
* Mon Feb 12 2024 tonyj@suse.de
- perf stat: Fix hard coded LL miss units (git-fixes).
  [kernel-source commit 9bdb60524b]
* Mon Feb 12 2024 tonyj@suse.de
- perf env: Avoid recursively taking env->bpf_progs.lock
  (git-fixes).
  [kernel-source commit 7b57b2a0f8]
* Mon Feb 12 2024 tonyj@suse.de
- perf vendor events: Remove UTF-8 characters from cmn.json
  (git-fixes).
  [kernel-source commit b7bdab6f26]
* Mon Feb 12 2024 tonyj@suse.de
- perf unwind-libunwind: Fix base address for .eh_frame
  (git-fixes).
  [kernel-source commit 8f58229b79]
* Mon Feb 12 2024 tonyj@suse.de
- perf unwind-libdw: Handle JIT-generated DSOs properly
  (git-fixes).
  [kernel-source commit 2b678bbb6b]
* Mon Feb 12 2024 tonyj@suse.de
- perf genelf: Set ELF program header addresses properly
  (git-fixes).
  [kernel-source commit 034b81845f]
* Mon Feb 12 2024 tonyj@suse.de
- perf hisi-ptt: Fix one memory leakage in
  hisi_ptt_process_auxtrace_event() (git-fixes).
  [kernel-source commit 48ed189a76]
* Mon Feb 12 2024 tonyj@suse.de
- perf header: Fix one memory leakage in
  perf_event__fprintf_event_update() (git-fixes).
  [kernel-source commit d3460cacbc]
* Mon Feb 12 2024 tonyj@suse.de
- perf stat: Fix help message for --metric-no-threshold option
  (git-fixes).
  [kernel-source commit fc785474ce]
* Mon Feb 12 2024 tonyj@suse.de
- perf stat: Exit perf stat if parse groups fails (git-fixes).
  [kernel-source commit 2a3d7732e5]
* Mon Feb 12 2024 tonyj@suse.de
- perf mem: Fix error on hybrid related to availability of mem
  event in a PMU (git-fixes).
  [kernel-source commit b52007e8cc]
* Mon Feb 12 2024 tonyj@suse.de
- perf vendor events powerpc: Update datasource event name to
  fix duplicate events (git-fixes).
  [kernel-source commit cf8195c7b5]
* Mon Feb 12 2024 tonyj@suse.de
- perf vendor events arm64 AmpereOne: Rename BPU_FLUSH_MEM_FAULT
  to GPC_FLUSH_MEM_FAULT (git-fixes).
  [kernel-source commit fd4435afd5]
* Mon Feb 12 2024 tonyj@suse.de
- perf test record user-regs: Fix mask for vg register
  (git-fixes).
  [kernel-source commit 0ff1685428]
* Mon Feb 12 2024 tonyj@suse.de
- perf docs: Fix man page formatting for 'perf lock' (git-fixes).
  [kernel-source commit 0dca9e65bd]
* Mon Feb 12 2024 tonyj@suse.de
- perf test record+probe_libc_inet_pton: Fix call chain match
  on powerpc (bsc#1218986).
  [kernel-source commit 7eff685fc8]
* Mon Feb 12 2024 tonyj@suse.de
- perf tests: Skip pipe test if noploop symbol is missing
  (bsc#1219617).
  [kernel-source commit d7947e20b1]
* Mon Feb 12 2024 tonyj@suse.de
- perf tests lib: Add perf_has_symbol.sh (bsc#1219617).
  [kernel-source commit 10834451a9]
* Mon Feb 12 2024 tonyj@suse.de
- perf header: Fix segfault on build_mem_topology() error path
  (git-fixes).
  [kernel-source commit 3c75be3792]
* Mon Feb 12 2024 tonyj@suse.de
- perf test: Remove atomics from test_loop to avoid test failures
  (git-fixes).
  [kernel-source commit 04bc8ed576]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Basic branch counter support (jsc#PED-6012
  jsc#PED-6121).
  [kernel-source commit 554529dc26]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add branch counter knob (jsc#PED-6012 jsc#PED-6121).
  [kernel-source commit bcfa930b33]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Support num and width of branch counters
  (jsc#PED-6012 jsc#PED-6121).
  [kernel-source commit c638dccb3b]
* Mon Jan 15 2024 tonyj@suse.de
- perf list: Fix JSON segfault by setting the used
  skip_duplicate_pmus callback (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit acbb0879db]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: AmpereOne: Add missing
  DefaultMetricgroupName fields (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit d598e2e9f2]
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Avoid segv if default metricgroup isn't set
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69c1abb54e]
* Mon Jan 15 2024 tonyj@suse.de
- tools perf: Add arm64 sysreg files to MANIFEST (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3971573ba0]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Fix a build error on 32-bit (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7db26b275c]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Fix a build error on 32-bit (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 1b2fbc1dbf]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update tsx_cycles_per_elision metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit be5179bf77]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update bonnell version number to v5
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 93635bc8b0]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update westmereex events to v4
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fe864a9f99]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake events to v1.06
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e0d64f20cf]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update knightslanding events to v16
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c6e6f52ad2]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add typo fix for ivybridge FP
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 63a8a4e582]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update a spelling in haswell/haswellx
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8bc6482e8a]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids to v1.01
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 93c23e00bb]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake/alderlake events
  to v1.23 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 19f0d0f728]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Disable BPF skeletons if clang version is < 12.0.1
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5ebc0ac116]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain: Fix spelling mistake "statisitcs" ->
  "statistics" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69d739bf95]
* Mon Jan 15 2024 tonyj@suse.de
- perf report: Fix spelling mistake "heirachy" -> "hierarchy"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1ea59de96f]
* Mon Jan 15 2024 tonyj@suse.de
- perf python: Fix binding linkage due to rename and move
  of evsel__increase_rlimit() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 1a5c00c342]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: test_arm_coresight: Simplify source iteration
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d716cc2ccf]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add tigerlake two metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit dc4fd24d19]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add broadwellde two metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c326eaf1e5]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Fix broadwellde
  tma_info_system_dram_bw_use metric (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 4d1fd9e93a]
* Mon Jan 15 2024 tonyj@suse.de
- perf mem_info: Add and use map_symbol__exit and
  addr_map_symbol__exit (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit df6c7c85d3]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain: Minor layout changes to callchain_list
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ba9139bb57]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain: Make brtype_stat in callchain_list optional
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5f7a3989bd]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain: Make display use of branch_type_stat const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a3071857ef]
* Mon Jan 15 2024 tonyj@suse.de
- perf offcpu: Add missed btf_free (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 35ca003207]
* Mon Jan 15 2024 tonyj@suse.de
- perf threads: Remove unused dead thread list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bf969df35e]
* Mon Jan 15 2024 tonyj@suse.de
- perf hist: Add missing puts to hist__account_cycles (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e101721c41]
* Mon Jan 15 2024 tonyj@suse.de
- libperf rc_check: Add RC_CHK_EQUAL (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 2c3d46a3c3]
* Mon Jan 15 2024 tonyj@suse.de
- libperf rc_check: Make implicit enabling work for GCC (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1b835690c8]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Avoid out of bounds LBR memory read (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8e8ebcf987]
* Mon Jan 15 2024 tonyj@suse.de
- perf rwsem: Add debug mode that uses a mutex (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d5f034d19e]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Address stray '\' before # that is warned about
  since grep 3.8 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c0d93bff9c]
* Mon Jan 15 2024 tonyj@suse.de
- perf report: Fix hierarchy mode on pipe input (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit af7a278ec0]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Use per-cpu array map for spinlocks
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c029d549dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Check race in tstamp elem creation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fd3fd4cac8]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Clear lock addr after use (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2724e680e4]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Rename evsel__increase_rlimit to
  rlimit__increase_nofile (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a99467dfc5]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench sched pipe: Add -G/--cgroups option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 19887ad493]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Skip CoreSight tests if cs_etm// event is not
  available (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c07b748aae]
* Mon Jan 15 2024 tonyj@suse.de
- perf data: Increase RLIMIT_NOFILE limit when open too many
  files in perf_data__create_dir() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 3e4b995690]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Use the right bpf_probe_read(_str) variant for
  reading user data (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b1dfdc8418]
* Mon Jan 15 2024 tonyj@suse.de
- perf: script: fix missing ',' for fields option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cb8b696db6]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Fix shellcheck warning in stat_all_metricgroups
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8d6bc73e0a]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Fix shellcheck warning in record_sideband.sh
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3c617bbe32]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Ignore shellcheck warning in lock_contention
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 679781168c]
* Mon Jan 15 2024 tonyj@suse.de
- tools/perf/arch/powerpc: Fix the CPU ID const char* value by
  adding 0x prefix (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6c3f69e6e2]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Respect timestamp option (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 731e40cf8c]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Validate timestamp tracing in per-thread mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b9a52965c6]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Lazily compute default config (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit afde0ff854]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu-events: Remember the perf_events_map for a PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1744567f7e]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Const-ify perf_pmu__config_terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit aaf6232827]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Const-ify file APIs (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit b29d01abcd]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm-spe: Move PMU initialization from default config code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69edd919fc]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Move PMU initialization from default config code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8f8d50800a]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Rename perf_pmu__get_default_config to
  perf_pmu__arch_init (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3fce85f57a]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Prefer get_unaligned_le64 to memcpy_le64
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b9b9d2243c]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Use get_unaligned_le16() etc (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 002149f08c]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Use existing definitions of le16_to_cpu() etc
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a1210a989b]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Simplify intel_pt_get_vmcs() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5334402a28]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add get_unaligned_leNN() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 533f0d4ab3]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Fix incorrect or missing decoder for raw trace
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69eb5ce92c]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf_counter: Fix a few memory leaks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7316b69129]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Fix various error path memory leaks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d4d4b28279]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace-event-info: Avoid passing NULL value to closedir
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c15555a61f]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fix unlikely memory leak when cloning terms
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 40312f327c]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock: Fix a memory leak on an error path (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7d1c118a4b]
* Mon Jan 15 2024 tonyj@suse.de
- perf svghelper: Avoid memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 41c9ed4fea]
* Mon Jan 15 2024 tonyj@suse.de
- perf hists browser: Avoid potential NULL dereference (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9c4fa7e8d2]
* Mon Jan 15 2024 tonyj@suse.de
- perf hists browser: Reorder variables to reduce padding
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 314130b1c9]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Be defensive against potential NULL dereference
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 140f2004e9]
* Mon Jan 15 2024 tonyj@suse.de
- perf mem-events: Avoid uninitialized read (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 41a4c15f12]
* Mon Jan 15 2024 tonyj@suse.de
- perf jitdump: Avoid memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 55cd7c6f19]
* Mon Jan 15 2024 tonyj@suse.de
- perf env: Remove unnecessary NULL tests (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e63a600932]
* Mon Jan 15 2024 tonyj@suse.de
- perf buildid-cache: Fix use of uninitialized value (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 698b349679]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe: Fix potential use of memory after free
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f2f66d04ca]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fix for term values that are raw events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 030454f72c]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Add missing comment about NO_LIBTRACEEVENT=1
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4f6d482855]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbols: Add 'intel_idle_ibrs' to the list of idle symbols
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 33e3a090ce]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid erange from hex numbers (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e23a884ef5]
* Mon Jan 15 2024 tonyj@suse.de
- tools/perf: Update call stack check in builtin-lock.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 34a7de9fbe]
* Mon Jan 15 2024 tonyj@suse.de
- tools/perf/tests: Fix object code reading to skip address
  that falls out of text section (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 86fd825f51]
* Mon Jan 15 2024 tonyj@suse.de
- tools/perf: Add "is_kmod" to struct dso to check if it is
  kernel module (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 428ef515bc]
* Mon Jan 15 2024 tonyj@suse.de
- tools/perf: Add text_end to "struct dso" to save .text section
  size (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7fd30fb68e]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Avoid system wide when not privileged (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 46ee96fed6]
* Mon Jan 15 2024 tonyj@suse.de
- perf hisi-ptt: Fix memory leak in lseek failure handling
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1ce5d93855]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Fix async branch flags (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit bbcdee7c9d]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Make PMU alias name loading lazy (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 79cc2cba29]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix parse-events tests to skip parametrized events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5e14e15d8f]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events: Add JSON metrics for Arm CMN (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0e11ed2dc0]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Add support for Arm CMN PMU aliasing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 15fd30b239]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add pmu-event test for "Compat" and new event_field
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 245850dfd6]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Make matching_pmu effective (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 9e1f125a5c]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Support EventidCode and NodeType (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 641d9c70b8]
* Mon Jan 15 2024 tonyj@suse.de
- perf metric: "Compat" supports regular expression matching
  identifiers (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 76d090adc8]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: "Compat" supports regular expression matching
  identifiers (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit afb9b6a585]
* Mon Jan 15 2024 tonyj@suse.de
- perf record: Fix BTF type checks in the off-cpu profiling
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 10e90e11ec]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench messaging: Kill child processes when exit abnormally
  in process mode (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cce54943ca]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench messaging: Store chlid process pid when creating
  worker for process mode (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0038cd401b]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench messaging: Factor out create_worker() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8a01da6d96]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench messaging: Fix coding style issues for
  sched-messaging (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit de9b10238b]
* Mon Jan 15 2024 tonyj@suse.de
- tests/shell: Fix shellcheck warnings for SC2153 in multiple
  scripts (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4cd0ca24b2]
* Mon Jan 15 2024 tonyj@suse.de
- tests/shell: Fix shellcheck issues in
  tests/shell/stat+shadow_stat.sh tetscase (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6e8294d866]
* Mon Jan 15 2024 tonyj@suse.de
- tests/shell: Fix shellcheck SC1090 to handle the location of
  sourced files (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c373d2d904]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Fix spelling mistake "Captuer" -> "Capture"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a770be6f82]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Avoid frequency mode for the dummy event (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit be4f2dccdc]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendors events: Remove repeated word in comments (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a56b40d024]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Fix for AmpereOne metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit efcd9b10bd]
* Mon Jan 15 2024 tonyj@suse.de
- perf test lock_contention.sh: Skip test if not enough CPUs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 92afea3380]
* Mon Jan 15 2024 tonyj@suse.de
- perf test stat+shadow_stat.sh: Add threshold for rounding errors
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f41dfb6a01]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: fix no member named 'entries' issue (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ab7c69bf52]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fix tracepoint name memory leak (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 07b7fe9c42]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Detect off-cpu support from build options (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 85882b9267]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Ensure EXTRA_TESTS is covered in build test
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f5f4560e3c]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Update build test for changed BPF skeleton defaults
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 71d25caa3e]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Default BUILD_BPF_SKEL, warn/disable for missing
  deps (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 730785c384]
* Mon Jan 15 2024 tonyj@suse.de
- perf version: Add status of bpf skeletons (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 908c0419ee]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Simplify bool conversion (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 42a192c626]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix test-record-dummy-C0 failure for supported
  PERF_FORMAT_LOST feature kernel (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8006cfd788]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Fix spelling mistake "COMMMAND" -> "COMMAND"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cb13031fb4]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Add more x86 mov instruction cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e33b520265]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove unused function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit c67844b982]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Simplify perf_pmus__find_core_pmu() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4fbcf0eb03]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Move pmu__find_core_pmu() to pmus.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 20d110435e]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol: Avoid an undefined behavior warning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a8a26a8240]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf-filter: Add YYDEBUG (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit ab66831dcf]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Add YYDEBUG (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ac0e75f623]
* Mon Jan 15 2024 tonyj@suse.de
- perf expr: Make YYDEBUG dependent on doing a debug build
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6dfcfedf58]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Make YYDEBUG dependent on doing a debug build
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 49cff8ab3c]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove unused header files (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d81e148a3d]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add includes for detected configs in Makefile.perf
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d632b2741d]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Update cs_etm testcase for Arm ETE (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d2d2bc55a5]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add V1 metrics using Arm telemetry
  repo (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c336f65a54]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Update V1 events using Arm telemetry
  repo (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 905f77a6ec]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add a test for strcmp_cpuid_str() expression
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 13120b46d0]
* Mon Jan 15 2024 tonyj@suse.de
- perf util: Add a function for replacing characters in a string
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0a135a44f5]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Remove unused keyword (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit acc213ae31]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Check result of has_event(cycles) test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 13907e6a8a]
* Mon Jan 15 2024 tonyj@suse.de
- perf list pfm: Retry supported test with exclude_kernel
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8d06d9c1a5]
* Mon Jan 15 2024 tonyj@suse.de
- perf list: Avoid a hardcoded cpu PMU name (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9a9fa5df18]
* Mon Jan 15 2024 tonyj@suse.de
- perf test shell lock_contention: Add cgroup aggregation and
  filter tests (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9f64737842]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Add -G/--cgroup-filter option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a8a2c163b2]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Add --lock-cgroup option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 57cd057dcb]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Prepare to handle cgroups (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9a3395af24]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add read_all_cgroups() and __cgroup_find()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit efa477b8c1]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Add BPF-based statistics on softirq event
  support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 96698f0961]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Add BPF-based statistics on hardirq event
  support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c3a87d9c1c]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Implements BPF-based cpu usage statistics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 32eba2f5cd]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Add -C/--cpu -i/--input -n/--name -s/--sort
  - -time options (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e39219f876]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Add statistics on softirq event support
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 600ce20732]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Add statistics on hardirq event support
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 594ddb974a]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Add evsel__intval_common() helper (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9cbd426ac6]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork top: Introduce new top utility (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2234ec204f]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Add `root` parameter to work_sort() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 097c15b104]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Add sched record support (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 789d0aa94a]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Set default events list if not specified in
  setup_event_list() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b3eb05bd14]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Overwrite original atom in the list when a new
  atom is pushed (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 865d1cd85e]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Add `kwork` and `src_type` to work_init() for
  'struct kwork_class' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a145e1cbb7]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Set ordered_events to true in 'struct perf_tool'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f915ca9d8f]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Add the supported subcommands to the document
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c949234ac2]
* Mon Jan 15 2024 tonyj@suse.de
- perf kwork: Fix incorrect and missing free atom in
  work_push_atom() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 65a6b18f5c]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add perf_event_attr test for record dummy event
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 30c64061e1]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add test case for record sideband events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cbc5788ef6]
* Mon Jan 15 2024 tonyj@suse.de
- perf record: Track sideband events for all CPUs when tracing
  selected CPUs (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5eaa6dfbde]
* Mon Jan 15 2024 tonyj@suse.de
- perf record: Move setting tracking events before
  record__init_thread_masks() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 97450cbde7]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Add evlist__findnew_tracking_event() helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e05e23f2d2]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Add perf_evlist__go_system_wide() helper (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1638709b67]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Fix spelling mistakes (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7b0cd1d2b7]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add emeraldrapids, update
  sapphirerapids to v1.16 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9bd1e648d6]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add lunarlake v1.0 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5dc174d3fe]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Introduce 'struct parse_events_terms'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c5d7549cdf]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Copy fewer term lists (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4daef7b4e4]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid enum casts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 5276dc2cd7]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Tidy up str parameter (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8f3f04d5c2]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove unnecessary __maybe_unused (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 78c5d97b8a]
* Mon Jan 15 2024 tonyj@suse.de
- perf shell completion: Support completion of
  metrics/metricgroups (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 78942fcac1]
* Mon Jan 15 2024 tonyj@suse.de
- perf completion: Support completion of libpfm4 events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fcb392e433]
* Mon Jan 15 2024 tonyj@suse.de
- perf shell completion: Restrict completion of events to events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9ea4cd6983]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Fix aggr mode initialization (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit aeae13a089]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events power10: Add extra data-source events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2aef5f73f9]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Use true and false for bool variable (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 194e1883b9]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Add a test for object_code() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b9576d9919]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Fix use of addr_location__exit() in
  dlfilter__object_code() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4ed98d931c]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Fix perf stat output with correct scale and unit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4bf569b80e]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevent: fix core dump on software events on s390 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 340d5dd116]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Ensure all alias variables are initialized (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit aaa52488b2]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents metric: Fix type of strcmp_cpuid_str (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d6a648ac10]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Avoid compile error wrt redefining bool (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8a2b39f4a9]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench sched-seccomp-notify: Use the tools copy of seccomp.h
  UAPI (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 315c9687d2]
* Mon Jan 15 2024 tonyj@suse.de
- tools headers UAPI: Copy seccomp.h to be able to build 'perf
  bench' in older systems (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5a46d4206e]
* Mon Jan 15 2024 tonyj@suse.de
- tools headers UAPI: Sync files changed by new fchmodat2 and
  map_shadow_stack syscalls with the kernel sources (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ea03e8bb70]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fix driver config term (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a3c5a046d7]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fixes relating to no_value terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b2a6bdf996]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Fix propagation of term's no_value when
  cloning (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 91ba41c9fc]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Name the two term enums (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 37b884f185]
* Mon Jan 15 2024 tonyj@suse.de
- perf list: Don't print Unit for "default_core" (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c4e509bdce]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Fix modifier in
  tma_info_system_mem_parallel_reads for skylake (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2d5b2d10ab]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Avoid leak in v0 API test use of
  resolve_address() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 48230698d5]
* Mon Jan 15 2024 tonyj@suse.de
- perf metric: Add #num_cpus_online literal (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9a1e563b7c]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove str from perf_pmu_alias (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9c5005d89c]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Make common term list to strbuf helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0ef0cf3310]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Minor help message improvements (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 55788f3ec1]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Avoid uninitialized use of alias->str (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 22537722b9]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Use "default_core" for events with no Unit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4221875daf]
* Mon Jan 15 2024 tonyj@suse.de
- perf test stat_bpf_counters_cgrp: Enhance perf stat cgroup
  BPF counter test (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5a1c963b21]
* Mon Jan 15 2024 tonyj@suse.de
- perf test shell stat_bpf_counters: Fix test on Intel (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit eff613f64a]
* Mon Jan 15 2024 tonyj@suse.de
- perf test shell record_bpf_filter: Skip 6.2 kernel (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ae744d3d3b]
* Mon Jan 15 2024 tonyj@suse.de
- libperf: Get rid of attr.id field (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 025e5c5454]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Convert to perf_record_header_attr_id() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 52701744a2]
* Mon Jan 15 2024 tonyj@suse.de
- libperf: Add perf_record_header_attr_id() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4f5c8a9a32]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Handle old data in PERF_RECORD_ATTR (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fe44f6c6b3]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Skip duplicate PMUs and don't print list suffix by
  default (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 06e126fae4]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Sort pmus by name then suffix (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b5db4206e7]
* Mon Jan 15 2024 tonyj@suse.de
- perf beauty mmap_flags: Use "test -f" instead of "" (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 084ac3ed76]
* Mon Jan 15 2024 tonyj@suse.de
- perf beauty mmap_flags: Fix script for archs that use the
  generic mman.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bd9ce05b67]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Allow to use cpuinfo on LoongArch (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e0776b1f97]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Fix typo in max-stack option description
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cf95cb99a3]
* Mon Jan 15 2024 tonyj@suse.de
- perf tui slang: Tidy casts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 9ccee57e9b]
* Mon Jan 15 2024 tonyj@suse.de
- perf build-id: Simplify build_id_cache__cachedir() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bcd7384e3a]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Make id const and add missing free (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7709dec7ab]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Make term's config const (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a535e2e507]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove logic for PMU name being NULL (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 949b5083a0]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Fix missing PMU caps (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit c99e4b3b53]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Don't append Unit to desc (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8a013c94ee]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python gecko: Launch the profiler UI on the default
  browser with the appropriate URL (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit ab8330177b]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Add support for input args in gecko script
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4a05a706f2]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Sort strings in the big C string to reduce faults
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a1a18ea7b2]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Lazily load sysfs aliases (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e748f2a5fa]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Be lazy about loading event info files from sysfs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c47425b67f]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Scan type early to fail an invalid PMU quickly
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b373d18d99]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Lazily add JSON events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 23e10fb713]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Cache JSON events table (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit dee9fe585e]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Merge JSON events with sysfs at load time (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit afd70421bd]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Prefer passing pmu to aliases list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cf32e6fef8]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Parse sysfs events directly from a file (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2b13aef3b8]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu-events: Add pmu_events_table__find_event() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6410e124e1]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu-events: Reduce processed events by passing PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c5e7c55470]
* Mon Jan 15 2024 tonyj@suse.de
- perf s390 s390_cpumcfdg_dump: Don't scan all PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9077446fb8]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Improve error message for double setting
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d2f6b9ea67]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Group events by PMU (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit fcdc040206]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu-events: Add extra underscore to function names
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 768027d6f7]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Abstract alias/event struct (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit a8ff4ab6d0]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Make the loading of formats lazy (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f9d82af799]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Allow customization of clang options for BPF target
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0cf860a3aa]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Pass PMU rather than aliases and format (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 33ee0fba89]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Avoid passing format list to perf_pmu__format_bits()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 947286a275]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Avoid passing format list to perf_pmu__format_type
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5d0c67cdb5]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Avoid passing format list to perf_pmu__config_terms()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a503aa2c7b]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Reduce scope of perf_pmu_error() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2821862f9b]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Move perf_pmu__set_format to pmu.y (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 42a93a3a2d]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Avoid a path name copy (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit db3f97427f]
* Mon Jan 15 2024 tonyj@suse.de
- perf script ibs: Remove unused include (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 3fad43df88]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench breakpoint: Skip run if no breakpoints available
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b42d495c04]
* Mon Jan 15 2024 tonyj@suse.de
- perf lzma: Convert some pr_err() to pr_debug() as callers
  already use pr_debug() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 25e51cb460]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat-display: Check if snprintf()'s fmt argument is NULL
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8fe10d15b1]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf augmented_raw_syscalls: Add an assert to make sure
  sizeof(augmented_arg->value) is a power of two (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 79f8a9a2a1]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf augmented_raw_syscalls: Add an assert to make sure
  sizeof(saddr) is a power of two (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 7b0648d10d]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: AmpereOne: Remove unsupported events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9b3af5ecf8]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add AmpereOne metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 30016c6f56]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: AmpereOne: Mark affected STALL_*
  events impacted by errata (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 041d8ad130]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Remove L1D_CACHE_LMISS from AmpereOne
  list (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 068f6627f1]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Raise exception for no definition of a arch std
  event (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fa31efc48b]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Use heuristic when deciding if a syscall tracepoint
  "const char *" field is really a string (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e5c4f0e521]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Use the augmented_raw_syscall BPF skel only for
  tracing syscalls (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7b46e1898f]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock: Don't pass an ERR_PTR() directly to
  perf_session__delete() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 94ec1e53b6]
* Mon Jan 15 2024 tonyj@suse.de
- perf top: Don't pass an ERR_PTR() directly to
  perf_session__delete() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ac3cf0385a]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Update N2 and V2 metrics and
  events using Arm telemetry repo (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit cf0943cb83]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Update stall_slot workaround for N2
  r0p3 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e19fb041d8]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Add a new expression builtin strcmp_cpuid_str()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9bf2606a72]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add a test for the new Arm CPU ID comparison behavior
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit dd753cab9e]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm64: Allow version comparisons of CPU IDs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9937f01b7a]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf_skel augmented_raw_syscalls: Cap the socklen parameter
  using &= sizeof(saddr) (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3ff89f376e]
* Mon Jan 15 2024 tonyj@suse.de
- libperf: Implement riscv mmap support (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 483e69d053]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-regs: Move out arch specific header from
  util/perf_regs.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3b042fe219]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-regs: Remove PERF_REGS_{MAX|MASK} from common code
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b147dc4d35]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-regs: Remove unused macros PERF_REG_{IP|SP}
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6a73bd1e73]
* Mon Jan 15 2024 tonyj@suse.de
- perf unwind: Use perf_arch_reg_{ip|sp}() to substitute macros
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9f86661591]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-regs: Introduce functions perf_arch_reg_{ip|sp}()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a09f842502]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-regs: Refactor arch register parsing functions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f54156622e]
* Mon Jan 15 2024 tonyj@suse.de
- perf docs: Fix format of unordered lists (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2fa8d7ee65]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Update scale units and descriptions of
  common topdown metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 010bd46a6d]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Don't duplicate FIELD_GET() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f26d9a7089]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Add al_cleanup() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 76c01804ee]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Initialize addr_location before passing
  it to thread__find_symbol_fb() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 9b9144d9e3]
* Mon Jan 15 2024 tonyj@suse.de
- perf dlfilter: Add a test for resolve_address() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cb69cc8b96]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Update audit-libs package name for python3
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 73cf7b7164]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Support syscall name parsing on arm64
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6a67fe87a3]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Remove duplicate check for `field` in
  evsel__intval() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 15af1436eb]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add perf record sample filtering test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 68b670de44]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf-filter: Fix sample flag check with || (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ba0eed252f]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Tidy comments related to BPF + syscall augmentation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 292f5240e6]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf examples: With no BPF events remove examples (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ccedd2ca4b]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Migrate BPF augmentation to use a skeleton
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6c32c96ed8]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove BPF event support (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d52e6a0efd]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf: Remove support for embedding clang for compiling
  BPF events (-e foo.c) (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f77074f943]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests trace+probe_vfs_getname.sh: Accept quotes surrounding
  the filename (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3b35d96875]
* Mon Jan 15 2024 tonyj@suse.de
- perf test trace+probe_vfs_getname.sh: Remove stray \ before /
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 02acc7535c]
* Mon Jan 15 2024 tonyj@suse.de
- perf script python: Add stub for PMU symbol to the python
  binding (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4b42b94cef]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbols: Fix DSO kernel load and symbol process to
  correctly map DSO to its long_name, type and adjust_symbols
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b796f37bd2]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Remove -Wno-unused-but-set-variable from the
  flex flags when building with clang < 13.0.0 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6ff9042b49]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Print "cgroup" field on the same line as "comm"
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ad947a3f4c]
* Mon Jan 15 2024 tonyj@suse.de
- perf probe: Make synthesize_perf_probe_point() private to
  probe-event.c (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit da471cac1e]
* Mon Jan 15 2024 tonyj@suse.de
- perf probe: Free string returned by
  synthesize_perf_probe_point() on failure in
  synthesize_perf_probe_command() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 700bd85a25]
* Mon Jan 15 2024 tonyj@suse.de
- perf probe: Free string returned by
  synthesize_perf_probe_point() on failure to add a probe
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7f5cce10ba]
* Mon Jan 15 2024 tonyj@suse.de
- perf hists browser: Fix the number of entries for 'e' key
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 79f400d856]
* Mon Jan 15 2024 tonyj@suse.de
- perf hists browser: Fix hierarchy mode header (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 292a3332d7]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate bpf: Don't enclose non-debug code with an assert()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c88d4d07f1]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Support llvm and clang support compiled in
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3bcc083aee]
* Mon Jan 15 2024 tonyj@suse.de
- perf script python: Cope with declarations after statements
  found in Python.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7e65c625f4]
* Mon Jan 15 2024 tonyj@suse.de
- perf python: Cope with declarations after statements found in
  Python.h (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fbb3e5a040]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update Icelake+ metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b5193ab3df]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids to 1.15
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c6becf356c]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake to 1.04 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d9bc7cac59]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events x86: Avoid sorting uops_retired.slots
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 45804e9cd5]
* Mon Jan 15 2024 tonyj@suse.de
- perf probe: Show correct error message about @symbol usage
  for uprobe (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ad6c519564]
* Mon Jan 15 2024 tonyj@suse.de
- perf test bpf: Address error about non-null argument for
  epoll_pwait 2nd arg (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fcdc0aa34c]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+std_output: Fix shellcheck warnings about word
  splitting/quoting and local variables (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e3a96f1091]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+std_output: Fix shellcheck warnings about word
  splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1823f828c6]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lib stat_output: Fix shellcheck warning about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bc1e09d812]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests coresight thread_loop_check_tid_2: Fix shellcheck
  warnings about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 41e4df40dd]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests record+zstd_comp_decomp: Fix the shellcheck
  warnings about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e7a7ef6cc9]
* Mon Jan 15 2024 tonyj@suse.de
- perf arch x86: Address shellcheck warnings about unused
  variables in syscalltbl.sh (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 23a70f8eb8]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace x86_arch_prctl: Address shellcheck warnings about
  local variables (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b1921f031d]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lib waiting: Fix the shellcheck warnings about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 155a815f15]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lib probe_vfs_getname: Fix shellcheck warnings
  about missing shebang/local variables (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit c27fe1faf0]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests unroll_loop_thread_10: Fix shellcheck warnings about
  word splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ea2990db85]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests thread_loop_check_tid_10: Fix shellcheck warnings
  bout word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 1b90318652]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Fix shellcheck issue about quotes for
  check-headers.sh (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 619c201f1d]
* Mon Jan 15 2024 tonyj@suse.de
- perf beauty arch_errno_names: Fix shellcheck issue about local
  variables (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f0653795b6]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lib probe: Fix shellcheck warning about about
  missing shebang (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a2e9451c86]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests memcpy_thread_16k_10: Fix shellcheck warning about
  word splitting/quote (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7244f64c33]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests asm_pure_loop: Fix shellcheck warning about word
  splitting/quote (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a71699d2f1]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+shadow_stat: Fix shellcheck warning about
  unused variable (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8a67d7f949]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat_bpf_counters: Fix usage of '==' to address
  shellcheck warning (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 106d52464c]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests perf_dat _converter_json: Use quoting to avoid word
  splitting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0634e94faa]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+csv_summary: Fix unused variable references
  detected via shellcheck (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b30d79961c]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Address signal case issues detected via shellcheck
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 84e6068a01]
* Mon Jan 15 2024 tonyj@suse.de
- perf test stat_bpf_counters_cgrp: Fix shellcheck issue about
  logical operators (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 486c5f6eb1]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lock_contention: Fix shellcheck issue about quoting
  to avoid word splitting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 88f1944134]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests record_offcpu: Fix shellcheck warnings about
  word splitting/quoting and signal names case (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cb81506dfd]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests probe_vfs_getname: Fix shellcheck warnings about
  word splitting/quoting (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8ba741be17]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests trace+probe_vfs_getname: Fix shellcheck warnings
  about word splitting/quoting (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit fa701d52ff]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests task_analyzer: Check perf build options for
  libtraceevent support (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 78d6b6bbbd]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove array remnants (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4fce476c63]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Revert enable indices setting syntax for BPF map
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8a21f649dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-event: Avoid BPF test SEGV (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 3a4a331426]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Include generated header files properly (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1156928eef]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Update build rule for generated files (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d2bce40065]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Remove -Wno-redundant-decls in 2 cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 904118f55a]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Disable fewer bison warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8e0992e522]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Disable fewer flex warnings (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 6287a212a9]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Add Wextra for C++ compilation (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 06a1fba811]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Don't always set -funwind-tables and -ggdb3
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 02d655e8f4]
* Mon Jan 15 2024 tonyj@suse.de
- perf bpf-loader: Remove unneeded diagnostic pragma (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 28b453578c]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add JSON metrics for Yitian 710 DDR
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0eeeb4708e]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Add support for Yitian 710 DDR PMU (arm64)
  aliasing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7456e2a3fc]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add a place to put kernel config fragments for
  test runs (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bc618cafe1]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Add command execution for gecko script
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 49a38277c3]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Implement add sample function and thread
  processing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2c4c849777]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Implement add sample function and thread
  processing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ad07e261d5]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Add trace end processing and PRODUCT and
  CATEGORIES information (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6ce5150662]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Add classes and conversion functions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2101d1b493]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Extact necessary information from process
  event (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6d130b21b1]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripts python: Add initial script file with usage
  information (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4429c9cde5]
* Mon Jan 15 2024 tonyj@suse.de
- perf doc: Fix typo in perf.data-file-format.txt (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 35e38d6c0e]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Include data symbols in the kernel map (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d02c363b38]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbols: Add kallsyms__get_symbol_start() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9400fead21]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove ABORT_ON (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 798ab83ec4]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Improve location for add pmu (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 132c1c0378]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Populate error column for BPF/tracepoint
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 740e0393b1]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Additional error reporting (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9b315af3c9]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Separate ENOMEM memory handling (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9aaa200566]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Move instances of YYABORT to YYNOMEM
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f3f2a70871]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Separate YYABORT and YYNOMEM cases (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d278792d0e]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-event: Add memory allocation test for name terms
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6781c9c272]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Define YYNOMEM as YYNOABORT for bison < 3.81
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3f3647fb06]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid regrouped warning for wild card events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c8961bc71f]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Add more comments to 'struct
  parse_events_state' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d0cd854b85]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove two unused tokens (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8dd80870fb]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove unused PE_KERNEL_PMU_EVENT token
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cdd205ae8d]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove unused PE_PMU_EVENT_FAKE token
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6fb9d24f8f]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Add LTO build option (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 157d756fc1]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Avoid weak symbol for arch_tests (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit dd1a0d9743]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid use uninitialized warning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6084ec4da3]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Avoid uninitialized use of perf_stat_config
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9cd92d7509]
* Mon Jan 15 2024 tonyj@suse.de
- perf diff: Replaces some ',' as separator with the more usual
  ';' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ab6852bf82]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe trace_printk: Add entry attaching an BPF
  program that does a trace_printk (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 00bc64d05c]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe empty: Add entry attaching an empty BPF
  program (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 89e1340d54]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe: Show diff to previous (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1aeff544d1]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe: Print diff to baseline (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 446e7482db]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench uprobe: Add benchmark to test uprobe overhead
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1f8707dd71]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Free thread_trace->files table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit da19de6ead]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Really free the evsel->priv area (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2993497b9a]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Register a thread priv destructor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 93ac76a970]
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Allow tools to register a thread->priv destructor
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 93e33d15bd]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Free evsel->filter on the destructor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e9d4b49b74]
* Mon Jan 15 2024 tonyj@suse.de
- perf: tests: Adapt mmap-basic.c for riscv (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c2bb6ed346]
* Mon Jan 15 2024 tonyj@suse.de
- perf/benchmark: add a new benchmark for seccom_unotify
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fc645683ff]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Don't display zero tool counts (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b68b4e1d42]
* Mon Jan 15 2024 tonyj@suse.de
- perf test parse-events: Test complex name has required event
  format (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 18b6f6f49c]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Create placholder regardless of scanning core_only
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 824dd52f88]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Only move force grouped evsels when sorting
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e571e492b4]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: When fixing group leaders always set the
  leader (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 24f6cf3205]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Extra care around force grouped events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c261037a11]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain powerpc: Fix addr location init during
  arch_skip_callchain_idx function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit f46254b49f]
* Mon Jan 15 2024 tonyj@suse.de
- perf test task_exit: No need for a cycles event to check if we
  get an PERF_RECORD_EXIT (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69c53b4f75]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid SEGV if PMU lookup fails for legacy
  cache terms (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 967f85c143]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events amd: Fix large metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f7934d3dbe]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix event parsing test when
  PERF_PMU_CAP_EXTENDED_HW_TYPE isn't supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit eac3b7c160]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix event parsing test on Arm (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 860ce1c291]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel amd: Fix IBS error message (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit b6c5816706]
* Mon Jan 15 2024 tonyj@suse.de
- perf: unwind: Fix symfs with libdw (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e92eee0118]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol: Fix uninitialized return value in
  symbols__find_by_name() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 67c3e57f88]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Test perf lock contention CSV output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 17e62453dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Add --output option (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ca6039eedc]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock contention: Add -x option for CSV style output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 852da33d5e]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock: Remove stale comments (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 5ed2a0aee7]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake to 1.13 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b5674e5c6f]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update skylakex to 1.31 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 498c3d7100]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update skylake to 57 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit beb7cfbd15]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids to 1.14
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 026c1f94bd]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex to 1.21 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 69c8b711af]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update icelake to 1.19 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ce1d713085]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex to 1.19 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d2c9768332]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake to 1.03 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4b3394143e]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add rocketlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cabf260303]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor metrics intel: Make transaction metrics conditional
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 477ca775f8]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Support for has_event function (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b2b67026cd]
* Mon Jan 15 2024 tonyj@suse.de
- perf expr: Add has_event function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit a31bae311e]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Do not remove addr_location.thread in
  thread__find_map() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8e7e86c65a]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Add placeholder core PMU (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 00b039ca08]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix a compile error on pe-file-parsing.c (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 881d4e7e76]
* Mon Jan 15 2024 tonyj@suse.de
- perf: Replace deprecated -target with --target= for Clang
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2189990418]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Correct auto_merge_stats test (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 1e11f89597]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add missing else to cmd_daemon subcommand condition
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit dc6b89e4f3]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add printing perf_event_attr config symbol
  in perf_event_attr__fprintf() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit cb0ef653bb]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Add printing perf_event_attr type symbol
  in perf_event_attr__fprintf() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 9ab5751562]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Extend PRINT_ATTRf to support printing of members
  with a value of 0 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4ccff222cf]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace-event-info: Add tracepoint_id_to_name() helper
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7e21a5a4a2]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol: Remove now unused symbol_conf.sort_by_name
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ae8788c9a1]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol: Remove symbol_name_rb_node (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 97b8927d1a]
* Mon Jan 15 2024 tonyj@suse.de
- perf dso: Sort symbols under lock (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8bbc18a8f0]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Filter out BTF sources without a .BTF section
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 57d8481a2a]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add build tests for BUILD_BPF_SKEL (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 865097951b]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Add ability to build with a generated vmlinux.h
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/perf-bpf-Move-the-declaration-of-struct-rq.patch.
  Relevant changes:
- Refresh patch: patches.suse/perf-bpf-Move-the-declaration-of-struct-rq.patch
  perf bpf: Move the declaration of struct rq
  (bsc#1012628)
- Add patch: patches.suse/perf-build-Add-ability-to-build-with-a-generated-vmlinux.h.patch
  perf build: Add ability to build with a generated vmlinux.h
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121))
  [kernel-source commit 8909076c3b]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Skip metrics w/o event name in stat STD output linter
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cb6b3730af]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Reorder event name checks in stat STD output linter
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ab4c0d4d2c]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove a hard coded cpu PMU assumption (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b7c7177215]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Add notion of default PMU for JSON events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 57493c5230]
* Mon Jan 15 2024 tonyj@suse.de
- perf unwind: Fix map reference counts (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 39f9261ba8]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Initialize buffer for regs_map() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2f8c7b2e3c]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Fix test_arm_callgraph_fp variable expansion
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 06b948dcb1]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol: Add LoongArch case in get_plt_sizes() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bc7105000e]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Rerun failed metrics with longer workload (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6987dcf5dd]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add skip list for metrics known would fail (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f220a2c969]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add metric value validation test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e8e2796c61]
* Mon Jan 15 2024 tonyj@suse.de
- perf jit: Fix incorrect file name in DWARF line table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4cd572deda]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Fix instruction association and parsing for
  LoongArch (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5f83059a65]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotation: Switch lock from a mutex to a sharded_mutex
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5bd403f9c5]
* Mon Jan 15 2024 tonyj@suse.de
- perf sharded_mutex: Introduce sharded_mutex (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3752c3890a]
* Mon Jan 15 2024 tonyj@suse.de
- tools: Fix incorrect calculation of object size by sizeof
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d064c1a0bb]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove unneeded semicolon (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0c655230a9]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse: Add missing newline to pr_debug message in
  evsel__compute_group_pmu_name() (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e88289d4ef]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Add missing newline in pr_err messages (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2fb62424c4]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Check if we can encode the PMU number in
  perf_event_attr.type (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c943448459]
* Mon Jan 15 2024 tonyj@suse.de
- perf print-events: Export is_event_supported() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f010e6a933]
* Mon Jan 15 2024 tonyj@suse.de
- perf test record+probe_libc_inet_pton.sh: Use "grep -F" instead
  of obsolescent "fgrep" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c779851538]
* Mon Jan 15 2024 tonyj@suse.de
- perf mem: Scan all PMUs instead of just core ones (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c6bb83f369]
* Mon Jan 15 2024 tonyj@suse.de
- perf mem amd: Fix perf_pmus__num_mem_pmus() (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 19d39346a7]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Describe semantics of 'core_pmus' and 'other_pmus'
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 87aa8ff572]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Show average value on multiple runs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1f24ba0f7e]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: fix failing test cases on linux-next for s390
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f8fe177797]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Work with vmlinux outside symfs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8e68013e65]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add default tags for Hisi hip08 L1
  metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit be431bdc26]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add test case for the standard 'perf stat' output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0936269e20]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Move all the check functions of stat CSV output to
  lib (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b325dd9e8a]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: New metricgroup output for the default mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8ed29d18ee]
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Sort the Default metricgroup (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d9519a3854]
* Mon Jan 15 2024 tonyj@suse.de
- pert tests: Update metric-value for perf stat JSON output
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a49ab6b0ea]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat,jevents: Introduce Default tags for the default mode
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 86bd5d8477]
* Mon Jan 15 2024 tonyj@suse.de
- perf metric: JSON flag to default metric group (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e1df18d83e]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Fix the annotation for hardware events on hybrid
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c3bb04c348]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Fix handling of inline functions (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9aceeced72]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Add a timeout to reading from addr2line (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6eb5ec9985]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add default tags into topdown L1
  metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c9f1c6a7f3]
* Mon Jan 15 2024 tonyj@suse.de
- pert tests: Support metricgroup perf stat JSON output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8d3d8b722e]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests task_analyzer: Print command that failed instead
  of just "perf" (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7b390c0a52]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+shadow_stat.sh: Fix all POSIX sh warnings
  found using shellcheck (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ba71f6375e]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests test_brstack.sh: Fix all POSIX sh warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 645bbaadeb]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests shell: Fixed shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4441ed1ba2]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests lock_contention: Fix shellscript errors (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ea982efb41]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests test_arm_spe: Address shellcheck warnings about
  signal name case (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9bd8507c24]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests test_task_analyzer: Fix shellcheck issues (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/perf-tests-task_analyzer-Skip-tests-if-no-libtr.patch.
  [kernel-source commit 901121394e]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat_all_metrics: Fix shellcheck warning SC2076
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 608c758f1b]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests test_arm_coresight: Shellcheck fixes (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 14b9ae3109]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+csv_output: Fix shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 27d3fe1cf7]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests daemon: Address shellcheck warnings (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 38574b9c4a]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests arm_callgraph_fp: Address shellcheck warnings about
  signal names and adding double quotes for expression (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b14127e1b3]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests stat+json_output: Address shellcheck warnings
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2ee8e59a4a]
* Mon Jan 15 2024 tonyj@suse.de
- perf python scripting: Get rid of unused import in
  arm-cs-trace-disasm (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 682d0c2873]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid string for PE_BP_COLON, PE_BP_SLASH
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ecb38c4a13]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Make sentinel reading for binutils addr2line
  more robust (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b74c9b96ea]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Make addr2line configuration failure more verbose
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 98f283451c]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Make x86 new instructions test optional at build
  time (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 89d38eaf42]
* Mon Jan 15 2024 tonyj@suse.de
- perf dwarf-aux: Allow unnamed struct/union/enum (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 04a8fdb46b]
* Mon Jan 15 2024 tonyj@suse.de
- perf pfm: Remove duplicate util/cpumap.h include (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3e893e1984]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Allow whitespace between insn operands (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6f798c7687]
* Mon Jan 15 2024 tonyj@suse.de
- perf inject: Lazily allocate guest_event event_buf (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a66442a352]
* Mon Jan 15 2024 tonyj@suse.de
- perf inject: Lazily allocate event_copy (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit dbf073a8a8]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Remove some large stack allocations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit aafcab9f61]
* Mon Jan 15 2024 tonyj@suse.de
- perf sched: Avoid large stack allocations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5e6c0c2f47]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench sched messaging: Free contexts on exit (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ceb61ab7a6]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench futex: Avoid memory leaks from pthread_attr
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1bbe027261]
* Mon Jan 15 2024 tonyj@suse.de
- perf bench epoll: Fix missing frees/puts on the exit path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 99938a2790]
* Mon Jan 15 2024 tonyj@suse.de
- perf help: Ensure clean_cmds is called on all paths (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3f75f6e3e1]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Add exception level consistency check (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 68182e9bb9]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Track exception level (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 5b148837b9]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Make PID format accessible from struct
  cs_etm_auxtrace (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7fc2deab0a]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Use previous thread for branch sample source IP
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fe8ccf6621]
* Mon Jan 15 2024 tonyj@suse.de
- perf cs-etm: Only track threads instead of PID and TIDs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d9331cfb99]
* Mon Jan 15 2024 tonyj@suse.de
- perf map: Fix double 'struct map' reference free found with
  - DREFCNT_CHECKING=1 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit aeff8890ac]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Optimize comparision against SRCLINE_UNKNOWN
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9d0d6f0e6e]
* Mon Jan 15 2024 tonyj@suse.de
- perf hist: Fix srcline memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 78b81a2435]
* Mon Jan 15 2024 tonyj@suse.de
- perf srcline: Change free_srcline to zfree_srcline (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d660f60966]
* Mon Jan 15 2024 tonyj@suse.de
- perf callchain: Use pthread keys for tls callchain_cursor
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6f9929faf5]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Avoid out-of-bounds read (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 987a9122be]
* Mon Jan 15 2024 tonyj@suse.de
- perf top: Add exit routine for main thread (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 40eb9ff6ef]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Fix parse_objdump_line memory leak (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4ecabecb49]
* Mon Jan 15 2024 tonyj@suse.de
- perf map/maps/thread: Changes to reference counting (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9719672f9a]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Don't leak module maps (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit a4a8e8bfc2]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Fix leak of kernel dso (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit dcc8817f9f]
* Mon Jan 15 2024 tonyj@suse.de
- perf maps: Fix overlapping memory leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 71fa1e996e]
* Mon Jan 15 2024 tonyj@suse.de
- perf symbol-elf: Correct holding a reference (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 954c5d6b27]
* Mon Jan 15 2024 tonyj@suse.de
- perf jit: Fix two thread leaks (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit b9af627bbd]
* Mon Jan 15 2024 tonyj@suse.de
- perf python: Avoid 2 leak sanitizer issues (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0251caa385]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Free stats in all evlist destruction (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 76ed56e69b]
* Mon Jan 15 2024 tonyj@suse.de
- perf intel-pt: Fix missed put and leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 7f8d6305af]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Avoid evlist leak (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 663b2e97af]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Ensure bitmaps are freed (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit bd976935fb]
* Mon Jan 15 2024 tonyj@suse.de
- perf report: Avoid 'parent_thread' thread leak on '--tasks'
  processing (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2999510ab4]
* Mon Jan 15 2024 tonyj@suse.de
- perf machine: Make delete_threads part of machine__exit
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bed0f39d36]
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Add reference count checking (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2cc11939b5]
* Mon Jan 15 2024 tonyj@suse.de
- perf addr_location: Add init/exit/copy functions (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch.
  Relevant changes:
- Refresh patch: patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch
  Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628)
- Add patch: patches.suse/perf-addr_location-Add-init-exit-copy-functions.patch
  perf addr_location: Add init/exit/copy functions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121))
  [kernel-source commit 325f16fee3]
* Mon Jan 15 2024 tonyj@suse.de
- perf addr_location: Move to its own header (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5dca2fc172]
* Mon Jan 15 2024 tonyj@suse.de
- perf maps: Make delete static, always use put (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1824c3bf2b]
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Add accessor functions for thread (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3cbaaae613]
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Make threads rbtree non-invasive (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh
  patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch.
  [kernel-source commit 94d9b89d35]
* Mon Jan 15 2024 tonyj@suse.de
- perf thread: Remove notion of dead threads (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 462a1157b7]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add test of libpfm4 events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit be70ae237f]
* Mon Jan 15 2024 tonyj@suse.de
- perf list: Check arguments to show libpfm4 events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ddb86c8f1f]
* Mon Jan 15 2024 tonyj@suse.de
- perf list: Check if libpfm4 event is supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d752ac86e8]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse: Allow config terms with breakpoints (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit aeebde475b]
* Mon Jan 15 2024 tonyj@suse.de
- tools headers: Make the difference output easier to read
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 584de64d8c]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Remove x86 instructions with suffix (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2749b03e09]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Handle x86 instruction suffix generally
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4d5f42524d]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Document --metric-no-threshold and threshold colors
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 23c69cfb2c]
* Mon Jan 15 2024 tonyj@suse.de
- perf expr: Make the evaluation of & and | logical and lazy
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 66d5a8869e]
* Mon Jan 15 2024 tonyj@suse.de
- perf LoongArch: Simplify mksyscalltbl (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 92ebc4e4a3]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm64: Use max_nr to define SYSCALLTBL_ARM64_MAX_ID
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b65cb81868]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm64: Handle __NR3264_ prefixed syscall number (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b306f3ec07]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm64: Rename create_table_from_c() to create_sc_table()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e37f26b599]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Declare syscalltbl_* as const for all archs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 32548d9454]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Increase PID/TID width for output (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 771b5c927d]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Warn about invalid config for all PMUs and configs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d4143adf22]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Only warn about unsupported formats once (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 948d7b2ae8]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Update parse-events expectations to test for multiple
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3723e9b086]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Wildcard most "numeric" events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bcb5c8f5d5]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Add verbose 3 print of evsel name when opening
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 15378ed423]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Correct perf_pmu__auto_merge_stats() affecting hybrid
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 40888dd48f]
* Mon Jan 15 2024 tonyj@suse.de
- perf kvm powerpc: Add missing rename opf pmu_have_event() to
  perf_pmus__have_event() (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8c1fe2cadd]
* Mon Jan 15 2024 tonyj@suse.de
- perf test pmu: Avoid 2 static path arrays (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f2df65bbe8]
* Mon Jan 15 2024 tonyj@suse.de
- perf scripting-engines: Move static to local variable, remove
  16384 from .bss (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5a64cc0df9]
* Mon Jan 15 2024 tonyj@suse.de
- perf path: Make mkpath thread safe, remove 16384 bytes from .bss
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6deb9854f2]
* Mon Jan 15 2024 tonyj@suse.de
- perf probe: Dynamically allocate params memory (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9e42b97e12]
* Mon Jan 15 2024 tonyj@suse.de
- perf timechart: Make large arrays dynamic (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7707ebca41]
* Mon Jan 15 2024 tonyj@suse.de
- perf lock: Dynamically allocate lockhash_table (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9dbd53a804]
* Mon Jan 15 2024 tonyj@suse.de
- perf daemon: Dynamically allocate path to perf (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cc52a326c6]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace beauty: Make MSR arrays const to move it to
  .data.rel.ro (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 09205cea72]
* Mon Jan 15 2024 tonyj@suse.de
- perf trace: Make some large static arrays const to move it to
  .data.rel.ro (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 455ee1c1f5]
* Mon Jan 15 2024 tonyj@suse.de
- perf test x86: intel-pt-test data is immutable so mark it const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8003a37717]
* Mon Jan 15 2024 tonyj@suse.de
- perf test x86: insn-x86 test data is immutable so mark it const
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4b4ccd39ff]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Make nodes dynamic in write_mem_topology()
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7e09edd7db]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Don't let evsel__group_pmu_name() traverse unsorted
  group (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f17ed2d8e8]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove is_pmu_hybrid (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 411a4b2db6]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Remove perf_pmus__has_hybrid (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8381641fdf]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Add function to return count of core PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0274fe1e33]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Ensure all PMUs are read for find_by_type (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 71ab7fb1ff]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Avoid repeated sysfs scanning (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 24f30900b7]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Allow just core PMU scanning (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit e00598fdc5]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Split pmus list into core and other (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cc3237f3f4]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Separate pmu and pmus (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 917eedd157]
* Mon Jan 15 2024 tonyj@suse.de
- perf x86 mem: minor refactor to is_mem_loads_aux_event
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6cf9b61bd7]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmus: Prefer perf_pmu__scan over perf_pmus__for_each_pmu
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ab22c7796f]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove perf_pmu__hybrid_pmus list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a816f308b8]
* Mon Jan 15 2024 tonyj@suse.de
- perf mem: Avoid hybrid PMU list (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit ce6f709758]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Avoid hybrid PMU list (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 5148f1f3fa]
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Remove perf_pmu__is_hybrid use (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 48d028cf54]
* Mon Jan 15 2024 tonyj@suse.de
- perf header: Avoid hybrid PMU list in write_pmu_caps (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0546cfda92]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Compute is_hybrid from PMU being core (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit eaab52bcf1]
* Mon Jan 15 2024 tonyj@suse.de
- perf topology: Avoid hybrid list for hybrid topology (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 38fecfd6be]
* Mon Jan 15 2024 tonyj@suse.de
- perf x86: Iterate hybrid PMUs as core PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3854d13406]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Rewrite perf_pmu__has_hybrid to avoid list (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7782465490]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Remove perf_pmu__hybrid_mounted (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 258320c3ca]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Reduce scope of evlist__has_hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b02b22b8ec]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Remove __evlist__add_default (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9fb8d1aa6f]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Remove evlist__warn_hybrid_group (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2ff2a37460]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools: Warn if no user requested CPUs match PMU's CPUs
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 877db920dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf target: Remove unused hybrid value (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 93b8f281cb]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Allow has_user_cpus to be set on hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1bb5c3846d]
* Mon Jan 15 2024 tonyj@suse.de
- perf evlist: Propagate user CPU maps intersecting core PMU maps
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c3b0707d96]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Add CPU map for "cpu" PMUs (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 0ac0971375]
* Mon Jan 15 2024 tonyj@suse.de
- perf evsel: Add is_pmu_core inorder to interpret own_cpus
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 41e0ce0c4b]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Add is_core to pmu (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit f196c10dcd]
* Mon Jan 15 2024 tonyj@suse.de
- perf pmu: Detect ARM and hybrid PMUs with sysfs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit edfd5f97c7]
* Mon Jan 15 2024 tonyj@suse.de
- libperf cpumap: Add "any CPU"/dummy test function (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit bf53996e96]
* Mon Jan 15 2024 tonyj@suse.de
- perf cpumap: Add equal function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit b9c32e56bb]
* Mon Jan 15 2024 tonyj@suse.de
- perf cpumap: Add internal nr and cpu accessors (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0635c86adb]
* Mon Jan 15 2024 tonyj@suse.de
- perf test python: Put perf python at start of sys.path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 92df2a7021]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix perf stat JSON output test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit eaab1ad39e]
* Mon Jan 15 2024 tonyj@suse.de
- perf tests: Organize cpu_map tests into a single suite
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f70d32e358]
* Mon Jan 15 2024 tonyj@suse.de
- perf cpumap: Add intersect function (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 266b3a811c]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add metricgroup descriptions for
  all models (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c458091725]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Add support for metricgroup descriptions
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e68f07a7b0]
* Mon Jan 15 2024 tonyj@suse.de
- pert tests: Add tests for new "perf stat --per-cache"
  aggregation option (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5679132ad5]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Add "--per-cache" aggregation option and document it
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0e4c4cc349]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat record: Save cache level information (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ee0d935e31]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Setup the foundation to allow aggregation based on
  cache topology (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 714b4fa41d]
* Mon Jan 15 2024 tonyj@suse.de
- perf: Extract building cache level for a CPU into separate
  function (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 67e758be4f]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e427c1881b]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update snowridgex events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit df227deeaf]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update skylake/skylakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 754746d369]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0cab3efdb5]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update sandybridge metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a97ca55f0a]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update jaketown metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 09c4102569]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update ivybridge/ivytown metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5de6994e82]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update icelake/icelakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b248301a8c]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update haswell(x) metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 8bdb8a4f55]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update elkhartlake events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d08d8e5ef1]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1691e456f6]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update broadwell variant
  events/metrics (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cd8388935f]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake events/metrics
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c0be447bb9]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add test validating JSON generated by 'perf data
  convert --to-json' (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit d4500ad592]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events arm64: Add AmpereOne core PMU events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b7edad4d9b]
* Mon Jan 15 2024 tonyj@suse.de
- perf ftrace: Flush output after each writing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 92c62afe9e]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate browser: Add '<' and '>' keys for navigation
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 591e66a210]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Parse x86 SIB addressing properly (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f8ef624906]
* Mon Jan 15 2024 tonyj@suse.de
- perf annotate: Handle "decq", "incq", "testq", "tzcnt"
  instructions on x86 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 6879ae6cce]
* Mon Jan 15 2024 tonyj@suse.de
- perf doc: Add support for KBUILD_BUILD_TIMESTAMP (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9b377cea61]
* Mon Jan 15 2024 tonyj@suse.de
- perf doc: Define man page date when using asciidoctor (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3b3269bcec]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add cputype testing to perf stat (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit eaedbc3ff7]
* Mon Jan 15 2024 tonyj@suse.de
- perf build: Don't use -ftree-loop-distribute-patterns and
  - gno-variable-location-views in the python feature test when
  building with clang-13 (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ef26da0913]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Reduce scope of is_event_supported (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 1713ac0a61]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Don't disable TopdownL1 metric on hybrid (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f1da0e1002]
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Be PMU specific in event match (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 97abf2b9b6]
* Mon Jan 15 2024 tonyj@suse.de
- perf jevents: Don't rewrite metrics across PMUs (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f2eb9467aa]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Correct alderlake metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 949504ad76]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Command line PMU metric filtering (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2f3b436da6]
* Mon Jan 15 2024 tonyj@suse.de
- perf metrics: Be PMU specific for referenced metrics (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
- Refresh patches.suse/perf-metric-Fix-no-group-check.patch.
  [kernel-source commit 95a6d4bff2]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Don't reorder atom cpu events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9b6e46dbef]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Don't auto merge hybrid wildcard events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f9964ff6dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid error when assigning a legacy cache
  term (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 5d58e490e7]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid error when assigning a term (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 7f55bff4e7]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Support hardware events as terms (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit b859f4a6ed]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Fix parse-events tests for >1 core PMU (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cd165abf59]
* Mon Jan 15 2024 tonyj@suse.de
- perf stat: Make cputype filter generic (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit a4736532de]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Add pmu filter (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit fe4e1ed0fd]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Minor type safety cleanup (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 44dde8413c]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Remove now unused hybrid logic (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f95c058a20]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Support wildcards on raw events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 64294d175f]
* Mon Jan 15 2024 tonyj@suse.de
- perf print-events: Print legacy cache events for each PMU
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit cdac5e2dc4]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Wildcard legacy cache events (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 4543812587]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Support PMUs for legacy cache events
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3b03cfba1b]
* Mon Jan 15 2024 tonyj@suse.de
- perf test x86 hybrid: Add hybrid extended type checks (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9cb29223b8]
* Mon Jan 15 2024 tonyj@suse.de
- perf test x86 hybrid: Update test expectations (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 3a68faac8a]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Move x86 hybrid tests to arch/x86 (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2398b6ff80]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Avoid scanning PMUs before parsing (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f7561abeaa]
* Mon Jan 15 2024 tonyj@suse.de
- perf print-events: Avoid unnecessary strlist (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit fba839210c]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Set pmu_name whenever a pmu is given
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9f5ca12711]
* Mon Jan 15 2024 tonyj@suse.de
- perf parse-events: Set attr.type to PMU type early (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c5551867dc]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Roundtrip name, don't assume 1 event per name
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 0cebcef96f]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Test more with config_cache (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 6079b88397]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Mask configs with extended types then test (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit ef88819e18]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Use valid for PMU tests (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit b1555741da]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Test more sysfs events (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8f7bca4369]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add tigerlake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 2b7f15f317]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add sapphirerapids metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c4a95be29a]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add icelakex metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9cae9590c4]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add icelake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit c812be1cf7]
* Mon Jan 15 2024 tonyj@suse.de
- perf vendor events intel: Add alderlake metric constraints
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a6c27a6a56]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Refine printing of dso offset (dsoff) (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 9e572ac335]
* Mon Jan 15 2024 tonyj@suse.de
- perf dso: Declare dso const as needed (perf-v6.7 (jsc#PED-6012
  jsc#PED-6121)).
  [kernel-source commit 8b39076fb2]
* Mon Jan 15 2024 tonyj@suse.de
- perf script: Add new output field 'dsoff' to print dso offset
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit a3f48d3e42]
* Mon Jan 15 2024 tonyj@suse.de
- perf map: Add helper map__fprintf_dsoname_dsoff (perf-v6.7
  (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 647db20111]
* Mon Jan 15 2024 tonyj@suse.de
- perf tools riscv: Add support for riscv lookup_binutils_path
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit f6ffa6a115]
* Mon Jan 15 2024 tonyj@suse.de
- perf arm-spe: Fix a dangling Documentation/arm64 reference
  (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit 264338ee2f]
* Mon Jan 15 2024 tonyj@suse.de
- perf test: Add selftest to test IBS invocation via core pmu
  events (perf-v6.7 (jsc#PED-6012 jsc#PED-6121)).
  [kernel-source commit e89002d14d]
* Wed Jan  3 2024 tonyj@suse.com
- Drop "Requires: kernel >= 2.6.31" (jsc#PED-7261)
  This requirement is pretty much guaranteed at this point and
  needs to be dropped to support container installation.
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Update PMC used in PM_RUN_INST_CMPL event
  for power10 platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit 12710f5acb]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-3594,
  jsc#PED-5091).
  [kernel-source commit 8280d00df7]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Update metric events for power10 platform
  (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit f562fceb7b]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Update metric event names for power10
  platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit 79bf288c69]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Update JSON/events for power10 platform
  (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit f6f80190ef]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Move JSON/events to appropriate files for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit 24f680c7b9]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Drop STORES_PER_INST metric event for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit bb1cc55451]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Drop some of the JSON/events for power10
  platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit b1e46118df]
* Tue Jan  2 2024 tonyj@suse.de
- perf vendor events: Update the JSON/events descriptions for
  power10 platform (jsc#PED-3594, jsc#PED-5091).
  [kernel-source commit d72e483852]
* Tue Dec  5 2023 tonyj@suse.de
- Delete patches.suse/perf_timechart_fix_zero_timestamps.patch
  Unclear why it was originally added, no BZ reference/etc. No response to 2017
  request for update. No timely response to 2023 request. Deleting.
  [kernel-source commit 8c9e160c0f]
* Thu Nov  2 2023 nmorey@suse.com
- perf beauty: Update copy of linux/socket.h with the kernel sources (bsc#1216396)
  [kernel-source commit 9c84033f24]
* Thu Nov  2 2023 nmorey@suse.com
- perf trace: fix MSG_SPLICE_PAGES build error (bsc#1216396)
  [kernel-source commit af42c7b1b5]
* Thu Nov  2 2023 nmorey@suse.com
- net: Kill MSG_SENDPAGE_NOTLAST (bsc#1216396)
  [kernel-source commit dbaaf080da]
* Thu Sep 14 2023 tiwai@suse.de
- Sort all patches and clean up reverts/corrections
  For making easier to backport patches via git-fixes tracking, move
  all patches in patches.kernel.org/* into sorted section in
  patches.suse/*.   It essentially means that our kernel is a pot
  stewing all different fixes of our own choices, including the patches
  Relevant changes:
- Delete patch: patches.kernel.org/6.4.10-026-perf-pmu-arm64-Fix-reading-the-PMU-cpu-slots-i.patch
  perf pmu arm64: Fix reading the PMU cpu slots in sysfs
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.10-044-perf-test-uprobe_from_different_cu-Skip-if-the.patch
  perf test uprobe_from_different_cu: Skip if there is no gcc
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.12-130-x86-retpoline-kprobes-Skip-optprobe-check-for-.patch
  x86/retpoline,kprobes: Skip optprobe check for indirect jumps
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.12-230-Revert-perf-report-Append-inlines-to-non-DWARF.patch
  Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-442-perf-evsel-Don-t-let-for_each_group-treat-the-h.patch
  perf evsel: Don't let for_each_group() treat the head of the
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-451-perf-bench-Add-missing-setlocale-call-to-allow-.patch
  perf bench: Add missing setlocale() call to allow usage of
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-462-perf-script-Fix-allocation-of-evsel-priv-relate.patch
  perf script: Fix allocation of evsel->priv related to
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-466-perf-dwarf-aux-Fix-off-by-one-in-die_get_varnam.patch
  perf dwarf-aux: Fix off-by-one in die_get_varname()
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-467-perf-metric-Fix-no-group-check.patch
  perf metric: Fix no group check
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-468-perf-tests-task_analyzer-Fix-bad-substitution-1.patch
  perf tests task_analyzer: Fix bad substitution ${$1}
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-469-perf-tests-task_analyzer-Skip-tests-if-no-libtr.patch
  perf tests task_analyzer: Skip tests if no libtraceevent
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-471-perf-tool-x86-Consolidate-is_amd-check-into-sin.patch
  perf tool x86: Consolidate is_amd check into single function
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-472-perf-tool-x86-Fix-perf_env-memory-leak.patch
  perf tool x86: Fix perf_env memory leak
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-477-perf-stat-Reset-aggr-stats-for-each-run.patch
  perf stat: Reset aggr stats for each run
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-489-perf-test-Set-PERF_EXEC_PATH-for-script-executi.patch
  perf test: Set PERF_EXEC_PATH for script execution
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.4-647-perf-bpf-Move-the-declaration-of-struct-rq.patch
  perf bpf: Move the declaration of struct rq
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.7-012-perf-probe-Add-test-for-regression-introduced-b.patch
  perf probe: Add test for regression introduced by switch to
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.7-013-perf-probe-Read-DWARF-files-from-the-correct-CU.patch
  perf probe: Read DWARF files from the correct CU
  (bsc#1012628)
- Delete patch: patches.kernel.org/6.4.7-146-perf-build-Fix-library-not-found-error-when-usi.patch
  perf build: Fix library not found error when using CSLIBS
  (bsc#1012628)
- Add patch: patches.suse/Revert-perf-report-Append-inlines-to-non-DWARF.patch
  Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628)
- Add patch: patches.suse/perf-bench-Add-missing-setlocale-call-to-allow-.patch
  perf bench: Add missing setlocale() call to allow usage of
  (bsc#1012628)
- Add patch: patches.suse/perf-bpf-Move-the-declaration-of-struct-rq.patch
  perf bpf: Move the declaration of struct rq
  (bsc#1012628)
- Add patch: patches.suse/perf-build-Fix-library-not-found-error-when-usi.patch
  perf build: Fix library not found error when using CSLIBS
  (bsc#1012628)
- Add patch: patches.suse/perf-dwarf-aux-Fix-off-by-one-in-die_get_varnam.patch
  perf dwarf-aux: Fix off-by-one in die_get_varname()
  (bsc#1012628)
- Add patch: patches.suse/perf-evsel-Don-t-let-for_each_group-treat-the-h.patch
  perf evsel: Don't let for_each_group() treat the head of the
  (bsc#1012628)
- Add patch: patches.suse/perf-metric-Fix-no-group-check.patch
  perf metric: Fix no group check
  (bsc#1012628)
- Add patch: patches.suse/perf-pmu-arm64-Fix-reading-the-PMU-cpu-slots-i.patch
  perf pmu arm64: Fix reading the PMU cpu slots in sysfs
  (bsc#1012628)
- Add patch: patches.suse/perf-probe-Add-test-for-regression-introduced-b.patch
  perf probe: Add test for regression introduced by switch to
  (bsc#1012628)
- Add patch: patches.suse/perf-probe-Read-DWARF-files-from-the-correct-CU.patch
  perf probe: Read DWARF files from the correct CU
  (bsc#1012628)
- Add patch: patches.suse/perf-script-Fix-allocation-of-evsel-priv-relate.patch
  perf script: Fix allocation of evsel->priv related to
  (bsc#1012628)
- Add patch: patches.suse/perf-stat-Reset-aggr-stats-for-each-run.patch
  perf stat: Reset aggr stats for each run
  (bsc#1012628)
- Add patch: patches.suse/perf-test-Set-PERF_EXEC_PATH-for-script-executi.patch
  perf test: Set PERF_EXEC_PATH for script execution
  (bsc#1012628)
- Add patch: patches.suse/perf-test-uprobe_from_different_cu-Skip-if-the.patch
  perf test uprobe_from_different_cu: Skip if there is no gcc
  (bsc#1012628)
- Add patch: patches.suse/perf-tests-task_analyzer-Fix-bad-substitution-1.patch
  perf tests task_analyzer: Fix bad substitution ${$1}
  (bsc#1012628)
- Add patch: patches.suse/perf-tests-task_analyzer-Skip-tests-if-no-libtr.patch
  perf tests task_analyzer: Skip tests if no libtraceevent
  (bsc#1012628)
- Add patch: patches.suse/perf-tool-x86-Consolidate-is_amd-check-into-sin.patch
  perf tool x86: Consolidate is_amd check into single function
  (bsc#1012628)
- Add patch: patches.suse/perf-tool-x86-Fix-perf_env-memory-leak.patch
  perf tool x86: Fix perf_env memory leak
  (bsc#1012628)
- Add patch: patches.suse/x86-retpoline-kprobes-Skip-optprobe-check-for-.patch
  x86/retpoline,kprobes: Skip optprobe check for indirect jumps
  (bsc#1012628)
  [kernel-source commit 9491f38eca]
* Thu Aug 24 2023 tiwai@suse.de
- Revert "perf report: Append inlines to non-DWARF callchains"
  (bsc#1012628).
  [kernel-source commit 3d46124eac]
* Thu Aug 24 2023 tiwai@suse.de
- x86/retpoline,kprobes: Skip optprobe check for indirect jumps
  with retpolines and IBT (bsc#1012628).
  [kernel-source commit 162139a579]
* Tue Aug 22 2023 tiwai@suse.de
- Bump to 6.4 kernel (jsc#PED-4593)
  Merge the contents of ALP-current branch as is with keeping the
  downstream fix patches marked with +SP6-NEED-REVIEW tag.
  The 6.4.x stable patches are still in patches.kernel.org.
  Relevant changes:
- Add patch: patches.kernel.org/6.4.10-026-perf-pmu-arm64-Fix-reading-the-PMU-cpu-slots-i.patch
  perf pmu arm64: Fix reading the PMU cpu slots in sysfs
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.10-044-perf-test-uprobe_from_different_cu-Skip-if-the.patch
  perf test uprobe_from_different_cu: Skip if there is no gcc
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-442-perf-evsel-Don-t-let-for_each_group-treat-the-h.patch
  perf evsel: Don't let for_each_group() treat the head of the
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-451-perf-bench-Add-missing-setlocale-call-to-allow-.patch
  perf bench: Add missing setlocale() call to allow usage of
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-462-perf-script-Fix-allocation-of-evsel-priv-relate.patch
  perf script: Fix allocation of evsel->priv related to
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-466-perf-dwarf-aux-Fix-off-by-one-in-die_get_varnam.patch
  perf dwarf-aux: Fix off-by-one in die_get_varname()
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-467-perf-metric-Fix-no-group-check.patch
  perf metric: Fix no group check
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-468-perf-tests-task_analyzer-Fix-bad-substitution-1.patch
  perf tests task_analyzer: Fix bad substitution ${$1}
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-469-perf-tests-task_analyzer-Skip-tests-if-no-libtr.patch
  perf tests task_analyzer: Skip tests if no libtraceevent
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-471-perf-tool-x86-Consolidate-is_amd-check-into-sin.patch
  perf tool x86: Consolidate is_amd check into single function
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-472-perf-tool-x86-Fix-perf_env-memory-leak.patch
  perf tool x86: Fix perf_env memory leak
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-477-perf-stat-Reset-aggr-stats-for-each-run.patch
  perf stat: Reset aggr stats for each run
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-489-perf-test-Set-PERF_EXEC_PATH-for-script-executi.patch
  perf test: Set PERF_EXEC_PATH for script execution
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.4-647-perf-bpf-Move-the-declaration-of-struct-rq.patch
  perf bpf: Move the declaration of struct rq
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.7-012-perf-probe-Add-test-for-regression-introduced-b.patch
  perf probe: Add test for regression introduced by switch to
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.7-013-perf-probe-Read-DWARF-files-from-the-correct-CU.patch
  perf probe: Read DWARF files from the correct CU
  (bsc#1012628)
- Add patch: patches.kernel.org/6.4.7-146-perf-build-Fix-library-not-found-error-when-usi.patch
  perf build: Fix library not found error when using CSLIBS
  (bsc#1012628)
- Delete patch: patches.suse/perf-Add-comment-about-current-state-of-PERF_MEM_LVL_-namespace-and-remove-an-extra-line.patch
  perf: Add comment about current state of PERF_MEM_LVL_* namespace and
  (jsc#PED-557)
- Delete patch: patches.suse/perf-Add-irq-and-exception-return-branch-types.patch
  perf: Add irq and exception return branch types
  (jsc#PED-1754 (dependent patch))
- Delete patch: patches.suse/perf-beauty-Update-copy-of-linux-socket.h-with-the-k.patch
  perf beauty: Update copy of linux/socket.h with the kernel sources
  (jsc#PED-612)
- Delete patch: patches.suse/perf-bench-futex-Fix-memory-leak-of-perf_cpu_map__ne.patch
  perf bench futex: Fix memory leak of perf_cpu_map__new()
  (git-fixes)
- Delete patch: patches.suse/perf-bench-inject-buildid-Handle-writen-errors.patch
  perf bench inject-buildid: Handle writen() errors
  (git-fixes stable-5.14.7)
- Delete patch: patches.suse/perf-bpf-Add-missing-free-to-bpf_event__print_bpf_pr.patch
  perf bpf: Add missing free to bpf_event__print_bpf_prog_info()
  (stable-5.14.19)
- Delete patch: patches.suse/perf-bpf-Switch-to-new-btf__raw_data-API.patch
  perf bpf: Switch to new btf__raw_data API
  (jsc#PED-1377)
- Delete patch: patches.suse/perf-config-Fix-caching-and-memory-leak-in-perf_home.patch
  perf config: Fix caching and memory leak in
  (git-fixes stable-5.14.7)
- Delete patch: patches.suse/perf-iostat-Fix-Segmentation-fault-from-NULL-struct-.patch
  perf iostat: Fix Segmentation fault from NULL 'struct perf_counts_values *'
  (stable-5.14.10)
- Delete patch: patches.suse/perf-iostat-Use-system-wide-mode-if-the-target-cpu_l.patch
  perf iostat: Use system-wide mode if the target cpu_list is unspecified
  (stable-5.14.10)
- Delete patch: patches.suse/perf-jevents-Free-the-sys_event_tables-list-after-pr.patch
  perf jevents: Free the sys_event_tables list after processing entries
  (stable-5.14.12)
- Delete patch: patches.suse/perf-machine-Initialize-srcline-string-member-in-add.patch
  perf machine: Initialize srcline string member in add_location struct
  (stable-5.14.7)
- Delete patch: patches.suse/perf-report-Add-tools-arch-x86-include-asm-amd-ibs.h.patch
  perf report: Add tools/arch/x86/include/asm/amd-ibs.h
  (jsc#PED-1755 (dependent patch))
- Delete patch: patches.suse/perf-script-Check-session-header.env.arch-before-usi.patch
  perf script: Check session->header.env.arch before using it
  (stable-5.14.16)
- Delete patch: patches.suse/perf-script-Fix-PERF_SAMPLE_WEIGHT_STRUCT-support.patch
  perf script: Fix PERF_SAMPLE_WEIGHT_STRUCT support
  (stable-5.14.16)
- Delete patch: patches.suse/perf-script-Fix-list-dlfilters-documentation.patch
  perf script: Fix --list-dlfilters documentation
  (git-fixes)
- Delete patch: patches.suse/perf-symbol-Look-for-ImageBase-in-PE-file-to-compute.patch
  perf symbol: Look for ImageBase in PE file to compute .text
  (git-fixes stable-5.14.8)
- Delete patch: patches.suse/perf-test-Fix-DWARF-unwind-for-optimized-builds.patch
  perf test: Fix DWARF unwind for optimized builds.
  (stable-5.14.10)
- Delete patch: patches.suse/perf-test-Fix-bpf-test-sample-mismatch-reporting.patch
  perf test: Fix bpf test sample mismatch reporting
  (git-fixes stable-5.14.8)
- Delete patch: patches.suse/perf-tools-Allow-build-id-with-trailing-zeros.patch
  perf tools: Allow build-id with trailing zeros
  (stable-5.14.8)
- Delete patch: patches.suse/perf-tools-Factor-out-copy_config_terms-and-free_config_terms.patch
  perf tools: Factor out copy_config_terms() and free_config_terms()
  (git-fixes)
- Delete patch: patches.suse/perf-tools-Fix-hybrid-config-terms-list-corruption.patch
  perf tools: Fix hybrid config terms list corruption
  (git-fixes)
- Delete patch: patches.suse/perf-trace-Update-cmd-string-table-to-decode-sys_bpf.patch
  perf trace: Update cmd string table to decode sys_bpf first arg
  (jsc#PED-1377)
- Delete patch: patches.suse/perf-unwind-Do-not-overwrite-FEATURE_CHECK_LDFLAGS-l.patch
  perf unwind: Do not overwrite
  (git-fixes stable-5.14.7)
- Delete patch: patches.suse/tools-Free-BTF-objects-at-various-locations.patch
  tools: Free BTF objects at various locations
  (stable-5.14.4)
- Delete patch: patches.suse/tools-perf-Stop-using-bpf_object__find_program_by_ti.patch
  tools/perf: Stop using bpf_object__find_program_by_title API.
  (jsc#PED-1377)
- Delete patch: patches.suse/x86-insn-Use-get_unaligned-instead-of-memcpy.patch
  x86/insn: Use get_unaligned() instead of memcpy()
  (stable-5.14.19)
  [kernel-source commit d016c04d73]
* Thu Aug 17 2023 tonyj@suse.com
- Switch to source service.
  No longer BuildRequire: kernel-source
  Derive tarball and changes from kernel-source git repository
* Thu Aug 17 2023 tonyj@suse.com
- Merge changes from Factory for initial SLE15-SP6 release
  * Create gtk subpackage (PED-5904)
    Original Factory changelog:
    Wed Nov 24 13:44:08 UTC 2021 Jan Engelhardt <jengelh@inai.de>
    Split gtk portion into separate package (pulls in about 40 packages for
    graphic systems that are not desired on text shells).
  * Create completion subpackage
    Original Factory changelog:
    Fri Oct  7 15:58:23 UTC 2022 - Callum Farmer <gmbr3@opensuse.org>
    Move bash-completion to subpackage so it isn't installed when
  * Enable bpf skel support
    Original Factory changelog:
    Fri Mar 25 17:37:08 UTC 2022 - Tony Jones <tonyj@suse.com>
    Enable bpf skel support.
    This enables shared counter support (--bpf-counters in perf-stat)
  * Use asciidoctor rather than asciidoc
    Original Factory changelog:
    Wed Jan 16 08:48:49 CET 2019 - tiwai@suse.de
    Build with asciidoctor instead of asciidoc (bsc#1075764)
  * Skip info file generation (causes make error)
    Original Factory changelog
    Wed Nov  3 10:10:21 UTC 2021 - Jiri Slaby <jslaby@suse.cz>
    skip info files generation which was enabled in 5.15
  * Add additional BuildRequires
  - libtraceevent
  - llvm
- Delete the following upstream patches (SLE15-SP6 kernel rebased to v6.4
    libperf-Add-preadn.patch
    perf-arch-events-riscv-sbi-firmware-std-event-files.patch
    perf-arm-spe-Fix-addresses-of-synthesized-SPE-events.patch
    perf-arm-spe-Fix-perf-report-mem-mode.patch
    perf-bench-Fix-epoll-bench-to-correct-usage-of-affinity-for-machines-with-CPUs-1K.patch
    perf-bench-Fix-futex-bench-to-correct-usage-of-affinity-for-machines-with-CPUs-1K.patch
    perf-bench-Fix-numa-bench-to-fix-usage-of-affinity-for-machines-with-CPUs-1K.patch
    perf-bench-Fix-numa-testcase-to-check-if-CPU-used-to-bind-task-is-online.patch
    perf-bench-Fix-two-memory-leaks-detected-with-ASan.patch
    perf-bench-Fix-two-numa-NDEBUG-warnings.patch
    perf-bench-futex-Group-test-parameters-cleanup.patch
    perf-bpf-Avoid-memory-leak-from-perf_env__insert_btf.patch
    perf-bpf-Defer-freeing-string-after-possible-strlen-on-it.patch
    perf-bpf-Fix-building-perf-with-BUILD_BPF_SKEL-1-by-default-in-more-distros.patch
    perf-bpf_skel-Do-not-use-typedef-to-avoid-error-on-old-clang.patch
    perf-data-Fix-double-free-in-perf_session__delete.patch
    perf-env-Add-perf_env__cpuid-perf_env__-nr_-pmu_mappings.patch
    perf-env-Track-kernel-64-bit-mode-in-environment.patch
    perf-evlist-Allow-setting-arbitrary-leader.patch
    perf-evlist-Always-use-arch_evlist__add_default_attrs.patch
    perf-evlist-Extend-arch_evsel__must_be_in_group-to-support-hybrid-systems.patch
    perf-evlist-Keep-topdown-counters-in-weak-group.patch
    perf-evsel-Add-bitfield_swap-to-handle-branch_stack-endian-issue.patch
    perf-evsel-Fixes-topdown-events-in-a-weak-group-for-the-hybrid-platform.patch
    perf-evsel-Improve-AMD-IBS-Instruction-Based-Sampling-error-handling-messages.patch
    perf-evsel-Improve-error-message-for-uncore-events.patch
    perf-evsel-Make-evsel__env-always-return-a-valid-env.patch
    perf-evsel-Override-attr-sample_period-for-non-libpfm4-events.patch
    perf-evsel-don-t-set-exclude_guest-by-default.patch
    perf-header-Add-ability-to-keep-feature-sections.patch
    perf-header-Pass-cpu-pmu-name-while-printing-caps.patch
    perf-header-Record-non-CPU-PMU-capabilities.patch
    perf-header-Store-PMU-caps-in-an-array-of-strings.patch
    perf-inject-Fix-output-from-a-file-to-a-pipe.patch
    perf-inject-Fix-output-from-a-pipe-to-a-file.patch
    perf-inject-Fix-segfault-due-to-close-without-open.patch
    perf-inject-Fix-segfault-due-to-perf_data__fd-without-open.patch
    perf-inject-Keep-some-features-sections-from-input-file.patch
    perf-intel-pt-Fix-error-timestamp-setting-on-the-decoder-error-path.patch
    perf-intel-pt-Fix-intel_pt_fup_event-assumptions-about-setting-state-type.patch
    perf-intel-pt-Fix-missing-instruction-events-with-q-option.patch
    perf-intel-pt-Fix-next-err-value-walking-trace.patch
    perf-intel-pt-Fix-parsing-of-VM-time-correlation-arguments.patch
    perf-intel-pt-Fix-some-PGE-packet-generation-enable-control-flow-packets-usage.patch
    perf-intel-pt-Fix-state-setting-when-receiving-overflow-OVF-packet.patch
    perf-intel-pt-Fix-sync-state-when-a-PSB-synchronization-packet-is-found.patch
    perf-jevents-Add-support-for-HiSilicon-CPA-PMU-aliasing.patch
    perf-list-Add-IBM-z16-event-description-for-s390.patch
    perf-list-Add-PMU-pai_crypto-event-description-for-IBM-z16.patch
    perf-list-Fix-PMU-name-pai_crypto-in-perf-list-on-s390.patch
    perf-list-Update-event-description-for-IBM-z10-to-latest-level.patch
    perf-list-Update-event-description-for-IBM-z13-to-latest-level.patch
    perf-list-Update-event-description-for-IBM-z14-to-latest-level.patch
    perf-list-Update-event-description-for-IBM-z15-to-latest-level.patch
    perf-list-Update-event-description-for-IBM-z196-z114-to-latest-level.patch
    perf-list-Update-event-description-for-IBM-zEC12-zBC12-to-latest-level.patch
    perf-parse-events-Architecture-specific-leader-override.patch
    perf-parse-events-Ignore-case-in-topdown.slots-check.patch
    perf-parse-events-Move-slots-event-for-the-hybrid-platform-too.patch
    perf-parse-events-Move-slots-only-with-topdown.patch
    perf-parse-events-Support-different-format-of-the-topdown-event-name.patch
    perf-pmu-Parse-pmu-caps-sysfs-only-once.patch
    perf-powerpc-Add-support-to-expose-instruction-and-data-address-registers-as-part-of-extended-regs.patch
    perf-probe-Fix-ppc64-perf-probe-add-events-failed-case.patch
    perf-python-Add-perf_env-stubs-that-will-be-needed-in-evsel__open_strerror.patch
    perf-record-Support-sample-read-topdown-metric-group-for-hybrid-platforms.patch
    perf-record-ibs-Warn-about-sampling-period-skew.patch
    perf-report-Add-support-to-print-a-textual-representation-of-IBS-raw-sample-data.patch
    perf-report-Set-PERF_SAMPLE_DATA_SRC-bit-for-Arm-SPE-event.patch
    perf-script-Always-allow-field-data_src-for-auxtrace.patch
    perf-script-Fix-CPU-filtering-of-a-script-s-switch-events.patch
    perf-script-Fix-hex-dump-character-output.patch
    perf-script-ibs-Support-new-IBS-bits-in-raw-trace-dump.patch
    perf-scripts-python-intel-pt-events.py-Fix-printing-of-switch-events.patch
    perf-session-Remap-buf-if-there-is-no-space-for-event.patch
    perf-stat-Add-topdown-metrics-in-the-default-perf-stat-on-the-hybrid-machine.patch
    perf-stat-Always-keep-perf-metrics-topdown-events-in-a-group.patch
    perf-stat-Fix-display-of-grouped-aliased-events.patch
    perf-stat-Fix-forked-applications-enablement-of-counters.patch
    perf-stat-Support-cputype-option-for-hybrid-events.patch
    perf-stat-Support-hybrid-topdown-option.patch
    perf-symbols-Fix-symbol-size-calculation-condition.patch
    perf-test-Add-basic-stat-and-topdown-group-test.patch
    perf-test-sample-parsing-Add-endian-test-for-struct-branch_flags.patch
    perf-test-sample-parsing-Fix-branch_stack-entry-endianness-check.patch
    perf-tests-Remove-bash-construct-from-record-zstd_comp_decomp.sh.patch
    perf-tests-attr-Add-missing-topdown-metrics-events.patch
    perf-tool-ibs-Sync-AMD-IBS-header-file.patch
    perf-tools-Add-an-option-to-build-without-libbfd.patch
    perf-tools-Fix-SMT-detection-fast-read-path.patch
    perf-tools-Fix-misleading-add-event-PMU-debug-message.patch
    perf-tools-Fix-perf-s-libperf_print-callback.patch
    perf-tools-Pass-a-fd-to-perf_file_header__read_pipe.patch
    perf-tools-Remove-repipe-argument-from-perf_session__new.patch
    perf-vendor-events-Add-Arm-Neoverse-V2-PMU-events.patch
    perf-vendor-events-Add-Intel-meteorlake.patch
    perf-vendor-events-Add-metrics-for-Icelake-Server.patch
    perf-vendor-events-Add-metrics-for-Tigerlake.patch
    perf-vendor-events-Add-missing-Neoverse-V1-events.patch
    perf-vendor-events-Fix-Alderlake-metric-groups.patch
    perf-vendor-events-Fix-Ivytown-UNC_M_ACT_COUNT.RD-umask.patch
    perf-vendor-events-Fix-all-remaining-invalid-JSON-files.patch
    perf-vendor-events-For-the-Arm-Neoverse-N2.patch
    perf-vendor-events-Remove-bad-broadwellde-uncore-events.patch
    perf-vendor-events-Remove-bad-ivytown-uncore-events.patch
    perf-vendor-events-Remove-bad-jaketown-uncore-events.patch
    perf-vendor-events-Rename-arm64-arch-std-event-files.patch
    perf-vendor-events-Syntax-corrections-in-Neoverse-N1-json.patch
    perf-vendor-events-Update-Intel-alderlake-a80de066.patch
    perf-vendor-events-Update-Intel-alderlake-a95ab294.patch
    perf-vendor-events-Update-Intel-broadwell-1775634e.patch
    perf-vendor-events-Update-Intel-broadwell-eb4f8d77.patch
    perf-vendor-events-Update-Intel-broadwellde-d7184d94.patch
    perf-vendor-events-Update-Intel-broadwellde-ef908a19.patch
    perf-vendor-events-Update-Intel-broadwellx-4266081e.patch
    perf-vendor-events-Update-Intel-broadwellx-5bc4e39e.patch
    perf-vendor-events-Update-Intel-cascadelakex-55b201a8.patch
    perf-vendor-events-Update-Intel-cascadelakex-f9d45862.patch
    perf-vendor-events-Update-Intel-elkhartlake.patch
    perf-vendor-events-Update-Intel-haswell-8e6389f9.patch
    perf-vendor-events-Update-Intel-haswell-dd7aae2c.patch
    perf-vendor-events-Update-Intel-haswellx-08ce57dd.patch
    perf-vendor-events-Update-Intel-haswellx-859fe0f4.patch
    perf-vendor-events-Update-Intel-icelake-8fb4ddf4.patch
    perf-vendor-events-Update-Intel-icelake-a4a4353e.patch
    perf-vendor-events-Update-Intel-icelakex-bd035250.patch
    perf-vendor-events-Update-Intel-icelakex-d214d0c2.patch
    perf-vendor-events-Update-Intel-ivybridge-3bd2d211.patch
    perf-vendor-events-Update-Intel-ivybridge-80c14459.patch
    perf-vendor-events-Update-Intel-ivytown-62201368.patch
    perf-vendor-events-Update-Intel-ivytown-d2aaf040.patch
    perf-vendor-events-Update-Intel-jaketown-3405de19.patch
    perf-vendor-events-Update-Intel-jaketown-376d8b58.patch
    perf-vendor-events-Update-Intel-knightslanding.patch
    perf-vendor-events-Update-Intel-nehalemep.patch
    perf-vendor-events-Update-Intel-nehalemex.patch
    perf-vendor-events-Update-Intel-sandybridge-777e1312.patch
    perf-vendor-events-Update-Intel-sandybridge-db35c1dc.patch
    perf-vendor-events-Update-Intel-sapphirerapids-34122105.patch
    perf-vendor-events-Update-Intel-sapphirerapids-9a1b4aa4.patch
    perf-vendor-events-Update-Intel-silvermont.patch
    perf-vendor-events-Update-Intel-skylake-35d65277.patch
    perf-vendor-events-Update-Intel-skylake-aac53e8f.patch
    perf-vendor-events-Update-Intel-skylakex-313b2f38.patch
    perf-vendor-events-Update-Intel-skylakex-59fd7d32.patch
    perf-vendor-events-Update-Intel-snowridgex.patch
    perf-vendor-events-Update-Intel-tigerlake-5e1dd4f2.patch
    perf-vendor-events-Update-Intel-tigerlake-a7c1aaa6.patch
    perf-vendor-events-Update-Intel-westmereep-dp.patch
    perf-vendor-events-Update-Intel-westmereep-sp.patch
    perf-vendor-events-Update-Intel-westmereex.patch
    perf-vendor-events-Update-Knights-Landing.patch
    perf-vendor-events-Update-Nehalem-EP.patch
    perf-vendor-events-Update-Sandybridge.patch
    perf-vendor-events-Update-Silvermont.patch
    perf-vendor-events-Update-Tigerlake.patch
    perf-vendor-events-Update-TremontX.patch
    perf-vendor-events-Update-Westmere-EP-SP.patch
    perf-vendor-events-Update-Westmere-EX.patch
    perf-vendor-events-Update-bonnell-mapfile.csv.patch
    perf-vendor-events-Update-elkhartlake-cpuids.patch
    perf-vendor-events-Update-events-and-metrics-for-broadwellx.patch
    perf-vendor-events-Update-events-and-metrics-for-cascadelakex.patch
    perf-vendor-events-Update-events-and-metrics-for-haswellx.patch
    perf-vendor-events-Update-events-and-metrics-for-icelakex.patch
    perf-vendor-events-Update-events-and-metrics-for-skylakex.patch
    perf-vendor-events-Update-events-for-Neoverse-E1.patch
    perf-vendor-events-Update-events-for-knightslanding.patch
    perf-vendor-events-Update-events-for-snowridgex.patch
    perf-vendor-events-Update-for-Bonnell.patch
    perf-vendor-events-Update-for-Goldmont.patch
    perf-vendor-events-Update-for-GoldmontPlus.patch
    perf-vendor-events-Update-for-Westmere-EP-DP.patch
    perf-vendor-events-Update-goldmont-mapfile.csv.patch
    perf-vendor-events-Update-goldmontplus-mapfile.csv.patch
    perf-vendor-events-Update-metrics-for-Broadwell-DE.patch
    perf-vendor-events-Update-metrics-for-Broadwell.patch
    perf-vendor-events-Update-metrics-for-BroadwellX.patch
    perf-vendor-events-Update-metrics-for-CascadeLake-Server.patch
    perf-vendor-events-Update-metrics-for-CascadelakeX.patch
    perf-vendor-events-Update-metrics-for-Haswell.patch
    perf-vendor-events-Update-metrics-for-HaswellX.patch
    perf-vendor-events-Update-metrics-for-Icelake.patch
    perf-vendor-events-Update-metrics-for-IcelakeX.patch
    perf-vendor-events-Update-metrics-for-Ivybridge.patch
    perf-vendor-events-Update-metrics-for-Ivytown.patch
    perf-vendor-events-Update-metrics-for-Jaketown.patch
    perf-vendor-events-Update-metrics-for-SkyLake-Server-3bad20d7.patch
    perf-vendor-events-Update-metrics-for-SkyLake-Server-c4ad8fab.patch
    perf-vendor-events-Update-metrics-for-Skylake.patch
    perf-vendor-events-Update-metrics-for-broadwellde.patch
    perf-vendor-events-Update-metrics-for-ivytown.patch
    perf-vendor-events-Update-metrics-for-jaketown.patch
    perf-vendor-events-Update-metrics-for-sapphirerapids.patch
    perf-vendor-events-Update-silvermont-cpuids.patch
    perf-vendor-events-amd-Add-Zen-4-core-events.patch
    perf-vendor-events-amd-Add-Zen-4-mapping.patch
    perf-vendor-events-amd-Add-Zen-4-metrics.patch
    perf-vendor-events-amd-Add-Zen-4-uncore-events.patch
    perf-vendor-events-arm64-Add-new-armv8-pmu-events.patch
    perf-vendor-events-arm64-Arm-Cortex-A78C-and-X1C.patch
    perf-vendor-events-arm64-Categorise-the-Neoverse-V1-counters.patch
    perf-vendor-events-arm64-Fix-JSON-indentation-to-4-spaces-standard.patch
    perf-vendor-events-arm64-Fix-incorrect-Hisi-hip08-L3-metrics.patch
    perf-vendor-events-arm64-Move-REMOTE_ACCESS-to-memory-category.patch
    perf-vendor-events-arm64-Revise-hip08-uncore-events.patch
    perf-vendor-events-intel-Add-basic-metrics-for-Elkhartlake.patch
    perf-vendor-events-intel-Add-core-event-list-for-Alderlake-N.patch
    perf-vendor-events-intel-Add-core-event-list-for-Alderlake.patch
    perf-vendor-events-intel-Add-core-event-list-for-Elkhartlake.patch
    perf-vendor-events-intel-Add-core-event-list-for-Tigerlake.patch
    perf-vendor-events-intel-Add-metrics-for-Alderlake-N.patch
    perf-vendor-events-intel-Add-metrics-for-Alderlake.patch
    perf-vendor-events-intel-Add-metrics-for-Sapphirerapids.patch
    perf-vendor-events-intel-Add-sapphirerapids-events.patch
    perf-vendor-events-intel-Add-uncore-event-list-for-Alderlake-N.patch
    perf-vendor-events-intel-Add-uncore-event-list-for-Alderlake.patch
    perf-vendor-events-intel-Add-uncore-event-list-for-Sapphirerapids.patch
    perf-vendor-events-intel-Fix-icelake-cstate-metrics.patch
    perf-vendor-events-intel-Fix-icelakex-cstate-metrics.patch
    perf-vendor-events-intel-Refresh-alderlake-metrics.patch
    perf-vendor-events-intel-Refresh-alderlake-n-metrics.patch
    perf-vendor-events-intel-Refresh-bonnell-events.patch
    perf-vendor-events-intel-Refresh-broadwell-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-broadwellde-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-broadwellx-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-cascadelakex-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-elkhartlake-events.patch
    perf-vendor-events-intel-Refresh-goldmont-events.patch
    perf-vendor-events-intel-Refresh-goldmontplus-events.patch
    perf-vendor-events-intel-Refresh-haswell-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-haswellx-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-icelake-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-icelakex-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-ivybridge-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-ivytown-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-jaketown-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-knightslanding-events.patch
    perf-vendor-events-intel-Refresh-meteorlake-events.patch
    perf-vendor-events-intel-Refresh-nehalemep-events.patch
    perf-vendor-events-intel-Refresh-nehalemex-events.patch
    perf-vendor-events-intel-Refresh-sandybridge-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-sapphirerapids-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-silvermont-events.patch
    perf-vendor-events-intel-Refresh-skylake-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-skylakex-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-snowridgex-events.patch
    perf-vendor-events-intel-Refresh-tigerlake-metrics-and-events.patch
    perf-vendor-events-intel-Refresh-westmereep-dp-events.patch
    perf-vendor-events-intel-Refresh-westmereep-sp-events.patch
    perf-vendor-events-intel-Refresh-westmereex-events.patch
    perf-vendor-events-intel-Rename-tremontx-to-snowridgex.patch
    perf-vendor-events-intel-Update-CLX-events-to-v1.15.patch
    perf-vendor-events-intel-Update-CLX-uncore-to-v1.14.patch
    perf-vendor-events-intel-Update-ICL-events-to-v1.13.patch
    perf-vendor-events-intel-Update-IVT-events-to-v21.patch
    perf-vendor-events-intel-Update-SKL-events-to-v53.patch
    perf-vendor-events-intel-Update-SKX-events-to-v1.27.patch
    perf-vendor-events-intel-Update-SKX-uncore.patch
    perf-vendor-events-intel-Update-WSM-EP-SP-events-to-v3.patch
    perf-vendor-events-intel-Update-WSM-EX-events-to-v3.patch
    perf-vendor-events-intel-Update-core-event-list-for-CascadeLake-Server.patch
    perf-vendor-events-intel-Update-core-event-list-for-Sapphirerapids.patch
    perf-vendor-events-intel-Update-core-event-list-for-SkyLake-Server.patch
    perf-vendor-events-intel-Update-elkhartlake-event-topics.patch
    perf-vendor-events-intel-Update-event-list-for-Alderlake.patch
    perf-vendor-events-intel-Update-event-list-for-Sapphirerapids.patch
    perf-vendor-events-intel-Update-event-list-for-Snowridgex.patch
    perf-vendor-events-intel-Update-event-list-for-broadwellx.patch
    perf-vendor-events-intel-Update-event-list-for-haswellx.patch
    perf-vendor-events-intel-Update-events-and-metrics-for-alderlake.patch
    perf-vendor-events-intel-Update-events-for-CascadelakeX.patch
    perf-vendor-events-intel-Update-events-for-Elkhartlake.patch
    perf-vendor-events-intel-Update-events-for-Icelake.patch
    perf-vendor-events-intel-Update-events-for-IcelakeX.patch
    perf-vendor-events-intel-Update-events-for-Skylake.patch
    perf-vendor-events-intel-Update-events-for-SkylakeX.patch
    perf-vendor-events-intel-Update-events-for-Tigerlake.patch
    perf-vendor-events-intel-Update-events-for-TremontX.patch
    perf-vendor-events-intel-Update-goldmont-event-topics.patch
    perf-vendor-events-intel-Update-goldmontplus-event-topics.patch
    perf-vendor-events-intel-Update-metrics-for-Alderlake.patch
    perf-vendor-events-intel-Update-nehalemep-event-topics.patch
    perf-vendor-events-intel-Update-tigerlake-topic.patch
    perf-vendor-events-intel-Update-tremontx-uncore-and-topics.patch
    perf-vendor-events-intel-Update-uncore-event-list-for-CascadeLake-Server.patch
    perf-vendor-events-intel-Update-uncore-event-list-for-SkyLake-Server.patch
    perf-vendor-events-intel-Update-westmereep-dp-event-topics.patch
    perf-vendor-events-intel-Update-westmereep-sp-event-topics.patch
    perf-vendor-events-intel-Update-westmereex-event-topics.patch
    perf-vendor-events-power10-Add-metric-events-JSON-file-for-power10-platform.patch
    perf-vendor-events-power10-Fix-hv-24x7-metric-events.patch
    perf-vendor-events-powerpc-Fix-spelling-mistake-icach-icache.patch
    perf-vendor-events-riscv-add-Sifive-U74-JSON-file.patch
    perf-vendors-events-arm64-Arm-Cortex-A34.patch
    perf-vendors-events-arm64-Arm-Cortex-A35.patch
    perf-vendors-events-arm64-Arm-Cortex-A510.patch
    perf-vendors-events-arm64-Arm-Cortex-A55.patch
    perf-vendors-events-arm64-Arm-Cortex-A65.patch
    perf-vendors-events-arm64-Arm-Cortex-A710.patch
    perf-vendors-events-arm64-Arm-Cortex-A73.patch
    perf-vendors-events-arm64-Arm-Cortex-A75.patch
    perf-vendors-events-arm64-Arm-Cortex-A77.patch
    perf-vendors-events-arm64-Arm-Cortex-A78.patch
    perf-vendors-events-arm64-Arm-Cortex-X1.patch
    perf-vendors-events-arm64-Arm-Cortex-X2.patch
    perf-vendors-events-arm64-Arm-Neoverse-E1.patch
    perf-vendors-events-arm64-Update-Cortex-A57-A72.patch
    perf-x86-evlist-Add-default-hybrid-events-for-perf-stat.patch
    tools-build-Add-feature-test-for-init_disassemble_info-API-changes.patch
    tools-build-Don-t-display-disassembler-four-args-feature-test.patch
    tools-build-Remove-needless-libpython-version-feature-check-that-breaks-test-all-fast-path.patch
    tools-headers-UAPI-Add-new-macros-for-mem_hops-field-to-perf_event.h.patch
    tools-include-add-dis-asm-compat.h-to-handle-version-differences.patch
    tools-perf-Add-mem_hops-field-in-perf_mem_data_src-structure.patch
    tools-perf-Fix-compilation-error-with-new-binutils.patch
* Mon Jan 30 2023 tonyj@suse.com
- Fix build breakage.  Patch was inadvertently checked into kernel-source
  after being present in userspace (from SP4 Genoa backport).  Drop it.
  Delete patch: perf-report-Add-tools-arch-x86-include-asm-amd-ibs.h.patch
* Thu Jan 19 2023 tonyj@suse.com
- Add topdown support for hybrid PMUs (Alder Lake etc) -- jsc#PED-1069, jsc#PED-810
  New patch: perf-evlist-Allow-setting-arbitrary-leader.patch
  New patch: perf-evlist-Always-use-arch_evlist__add_default_attrs.patch
  New patch: perf-evsel-Fixes-topdown-events-in-a-weak-group-for-the-hybrid-platform.patch
  New patch: perf-parse-events-Architecture-specific-leader-override.patch
  New patch: perf-parse-events-Ignore-case-in-topdown.slots-check.patch
  New patch: perf-parse-events-Move-slots-event-for-the-hybrid-platform-too.patch
  New patch: perf-parse-events-Move-slots-only-with-topdown.patch
  New patch: perf-parse-events-Support-different-format-of-the-topdown-event-name.patch
  New patch: perf-record-Support-sample-read-topdown-metric-group-for-hybrid-platforms.patch
  New patch: perf-stat-Add-topdown-metrics-in-the-default-perf-stat-on-the-hybrid-machine.patch
  New patch: perf-stat-Always-keep-perf-metrics-topdown-events-in-a-group.patch
  New patch: perf-stat-Support-cputype-option-for-hybrid-events.patch
  New patch: perf-stat-Support-hybrid-topdown-option.patch
  New patch: perf-test-Add-basic-stat-and-topdown-group-test.patch
  New patch: perf-x86-evlist-Add-default-hybrid-events-for-perf-stat.patch
  Refresh patch: perf-record-ibs-Warn-about-sampling-period-skew.patch
* Wed Jan 11 2023 tonyj@suse.com
- Power10 perf counter enhancements (jsc#PED-557)
  New patch: perf-bench-Fix-epoll-bench-to-correct-usage-of-affinity-for-machines-with-CPUs-1K.patch
  New patch: perf-bench-Fix-futex-bench-to-correct-usage-of-affinity-for-machines-with-CPUs-1K.patch
  New patch: perf-bench-Fix-two-numa-NDEBUG-warnings.patch
  New patch: perf-bench-futex-Group-test-parameters-cleanup.patch
  New patch: perf-evsel-Add-bitfield_swap-to-handle-branch_stack-endian-issue.patch
  New patch: perf-powerpc-Add-support-to-expose-instruction-and-data-address-registers-as-part-of-extended-regs.patch
  New patch: perf-test-sample-parsing-Add-endian-test-for-struct-branch_flags.patch
  New patch: perf-test-sample-parsing-Fix-branch_stack-entry-endianness-check.patch
  New patch: tools-headers-UAPI-Add-new-macros-for-mem_hops-field-to-perf_event.h.patch
  New patch: tools-perf-Add-mem_hops-field-in-perf_mem_data_src-structure.patch
  Refresh patch: perf-evlist-Keep-topdown-counters-in-weak-group.patch
* Tue Jan 10 2023 tonyj@suse.com
- Initial checkin for SLE15-SP5
  Update all JSON event description files.
  Satisfies jsc#PED-617, jsc#PED-811, jsc#PED-814, jsc#PED-816, jsc#PED=819,
  jsc#PED-821, jsc#PED-854 and jsc#PED-1059.
  New patch: perf-arch-events-riscv-sbi-firmware-std-event-files.patch
  New patch: perf-jevents-Add-support-for-HiSilicon-CPA-PMU-aliasing.patch
  New patch: perf-list-Add-IBM-z16-event-description-for-s390.patch
  New patch: perf-list-Add-PMU-pai_crypto-event-description-for-IBM-z16.patch
  New patch: perf-list-Fix-PMU-name-pai_crypto-in-perf-list-on-s390.patch
  New patch: perf-list-Update-event-description-for-IBM-z10-to-latest-level.patch
  New patch: perf-list-Update-event-description-for-IBM-z13-to-latest-level.patch
  New patch: perf-list-Update-event-description-for-IBM-z14-to-latest-level.patch
  New patch: perf-list-Update-event-description-for-IBM-z15-to-latest-level.patch
  New patch: perf-list-Update-event-description-for-IBM-z196-z114-to-latest-level.patch
  New patch: perf-list-Update-event-description-for-IBM-zEC12-zBC12-to-latest-level.patch
  New patch: perf-vendor-events-Add-Arm-Neoverse-V2-PMU-events.patch
  New patch: perf-vendor-events-Add-Intel-meteorlake.patch
  New patch: perf-vendor-events-Add-metrics-for-Icelake-Server.patch
  New patch: perf-vendor-events-Add-metrics-for-Tigerlake.patch
  New patch: perf-vendor-events-Add-missing-Neoverse-V1-events.patch
  New patch: perf-vendor-events-Fix-Alderlake-metric-groups.patch
  New patch: perf-vendor-events-Fix-Ivytown-UNC_M_ACT_COUNT.RD-umask.patch
  New patch: perf-vendor-events-Fix-all-remaining-invalid-JSON-files.patch
  New patch: perf-vendor-events-For-the-Arm-Neoverse-N2.patch
  New patch: perf-vendor-events-Remove-bad-broadwellde-uncore-events.patch
  New patch: perf-vendor-events-Remove-bad-ivytown-uncore-events.patch
  New patch: perf-vendor-events-Remove-bad-jaketown-uncore-events.patch
  New patch: perf-vendor-events-Rename-arm64-arch-std-event-files.patch
  New patch: perf-vendor-events-Syntax-corrections-in-Neoverse-N1-json.patch
  New patch: perf-vendor-events-Update-Intel-alderlake-a80de066.patch
  New patch: perf-vendor-events-Update-Intel-alderlake-a95ab294.patch
  New patch: perf-vendor-events-Update-Intel-broadwell-1775634e.patch
  New patch: perf-vendor-events-Update-Intel-broadwell-eb4f8d77.patch
  New patch: perf-vendor-events-Update-Intel-broadwellde-d7184d94.patch
  New patch: perf-vendor-events-Update-Intel-broadwellde-ef908a19.patch
  New patch: perf-vendor-events-Update-Intel-broadwellx-4266081e.patch
  New patch: perf-vendor-events-Update-Intel-broadwellx-5bc4e39e.patch
  New patch: perf-vendor-events-Update-Intel-cascadelakex-55b201a8.patch
  New patch: perf-vendor-events-Update-Intel-cascadelakex-f9d45862.patch
  New patch: perf-vendor-events-Update-Intel-elkhartlake.patch
  New patch: perf-vendor-events-Update-Intel-haswell-8e6389f9.patch
  New patch: perf-vendor-events-Update-Intel-haswell-dd7aae2c.patch
  New patch: perf-vendor-events-Update-Intel-haswellx-08ce57dd.patch
  New patch: perf-vendor-events-Update-Intel-haswellx-859fe0f4.patch
  New patch: perf-vendor-events-Update-Intel-icelake-8fb4ddf4.patch
  New patch: perf-vendor-events-Update-Intel-icelake-a4a4353e.patch
  New patch: perf-vendor-events-Update-Intel-icelakex-bd035250.patch
  New patch: perf-vendor-events-Update-Intel-icelakex-d214d0c2.patch
  New patch: perf-vendor-events-Update-Intel-ivybridge-3bd2d211.patch
  New patch: perf-vendor-events-Update-Intel-ivybridge-80c14459.patch
  New patch: perf-vendor-events-Update-Intel-ivytown-62201368.patch
  New patch: perf-vendor-events-Update-Intel-ivytown-d2aaf040.patch
  New patch: perf-vendor-events-Update-Intel-jaketown-3405de19.patch
  New patch: perf-vendor-events-Update-Intel-jaketown-376d8b58.patch
  New patch: perf-vendor-events-Update-Intel-knightslanding.patch
  New patch: perf-vendor-events-Update-Intel-nehalemep.patch
  New patch: perf-vendor-events-Update-Intel-nehalemex.patch
  New patch: perf-vendor-events-Update-Intel-sandybridge-777e1312.patch
  New patch: perf-vendor-events-Update-Intel-sandybridge-db35c1dc.patch
  New patch: perf-vendor-events-Update-Intel-sapphirerapids-34122105.patch
  New patch: perf-vendor-events-Update-Intel-sapphirerapids-9a1b4aa4.patch
  New patch: perf-vendor-events-Update-Intel-silvermont.patch
  New patch: perf-vendor-events-Update-Intel-skylake-35d65277.patch
  New patch: perf-vendor-events-Update-Intel-skylake-aac53e8f.patch
  New patch: perf-vendor-events-Update-Intel-skylakex-313b2f38.patch
  New patch: perf-vendor-events-Update-Intel-skylakex-59fd7d32.patch
  New patch: perf-vendor-events-Update-Intel-snowridgex.patch
  New patch: perf-vendor-events-Update-Intel-tigerlake-5e1dd4f2.patch
  New patch: perf-vendor-events-Update-Intel-tigerlake-a7c1aaa6.patch
  New patch: perf-vendor-events-Update-Intel-westmereep-dp.patch
  New patch: perf-vendor-events-Update-Intel-westmereep-sp.patch
  New patch: perf-vendor-events-Update-Intel-westmereex.patch
  New patch: perf-vendor-events-Update-Knights-Landing.patch
  New patch: perf-vendor-events-Update-Nehalem-EP.patch
  New patch: perf-vendor-events-Update-Sandybridge.patch
  New patch: perf-vendor-events-Update-Silvermont.patch
  New patch: perf-vendor-events-Update-Tigerlake.patch
  New patch: perf-vendor-events-Update-TremontX.patch
  New patch: perf-vendor-events-Update-Westmere-EP-SP.patch
  New patch: perf-vendor-events-Update-Westmere-EX.patch
  New patch: perf-vendor-events-Update-bonnell-mapfile.csv.patch
  New patch: perf-vendor-events-Update-elkhartlake-cpuids.patch
  New patch: perf-vendor-events-Update-events-and-metrics-for-broadwellx.patch
  New patch: perf-vendor-events-Update-events-and-metrics-for-cascadelakex.patch
  New patch: perf-vendor-events-Update-events-and-metrics-for-haswellx.patch
  New patch: perf-vendor-events-Update-events-and-metrics-for-icelakex.patch
  New patch: perf-vendor-events-Update-events-and-metrics-for-skylakex.patch
  New patch: perf-vendor-events-Update-events-for-Neoverse-E1.patch
  New patch: perf-vendor-events-Update-events-for-knightslanding.patch
  New patch: perf-vendor-events-Update-events-for-snowridgex.patch
  New patch: perf-vendor-events-Update-for-Bonnell.patch
  New patch: perf-vendor-events-Update-for-Goldmont.patch
  New patch: perf-vendor-events-Update-for-GoldmontPlus.patch
  New patch: perf-vendor-events-Update-for-Westmere-EP-DP.patch
  New patch: perf-vendor-events-Update-goldmont-mapfile.csv.patch
  New patch: perf-vendor-events-Update-goldmontplus-mapfile.csv.patch
  New patch: perf-vendor-events-Update-metrics-for-Broadwell-DE.patch
  New patch: perf-vendor-events-Update-metrics-for-Broadwell.patch
  New patch: perf-vendor-events-Update-metrics-for-BroadwellX.patch
  New patch: perf-vendor-events-Update-metrics-for-CascadeLake-Server.patch
  New patch: perf-vendor-events-Update-metrics-for-CascadelakeX.patch
  New patch: perf-vendor-events-Update-metrics-for-Haswell.patch
  New patch: perf-vendor-events-Update-metrics-for-HaswellX.patch
  New patch: perf-vendor-events-Update-metrics-for-Icelake.patch
  New patch: perf-vendor-events-Update-metrics-for-IcelakeX.patch
  New patch: perf-vendor-events-Update-metrics-for-Ivybridge.patch
  New patch: perf-vendor-events-Update-metrics-for-Ivytown.patch
  New patch: perf-vendor-events-Update-metrics-for-Jaketown.patch
  New patch: perf-vendor-events-Update-metrics-for-SkyLake-Server-3bad20d7.patch
  New patch: perf-vendor-events-Update-metrics-for-SkyLake-Server-c4ad8fab.patch
  New patch: perf-vendor-events-Update-metrics-for-Skylake.patch
  New patch: perf-vendor-events-Update-metrics-for-broadwellde.patch
  New patch: perf-vendor-events-Update-metrics-for-ivytown.patch
  New patch: perf-vendor-events-Update-metrics-for-jaketown.patch
  New patch: perf-vendor-events-Update-metrics-for-sapphirerapids.patch
  New patch: perf-vendor-events-Update-silvermont-cpuids.patch
  New patch: perf-vendor-events-amd-Add-Zen-4-core-events.patch
  New patch: perf-vendor-events-amd-Add-Zen-4-mapping.patch
  New patch: perf-vendor-events-amd-Add-Zen-4-metrics.patch
  New patch: perf-vendor-events-amd-Add-Zen-4-uncore-events.patch
  New patch: perf-vendor-events-arm64-Add-new-armv8-pmu-events.patch
  New patch: perf-vendor-events-arm64-Arm-Cortex-A78C-and-X1C.patch
  New patch: perf-vendor-events-arm64-Categorise-the-Neoverse-V1-counters.patch
  New patch: perf-vendor-events-arm64-Fix-JSON-indentation-to-4-spaces-standard.patch
  New patch: perf-vendor-events-arm64-Fix-incorrect-Hisi-hip08-L3-metrics.patch
  New patch: perf-vendor-events-arm64-Move-REMOTE_ACCESS-to-memory-category.patch
  New patch: perf-vendor-events-arm64-Revise-hip08-uncore-events.patch
  New patch: perf-vendor-events-intel-Add-basic-metrics-for-Elkhartlake.patch
  New patch: perf-vendor-events-intel-Add-core-event-list-for-Alderlake-N.patch
  New patch: perf-vendor-events-intel-Add-core-event-list-for-Alderlake.patch
  New patch: perf-vendor-events-intel-Add-core-event-list-for-Elkhartlake.patch
  New patch: perf-vendor-events-intel-Add-core-event-list-for-Tigerlake.patch
  New patch: perf-vendor-events-intel-Add-metrics-for-Alderlake-N.patch
  New patch: perf-vendor-events-intel-Add-metrics-for-Alderlake.patch
  New patch: perf-vendor-events-intel-Add-metrics-for-Sapphirerapids.patch
  New patch: perf-vendor-events-intel-Add-sapphirerapids-events.patch
  New patch: perf-vendor-events-intel-Add-uncore-event-list-for-Alderlake-N.patch
  New patch: perf-vendor-events-intel-Add-uncore-event-list-for-Alderlake.patch
  New patch: perf-vendor-events-intel-Add-uncore-event-list-for-Sapphirerapids.patch
  New patch: perf-vendor-events-intel-Fix-icelake-cstate-metrics.patch
  New patch: perf-vendor-events-intel-Fix-icelakex-cstate-metrics.patch
  New patch: perf-vendor-events-intel-Refresh-alderlake-metrics.patch
  New patch: perf-vendor-events-intel-Refresh-alderlake-n-metrics.patch
  New patch: perf-vendor-events-intel-Refresh-bonnell-events.patch
  New patch: perf-vendor-events-intel-Refresh-broadwell-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-broadwellde-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-broadwellx-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-cascadelakex-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-elkhartlake-events.patch
  New patch: perf-vendor-events-intel-Refresh-goldmont-events.patch
  New patch: perf-vendor-events-intel-Refresh-goldmontplus-events.patch
  New patch: perf-vendor-events-intel-Refresh-haswell-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-haswellx-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-icelake-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-icelakex-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-ivybridge-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-ivytown-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-jaketown-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-knightslanding-events.patch
  New patch: perf-vendor-events-intel-Refresh-meteorlake-events.patch
  New patch: perf-vendor-events-intel-Refresh-nehalemep-events.patch
  New patch: perf-vendor-events-intel-Refresh-nehalemex-events.patch
  New patch: perf-vendor-events-intel-Refresh-sandybridge-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-sapphirerapids-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-silvermont-events.patch
  New patch: perf-vendor-events-intel-Refresh-skylake-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-skylakex-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-snowridgex-events.patch
  New patch: perf-vendor-events-intel-Refresh-tigerlake-metrics-and-events.patch
  New patch: perf-vendor-events-intel-Refresh-westmereep-dp-events.patch
  New patch: perf-vendor-events-intel-Refresh-westmereep-sp-events.patch
  New patch: perf-vendor-events-intel-Refresh-westmereex-events.patch
  New patch: perf-vendor-events-intel-Rename-tremontx-to-snowridgex.patch
  New patch: perf-vendor-events-intel-Update-CLX-events-to-v1.15.patch
  New patch: perf-vendor-events-intel-Update-CLX-uncore-to-v1.14.patch
  New patch: perf-vendor-events-intel-Update-ICL-events-to-v1.13.patch
  New patch: perf-vendor-events-intel-Update-IVT-events-to-v21.patch
  New patch: perf-vendor-events-intel-Update-SKL-events-to-v53.patch
  New patch: perf-vendor-events-intel-Update-SKX-events-to-v1.27.patch
  New patch: perf-vendor-events-intel-Update-SKX-uncore.patch
  New patch: perf-vendor-events-intel-Update-WSM-EP-SP-events-to-v3.patch
  New patch: perf-vendor-events-intel-Update-WSM-EX-events-to-v3.patch
  New patch: perf-vendor-events-intel-Update-core-event-list-for-CascadeLake-Server.patch
  New patch: perf-vendor-events-intel-Update-core-event-list-for-Sapphirerapids.patch
  New patch: perf-vendor-events-intel-Update-core-event-list-for-SkyLake-Server.patch
  New patch: perf-vendor-events-intel-Update-elkhartlake-event-topics.patch
  New patch: perf-vendor-events-intel-Update-event-list-for-Alderlake.patch
  New patch: perf-vendor-events-intel-Update-event-list-for-Sapphirerapids.patch
  New patch: perf-vendor-events-intel-Update-event-list-for-Snowridgex.patch
  New patch: perf-vendor-events-intel-Update-event-list-for-broadwellx.patch
  New patch: perf-vendor-events-intel-Update-event-list-for-haswellx.patch
  New patch: perf-vendor-events-intel-Update-events-and-metrics-for-alderlake.patch
  New patch: perf-vendor-events-intel-Update-events-for-CascadelakeX.patch
  New patch: perf-vendor-events-intel-Update-events-for-Elkhartlake.patch
  New patch: perf-vendor-events-intel-Update-events-for-Icelake.patch
  New patch: perf-vendor-events-intel-Update-events-for-IcelakeX.patch
  New patch: perf-vendor-events-intel-Update-events-for-Skylake.patch
  New patch: perf-vendor-events-intel-Update-events-for-SkylakeX.patch
  New patch: perf-vendor-events-intel-Update-events-for-Tigerlake.patch
  New patch: perf-vendor-events-intel-Update-events-for-TremontX.patch
  New patch: perf-vendor-events-intel-Update-goldmont-event-topics.patch
  New patch: perf-vendor-events-intel-Update-goldmontplus-event-topics.patch
  New patch: perf-vendor-events-intel-Update-metrics-for-Alderlake.patch
  New patch: perf-vendor-events-intel-Update-nehalemep-event-topics.patch
  New patch: perf-vendor-events-intel-Update-tigerlake-topic.patch
  New patch: perf-vendor-events-intel-Update-tremontx-uncore-and-topics.patch
  New patch: perf-vendor-events-intel-Update-uncore-event-list-for-CascadeLake-Server.patch
  New patch: perf-vendor-events-intel-Update-uncore-event-list-for-SkyLake-Server.patch
  New patch: perf-vendor-events-intel-Update-westmereep-dp-event-topics.patch
  New patch: perf-vendor-events-intel-Update-westmereep-sp-event-topics.patch
  New patch: perf-vendor-events-intel-Update-westmereex-event-topics.patch
  New patch: perf-vendor-events-power10-Add-metric-events-JSON-file-for-power10-platform.patch
  New patch: perf-vendor-events-power10-Fix-hv-24x7-metric-events.patch
  New patch: perf-vendor-events-powerpc-Fix-spelling-mistake-icach-icache.patch
  New patch: perf-vendor-events-riscv-add-Sifive-U74-JSON-file.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A34.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A35.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A510.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A55.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A65.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A710.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A73.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A75.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A77.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-A78.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-X1.patch
  New patch: perf-vendors-events-arm64-Arm-Cortex-X2.patch
  New patch: perf-vendors-events-arm64-Arm-Neoverse-E1.patch
  New patch: perf-vendors-events-arm64-Update-Cortex-A57-A72.patch
* Wed Dec 28 2022 tonyj@suse.com
- Fix build issues relating to binutils update.
  New patch: tools-perf-Fix-compilation-error-with-new-binutils.patch
- Incorporate additional feature detection changes to support above:
  New patch: perf-tools-Add-an-option-to-build-without-libbfd.patch
  New patch: tools-build-Add-feature-test-for-init_disassemble_info-API-changes.patch
  New patch: tools-build-Don-t-display-disassembler-four-args-feature-test.patch
  New patch: tools-include-add-dis-asm-compat.h-to-handle-version-differences.patch
- Core feature detection code in tools/build/feature (kernel-source) appears
  broken. In order to make forward progress here force feature-libbfd-liberty-z
  and feature-disassembler-four-args to on (as done in openSUSE.925264)
* Fri Nov 11 2022 tonyj@suse.com
- Add AMD Genoa support (jsc#SLE-24578)
  New patch: libperf-Add-preadn.patch
  New patch: perf-env-Add-perf_env__cpuid-perf_env__-nr_-pmu_mappings.patch
  New patch: perf-env-Track-kernel-64-bit-mode-in-environment.patch
  New patch: perf-evlist-Extend-arch_evsel__must_be_in_group-to-support-hybrid-systems.patch
  New patch: perf-evlist-Keep-topdown-counters-in-weak-group.patch
  New patch: perf-evsel-don-t-set-exclude_guest-by-default.patch
  New patch: perf-evsel-Improve-AMD-IBS-Instruction-Based-Sampling-error-handling-messages.patch
  New patch: perf-evsel-Improve-error-message-for-uncore-events.patch
  New patch: perf-evsel-Make-evsel__env-always-return-a-valid-env.patch
  New patch: perf-header-Add-ability-to-keep-feature-sections.patch
  New patch: perf-header-Pass-cpu-pmu-name-while-printing-caps.patch
  New patch: perf-header-Record-non-CPU-PMU-capabilities.patch
  New patch: perf-header-Store-PMU-caps-in-an-array-of-strings.patch
  New patch: perf-inject-Fix-output-from-a-file-to-a-pipe.patch
  New patch: perf-inject-Fix-output-from-a-pipe-to-a-file.patch
  New patch: perf-inject-Fix-segfault-due-to-perf_data__fd-without-open.patch
  New patch: perf-inject-Keep-some-features-sections-from-input-file.patch
  New patch: perf-pmu-Parse-pmu-caps-sysfs-only-once.patch
  New patch: perf-python-Add-perf_env-stubs-that-will-be-needed-in-evsel__open_strerror.patch
  New patch: perf-record-ibs-Warn-about-sampling-period-skew.patch
  New patch: perf-report-Add-support-to-print-a-textual-representation-of-IBS-raw-sample-data.patch
  New patch: perf-report-Add-tools-arch-x86-include-asm-amd-ibs.h.patch
  New patch: perf-script-ibs-Support-new-IBS-bits-in-raw-trace-dump.patch
  New patch: perf-tool-ibs-Sync-AMD-IBS-header-file.patch
  New patch: perf-tools-Pass-a-fd-to-perf_file_header__read_pipe.patch
  New patch: perf-tools-Remove-repipe-argument-from-perf_session__new.patch
* Wed Oct  5 2022 tonyj@suse.com
- Patches for previous change were not correctly applied in perf.spec
  (bsc#1198595)
* Tue May 10 2022 tonyj@suse.com
- Fix perf bench numa assertion failure (bsc#1198595)
  New patch: perf-bench-Fix-numa-bench-to-fix-usage-of-affinity-for-machines-with-CPUs-1K.patch
  New patch: perf-bench-Fix-numa-testcase-to-check-if-CPU-used-to-bind-task-is-online.patch
* Tue May 10 2022 tonyj@suse.com
- Apply latest git-fixes reported against kernel-source:
  ARM-SPE
  - ------
  Correct missing virtual addresses in SPE samples
  New patch: perf-arm-spe-Fix-addresses-of-synthesized-SPE-events.patch
  Correct bug in perf mem report/perf report --mem-mode which was preventing
  opening of data files
  New patch: perf-arm-spe-Fix-perf-report-mem-mode.patch
  Correct bug in perf mem report/perf report --mem-mode which was preventing
  reporting of data if the PERF_SAMPLE_DATA_SRC bit was missing
  New patch: perf-report-Set-PERF_SAMPLE_DATA_SRC-bit-for-Arm-SPE-event.patch
  Always allow data_src option for SPE aux data
  New patch: perf-script-Always-allow-field-data_src-for-auxtrace.patch
  BPF
  - --
  Correct gcc possible-use-after-free warning
  New patch: perf-bpf-Defer-freeing-string-after-possible-strlen-on-it.patch
  SESSION
  - ------
  Correct double free in perf_session__delete
  New patch: perf-data-Fix-double-free-in-perf_session__delete.patch
  Remap memory rather than failing if insufficient memory to hold event
  New patch: perf-session-Remap-buf-if-there-is-no-space-for-event.patch
  STAT
  - ---
  Correctly display events that have multiple uncore aliases rather than
  marking as merged.
  New patch: perf-stat-Fix-display-of-grouped-aliased-events.patch
  Enable counter events before forking child process
  New patch: perf-stat-Fix-forked-applications-enablement-of-counters.patch
  MISC
  - ---
  Correct error message regarding non-fatal error
  New patch: perf-tools-Fix-misleading-add-event-PMU-debug-message.patch
  Fix incorrect use of eprintf in callback
  New patch: perf-tools-Fix-perf-s-libperf_print-callback.patch
  Fix incorrect symbol size calculation
  New patch: perf-symbols-Fix-symbol-size-calculation-condition.patch
* Sat Jan 29 2022 tonyj@suse.com
- Apply latest git-fixes reported against kernel-source:
  - Build: Fix build error when bpf_skel with clang-10
    New patch: perf-bpf_skel-Do-not-use-typedef-to-avoid-error-on-old-clang.patch
    New patch: perf-bpf-Fix-building-perf-with-BUILD_BPF_SKEL-1-by-default-in-more-distros.patch (dependent patch)
  - Build: Remove needless libpython-version feature chec
    New patch: tools-build-Remove-needless-libpython-version-feature-check-that-breaks-test-all-fast-path.patch
  - Evsel: Fix regression causing sample periods to be ignored on ARM
    New patch: perf-evsel-Override-attr-sample_period-for-non-libpfm4-events.patch
  - Inject: Fix crash due to attempting to close inject.output when not opened
    New patch: perf-inject-Fix-segfault-due-to-close-without-open.patch
  - Intel PT: Correctly update timestamp on error path
    New patch: perf-intel-pt-Fix-error-timestamp-setting-on-the-decoder-error-path.patch
  - Intel PT: do not universally override state type on FUP event
    New patch: perf-intel-pt-Fix-intel_pt_fup_event-assumptions-about-setting-state-type.patch
  - Intel PT: consider FUP packets to be an 'instruction'
    New patch: perf-intel-pt-Fix-missing-instruction-events-with-q-option.patch
  - Intel PT: ensure error path is 0 in intel_pt_walk_trace()
    New patch: perf-intel-pt-Fix-next-err-value-walking-trace.patch
  - Intel PT: Fix parsing of VM time correlation arguments
    New patch: perf-intel-pt-Fix-parsing-of-VM-time-correlation-arguments.patch
  - Intel PT: Fix some PGE (packet generation enable/control flow packets) usage
    New patch: perf-intel-pt-Fix-some-PGE-packet-generation-enable-control-flow-packets-usage.patch
  - Intel PT: Fix synchronization state on overflow and handle subsequent FUP
    New patch: perf-intel-pt-Fix-state-setting-when-receiving-overflow-OVF-packet.patch
    New patch: perf-intel-pt-Fix-sync-state-when-a-PSB-synchronization-packet-is-found.patch
  - Probe: skip function symbols when adding probe point on POWER
    New patch: perf-probe-Fix-ppc64-perf-probe-add-events-failed-case.patch
  - Script: Apply CPU filtering was to a script's switch events.
    New patch: perf-script-Fix-CPU-filtering-of-a-script-s-switch-events.patch
  - Script: Fix hex dump character output due to non-printable characters
    New patch: perf-script-Fix-hex-dump-character-output.patch
  - Scripts: Correctly display last switch event in intel-pt-events.py
    New patch: perf-scripts-python-intel-pt-events.py-Fix-printing-of-switch-events.patch
  - Tools: Fix SMT detection fast read path
    New patch: perf-tools-Fix-SMT-detection-fast-read-path.patch
* Mon Dec  6 2021 tonyj@suse.com
- Apply latest git-fixes reported against kernel-source:
- ASan reports memory leaks while running:
  New patch: perf-bench-Fix-two-memory-leaks-detected-with-ASan.patch
- Resolve memory leak in BPF when attempting to insert duplicate id's
  New patch: perf-bpf-Avoid-memory-leak-from-perf_env__insert_btf.patch
- Resolve failure to execute zstd test on !s390 systems
  New patch: perf-tests-Remove-bash-construct-from-record-zstd_comp_decomp.sh.patch
* Fri Nov  5 2021 tonyj@suse.com
- Incorporate latest git-fixes
  New patch: perf-tests-attr-Add-missing-topdown-metrics-events.patch
* Tue Nov  2 2021 tonyj@suse.com
- Create devel package based on Factory commit:
  "Mon Jul 26 07:05:21 UTC 2021 - Jiri Slaby <jslaby@suse.cz>"
  Since we now have a -devel package, move bpf includes to there also.
* Tue Oct 26 2021 tonyj@suse.com
- Update to v5.14 perf (from SLE-15-SP4:GA kernel-source - jsc#SLE-17360)
  Please refer to the kernel-* changelog for more information about changes
  included in this release.
  Delete patches (contained in v5.14):
    libperf-add-build-version-support.patch
    libperf-add-debug-output-support.patch
    libperf-add-libperf-to-the-python-so-build.patch
    libperf-add-nr_entries-to-struct-perf_evlist.patch
    libperf-add-perf-core-h-header.patch
    libperf-add-perf_cpu_map-struct.patch
    libperf-add-perf_cpu_map__dummy_new-function.patch
    libperf-add-perf_cpu_map__get-perf_cpu_map__put.patch
    libperf-add-perf_evlist-and-perf_evsel-structs.patch
    libperf-add-perf_evlist__add-function.patch
    libperf-add-perf_evlist__init-function.patch
    libperf-add-perf_evlist__remove-function.patch
    libperf-add-perf_evsel__init-function.patch
    libperf-add-perf_thread_map-struct.patch
    libperf-add-perf_thread_map__get-perf_thread_map__put.patch
    libperf-add-perf_thread_map__new_dummy-function.patch
    libperf-include-perf_evlist-in-evlist-object.patch
    libperf-include-perf_evsel-in-evsel-object.patch
    libperf-make-libperf-a-part-of-the-perf-build.patch
    perf-arm-spe-support-synthetic-events.patch
    perf-augmented_raw_syscalls-add-handler-for-openat.patch
    perf-augmented_raw_syscalls-augment-sockaddr-arg-in-connect.patch
    perf-augmented_raw_syscalls-rename-augmented_args_filename-to-augmented_args_payload.patch
    perf-augmented_raw_syscalls-support-copying-two-string-syscall-args.patch
    perf-augmented_raw_syscalls-switch-to-using-bpf_map_type_prog_array.patch
    perf-auxtrace-add-an-option-to-synthesize-callchains-for-regular-events.patch
    perf-auxtrace-add-four-itrace-options.patch
    perf-auxtrace-add-option-to-synthesize-branch-stack-for-regular-events.patch
    perf-bench-futex-wake-restore-thread-count-default-to-online-cpu-count.patch
    perf-bench-numa-fix-cpumask-memory-leak-in-node_has_cpus.patch
    perf-bench-numa-use-numa_node_to_cpus-to-bind-tasks-to-nodes.patch
    perf-block-cleanup-and-refactor-block-info-functions.patch
    perf-bpf-do-not-attach-a-bpf-prog-to-a-tracepoint-if-its-name-starts-with.patch
    perf-bpf-loader-add-missing-for-key_scan_pos.patch
    perf-c2c-add-option-to-enable-the-lbr-stitching-approach.patch
    perf-c2c-display-proper-cpu-count-in-nodes-column.patch
    perf-c2c-fix-report-with-offline-cpus.patch
    perf-cacheline-move-cacheline-related-routines-to-separate-files.patch
    perf-callchain-fix-segfault-in-thread__resolve_callchain_sample.patch
    perf-callchain-save-previous-cursor-nodes-for-lbr-stitching-approach.patch
    perf-callchain-stitch-lbr-call-stack.patch
    perf-callchain-use-struct-map_symbol-in-struct-callchain_cursor_node.patch
    perf-cpu_map-rename-struct-cpu_map-to-struct-perf_cpu_map.patch
    perf-cpumap-fix-snprintf-overflow-check.patch
    perf-cs-etm-move-definition-of-traceid_list-global-variable-from-header-file.patch
    perf-debug-remove-needless-include-directives-from-debug-h.patch
    perf-diff-don-t-use-hack-to-skip-column-length-calculation.patch
    perf-diff-report-noisy-for-cycles-diff.patch
    perf-diff-support-hot-streams-comparison.patch
    perf-diff-use-llabs-with-64-bit-values.patch
    perf-env-do-not-return-pointers-to-local-variables.patch
    perf-env-remove-needless-cpumap-h-header-partial.patch
    perf-events-parser-add-missing-intel-cpu-events-to-parser.patch
    perf-evlist-rename-perf_evlist__add-to-evlist__add.patch
    perf-evlist-rename-perf_evlist__close-to-evlist__close.patch
    perf-evlist-rename-perf_evlist__delete-to-evlist__delete.patch
    perf-evlist-rename-perf_evlist__disable-to-evlist__disable.patch
    perf-evlist-rename-perf_evlist__enable-to-evlist__enable.patch
    perf-evlist-rename-perf_evlist__init-to-evlist__init.patch
    perf-evlist-rename-perf_evlist__new-to-evlist__new.patch
    perf-evlist-rename-perf_evlist__open-to-evlist__open.patch
    perf-evlist-rename-perf_evlist__remove-to-evlist__remove.patch
    perf-evlist-rename-struct-perf_evlist-to-struct-evlist.patch
    perf-evsel-remove-need-for-symbol_conf-in-evsel_fprintf-c.patch
    perf-evsel-rename-perf_evsel__apply_filter-to-evsel__apply_filter.patch
    perf-evsel-rename-perf_evsel__cpus-to-evsel__cpus.patch
    perf-evsel-rename-perf_evsel__delete-to-evsel__delete.patch
    perf-evsel-rename-perf_evsel__disable-to-evsel__disable.patch
    perf-evsel-rename-perf_evsel__enable-to-evsel__enable.patch
    perf-evsel-rename-perf_evsel__init-to-evsel__init.patch
    perf-evsel-rename-perf_evsel__new-to-evsel__new.patch
    perf-evsel-rename-perf_evsel__open-to-evsel__open.patch
    perf-evsel-rename-struct-perf_evsel-to-struct-evsel.patch
    perf-evsel-store-backpointer-to-attached-bpf_object.patch
    perf-expr-add-expr-c-object.patch
    perf-expr-add-expr_-prefix-for-parse_ctx-and-parse_id.patch
    perf-expr-add-expr_scanner_ctx-object.patch
    perf-expr-fix-copy-paste-mistake.patch
    perf-expr-increase-expr_max_other-to-support-metrics-with-more-than-15-variables.patch
    perf-expr-make-expr__parse-return-1-on-error.patch
    perf-expr-move-expr-lexer-to-flex.patch
    perf-expr-straighten-expr__parse-expr__find_other-interface.patch
    perf-header-support-cpu-pmu-capabilities.patch
    perf-hist-add-fast-path-for-duplicate-entries-check.patch
    perf-hist-count-the-total-cycles-of-all-samples.patch
    perf-hist-support-block-formats-with-compare-sort-display.patch
    perf-hists-browser-restore-esc-as-zoom-out-of-dso-thread-etc.patch
    perf-hists-fix-variable-name-s-inconsistency-in-hists__for_each-macro.patch
    perf-include-bpf-add-bpf_tail_call-prototype.patch
    perf-intel-pt-add-brief-documentation-for-pebs-via-intel-pt.patch
    perf-intel-pt-fix-pebs-sample-for-xmm-registers.patch
    perf-intel-pt-process-options-for-pebs-event-synthesis.patch
    perf-jevents-fix-resource-leak-in-process_mapfile-and-main.patch
    perf-jevents-support-metric-constraint.patch
    perf-kvm-s390-add-missing-string-h-header.patch
    perf-list-allow-plurals-for-metric-metricgroup.patch
    perf-list-hide-deprecated-events-by-default.patch
    perf-machine-factor-out-lbr_callchain_add_kernel_ip.patch
    perf-machine-factor-out-lbr_callchain_add_lbr_ip.patch
    perf-machine-refine-the-function-for-lbr-call-stack-reconstruction.patch
    perf-machine-remove-the-indent-in-resolve_lbr_callchain_sample.patch
    perf-make-perf-able-to-build-with-latest-libbfd.patch
    perf-map-fix-off-by-one-in-strncpy-size-argument.patch
    perf-map-no-need-to-adjust-the-long-name-of-modules.patch
    perf-map_groups-pass-the-object-to-map_groups__find_ams.patch
    perf-metricgroup-factor-out-metricgroup__add_metric_weak_group.patch
    perf-metricgroup-fix-printing-event-names-of-metric-group-with-multiple-events-incase-of-overlapping-events.patch
    perf-metricgroup-fix-printing-event-names-of-metric-group-with-multiple-events.patch
    perf-metricgroup-remove-needless-includes-from-metricgroup-h.patch
    perf-metricgroup-scale-the-metric-result.patch
    perf-metricgroup-support-metric-constraint.patch
    perf-metricgroup-support-multiple-events-for-metricgroup.patch
    perf-metricgroups-enhance-json-metric-infrastructure-to-handle.patch
    perf-metrics-fix-parse-errors-in-power8-metrics.patch
    perf-metrics-fix-parse-errors-in-power9-metrics.patch
    perf-metrics-fix-parse-errors-in-skylake-metrics.patch
    perf-metrictroup-split-the-metricgroup__add_metric-function.patch
    perf-parse-events-fix-an-incompatible-pointer.patch
    perf-pmu-add-support-for-pmu-capabilities.patch
    perf-pmu-change-convert_scale-from-static-to-global.patch
    perf-probe-check-address-correctness-by-map-instead-of-etext.patch
    perf-probe-do-not-show-the-skipped-events.patch
    perf-probe-filter-out-instances-except-for-inlined-subroutine-and-subprogram.patch
    perf-probe-fix-to-check-blacklist-address-correctly.patch
    perf-probe-fix-to-find-range-only-function-instance.patch
    perf-probe-fix-to-list-probe-event-with-correct-line-number.patch
    perf-probe-fix-to-probe-a-function-which-has-no-entry-pc.patch
    perf-probe-fix-to-probe-an-inline-function-which-has-no-entry-pc.patch
    perf-probe-fix-to-show-calling-lines-of-inlined-functions.patch
    perf-probe-fix-to-show-function-entry-line-as-probe-able.patch
    perf-probe-fix-to-show-inlined-function-callsite-without-entry_pc.patch
    perf-probe-fix-to-show-ranges-of-variables-in-functions-without-entry_pc.patch
    perf-probe-fix-wrong-address-verification.patch
    perf-probe-skip-end-of-sequence-and-non-statement-lines.patch
    perf-probe-skip-overlapped-location-on-searching-variables.patch
    perf-probe-walk-function-lines-in-lexical-blocks.patch
    perf-record-fix-binding-of-aio-user-space-buffers-to-nodes.patch
    perf-regs-make-perf_reg_name-return-unknown-instead-of-null.patch
    perf-report-add-option-to-enable-the-lbr-stitching-approach.patch
    perf-report-allow-specifying-event-to-be-used-as-sort-key-in-group-output.patch
    perf-report-dump-lbr-callstack-data-by-d-jointly-with-thread-stack.patch
    perf-report-fix-incorrectly-added-dimensions-as-switch-perf-data-file.patch
    perf-report-fix-no-branch-type-statistics-report-issue.patch
    perf-report-fix-null-pointer-dereference-in-hists__fprintf_nr_sample_events.patch
    perf-report-jump-to-symbol-source-view-from-total-cycles-view.patch
    perf-report-sort-by-sampled-cycles-percent-per-block-for-stdio.patch
    perf-report-sort-by-sampled-cycles-percent-per-block-for-tui.patch
    perf-report-support-a-new-key-to-reload-the-browser.patch
    perf-report-support-interactive-annotation-of-code-without-symbols.patch
    perf-report-support-percent-limit-for-total-cycles.patch
    perf-report-top-do-not-offer-annotation-for-symbols-without-samples.patch
    perf-report-top-tui-support-hotkey-a-for-annotation-of-unresolved-addresses.patch
    perf-report-tui-fix-segmentation-fault-in-perf_evsel__hists_browse.patch
    perf-script-add-option-to-enable-the-lbr-stitching-approach.patch
    perf-script-allow-time-with-reltime.patch
    perf-script-fix-brstackinsn-for-auxtrace.patch
    perf-script-introduce-deltatime-option.patch
    perf-scripts-python-export-to-postgresql-py-fix-struct-pack-int-argument.patch
    perf-scripts-python-exported-sql-viewer-py-fix-unexpanded-find-result.patch
    perf-scripts-python-exported-sql-viewer-py-fix-zero-id-in-call-graph-find-result.patch
    perf-scripts-python-exported-sql-viewer-py-fix-zero-id-in-call-tree-find-result.patch
    perf-sort-remove-needless-headers-from-sort-h-provide-fwd-struct-decls.patch
    perf-srcline-add-missing-srcline-h-header-to-files-needing-its-defs.patch
    perf-stat-align-the-output-for-interval-aggregation-mode.patch
    perf-stat-don-t-report-a-null-stalled-cycles-per-insn-metric.patch
    perf-stat-ensure-group-is-defined-on-top-of-the-same-cpu-mask.patch
    perf-stat-fix-duration_time-value-for-higher-intervals.patch
    perf-stat-fix-free-memory-access-memory-leaks-in-metrics.patch
    perf-stat-fix-null-pointer-dereference.patch
    perf-stat-fix-wrong-per-thread-runtime-stat-for-interval-mode.patch
    perf-stat-honour-timeout-for-forked-workloads.patch
    perf-stat-improve-runtime-stat-for-interval-mode.patch
    perf-stat-increase-perf-metric-output-resolution.patch
    perf-stat-move-loaded-out-of-struct-perf_counts_values.patch
    perf-stat-show-percore-counts-in-per-cpu-output.patch
    perf-stat-support-all-kernel-all-user.patch
    perf-stat-support-new-per-thread-topdown-metrics.patch
    perf-stat-zero-all-the-ena-and-run-array-slot-stats-for-interval-mode.patch
    perf-streams-calculate-the-sum-of-total-streams-hits.patch
    perf-streams-compare-two-streams.patch
    perf-streams-get-the-evsel_streams-by-evsel_idx.patch
    perf-streams-introduce-branch-history-streams.patch
    perf-streams-link-stream-pair.patch
    perf-streams-report-hot-streams.patch
    perf-test-report-failure-for-mmap-events.patch
    perf-test-session-topology-fix-data-path.patch
    perf-tests-expr-added-test-for-runtime-param-in-metric-expression.patch
    perf-tests-fix-out-of-bounds-memory-access.patch
    perf-tests-remove-needless-headers-for-bp_account.patch
    perf-thread-add-a-knob-for-lbr-stitch-approach.patch
    perf-thread-save-previous-sample-for-lbr-stitching-approach.patch
    perf-tools-add-aux-output-config-term.patch
    perf-tools-add-aux_output-attribute-flag.patch
    perf-tools-add-documentation-for-topdown-metrics.patch
    perf-tools-add-hw_idx-in-struct-branch_stack.patch
    perf-tools-add-itrace-option-o-to-synthesize-aux-output-events.patch
    perf-tools-add-map_groups-to-struct-addr_location.patch
    perf-tools-enable-hz-hz-prinitg-for-metric-only-option.patch
    perf-tools-fix-reading-new-topology-attribute-core_cpus.patch
    perf-tools-fix-record-failure-when-mixed-with-arm-spe-event.patch
    perf-tools-move-arm-spe-pkt-decoder-h-c-to-the-new-dir.patch
    perf-tools-powerpc-add-support-for-extended-register-capability.patch
    perf-tools-powerpc-add-support-for-extended-regs-in-power10.patch
    perf-tools-remove-debug-h-from-header-files-not-needing-it.patch
    perf-tools-remove-needless-evlist-h-include-directives-partial.patch
    perf-tools-remove-needless-thread-h-include-directives-partial.patch
    perf-tools-remove-util-h-from-where-it-is-not-needed.patch
    perf-tools-rename-struct-thread_map-to-struct-perf_thread_map.patch
    perf-tools-tools-include-should-come-before-tools-uapi-include.patch
    perf-tools-use-define-api-pure-full-instead-of-pure-parser.patch
    perf-top-set-display-thread-comm-to-help-with-debugging.patch
    perf-top-support-group-sort-idx-to-change-the-sort-order.patch
    perf-top-support-hotkey-to-change-sort-order.patch
    perf-trace-add-bpf-handler-for-unaugmented-syscalls.patch
    perf-trace-add-pointer-to-bpf-object-containing-_augmented_syscalls__.patch
    perf-trace-add-sendfile64-alias-to-the-sendfile-syscall.patch
    perf-trace-allow-specifying-the-bpf-prog-to-augment-specific-syscalls.patch
    perf-trace-beauty-add-bpf-augmenter-for-the-rename-syscall.patch
    perf-trace-beauty-beautify-bind-s-sockaddr-arg.patch
    perf-trace-beauty-beautify-sendto-s-sockaddr-arg.patch
    perf-trace-beauty-disable-fd-pathname-when-close-not-enabled.patch
    perf-trace-beauty-do-not-try-to-use-the-fd-pathname-beautifier-for-bind-connect-fd-arg.patch
    perf-trace-beauty-make-connect-s-addrlen-be-printed-as-an-int-not-hex.patch
    perf-trace-forward-error-codes-when-trying-to-read-syscall-info.patch
    perf-trace-handle-raw_syscalls-sys_enter-just-like-the-bpf_output-augmented-event.patch
    perf-trace-look-for-default-name-for-entries-in-the-syscalls-prog-array.patch
    perf-trace-look-up-maps-just-on-the-_augmented_syscalls__-bpf-object.patch
    perf-trace-mark-syscall-ids-that-are-not-allocated-to-avoid-unnecessary-error-messages.patch
    perf-trace-order-e-syscalls-table.patch
    perf-trace-preallocate-the-syscall-table.patch
    perf-trace-put-the-per-syscall-entry-exit-prog_array-bpf-map-infrastructure-in-place.patch
    perf-trace-reuse-bpf-augmenters-from-syscalls-with-similar-args-signature.patch
    perf-ui-gtk-add-missing-zalloc-object.patch
    perf-unwind-use-struct-map_symbol-in-struct-unwind_entry.patch
    perf-util-factor-out-sysctl__nmi_watchdog_enabled.patch
    perf-util-move-block-tui-function-to-ui-browsers.patch
    perf-vendor-events-amd-add-itlb-instruction-fetch-hits-event-for-zen1.patch
    perf-vendor-events-amd-add-l2-prefetch-events-for-zen1.patch
    perf-vendor-events-amd-add-l3-cache-events-for-family-17h.patch
    perf-vendor-events-amd-add-recommended-events.patch
    perf-vendor-events-amd-add-zen2-events.patch
    perf-vendor-events-amd-enable-family-19h-users-by-matching-zen2-events.patch
    perf-vendor-events-amd-remove-redundant.patch
    perf-vendor-events-amd-remove-trailing-commas.patch
    perf-vendor-events-amd-restrict-model-detection-for-zen1-based-processors.patch
    perf-vendor-events-amd-update-zen1-events-to-v2.patch
    perf-vendor-events-arm64-fix-hisi-hip08-ddrc-pmu-eventname.patch
    perf-vendor-events-intel-add-icelake-v1-00-event-file.patch
    perf-vendor-events-intel-add-no_nmi_watchdog-metric-constraint.patch
    perf-vendor-events-intel-add-tremontx-event-file-v1-02.patch
    perf-vendor-events-intel-update-all-the-intel-json-metrics-from-tmam-3-6.patch
    perf-vendor-events-intel-update-cascadelakex-events-to-v1-05.patch
    perf-vendor-events-power9-add-hv_24x7-socket-chip-level-metric-events.patch
    perf-vendor-events-power9-add-missing-metrics-to-power9-cpi_breakdown.patch
    perf-vendor-events-remove-p8-hw-events-which-are-not-supported.patch
    perf-vendor-events-s390-add-json-transaction-for-machine-type-8561.patch
    perf-vendor-events-s390-add-new-deflate-counters-for-ibm-z15.patch
    perf-vendor-events-s390-remove-name-from-l1d_ro_excl_writes-description.patch
    perf-vendor-events-s390-use-s390-machine-name-instead-of-type-8561.patch
    pref-tools-make-struct-addr_map_symbol-contain-struct-map_symbol.patch
    s390-cpum_cf-perf-change-dflt_ccerror-counter-name-partial.patch
* Fri Jan 22 2021 tonyj@suse.com
- Add NO_NMI_WATCHDOG metric constraint to Page_Walks_Utilization for Sky Lake
  and Cascade Lake (bsc#1174516)
  New patch: perf-vendor-events-intel-add-no_nmi_watchdog-metric-constraint.patch
* Thu Jan 14 2021 tonyj@suse.com
- Enable ARM CoreSight Trace Decode (jsc#SLE-13692)
  This change enables perf support for the OpenCSD library, which
  provides an API suitable for the decode of ARM CoreSight trace
  streams.
* Thu Dec 10 2020 tonyj@suse.com
- S390. Change DFLT_CCERROR counter name (bsc#1175918)
  New patch: s390-cpum_cf-perf-change-dflt_ccerror-counter-name-partial.patch
* Mon Dec  7 2020 tonyj@suse.com
- Fix PPC64LE numa SIGABORT (bsc#1179649)
  new patch: perf-bench-numa-fix-cpumask-memory-leak-in-node_has_cpus.patch
  new patch: perf-bench-numa-use-numa_node_to_cpus-to-bind-tasks-to-nodes.patch
* Mon Dec  7 2020 tonyj@suse.com
- Arm SPE support synthetic events in "perf report" (jsc#SLE-14769)
  new patch: perf-arm-spe-support-synthetic-events.patch
  new patch: perf-auxtrace-add-an-option-to-synthesize-callchains-for-regular-events.patch
  new patch: perf-auxtrace-add-four-itrace-options.patch
  new patch: perf-auxtrace-add-option-to-synthesize-branch-stack-for-regular-events.patch
  new patch: perf-env-remove-needless-cpumap-h-header-partial.patch
  new patch: perf-script-introduce-deltatime-option.patch
  new patch: perf-tools-move-arm-spe-pkt-decoder-h-c-to-the-new-dir.patch
  new patch: perf-tools-remove-needless-evlist-h-include-directives-partial.patch
  new patch: perf-tools-remove-needless-thread-h-include-directives-partial.patch
* Wed Dec  2 2020 tonyj@suse.com
- Add IceLake PMU support for TopDown to perf stat (jsc#SLE-13346)
  new patch: perf-stat-support-new-per-thread-topdown-metrics.patch
  new patch: perf-tools-add-documentation-for-topdown-metrics.patch
* Mon Nov 30 2020 tonyj@suse.com
- Support diffing of streams (branch record history) (jsc#SLE-13472)
  new patch: perf-diff-support-hot-streams-comparison.patch
  new patch: perf-streams-calculate-the-sum-of-total-streams-hits.patch
  new patch: perf-streams-compare-two-streams.patch
  new patch: perf-streams-get-the-evsel_streams-by-evsel_idx.patch
  new patch: perf-streams-introduce-branch-history-streams.patch
  new patch: perf-streams-link-stream-pair.patch
  new patch: perf-streams-report-hot-streams.patch
* Tue Nov 24 2020 tonyj@suse.com
- Resolve "Parse event definition strings" perf test failure (jsc#SLE-13604, bsc#1174282)
  new patch: perf-events-parser-add-missing-intel-cpu-events-to-parser.patch
* Thu Nov  5 2020 tonyj@suse.com
- Sum the event among logical-processors of same physical SMT core (jsc#SLE-12729)
  new patch: perf-stat-show-percore-counts-in-per-cpu-output.patch
  refresh patch: perf-stat-fix-null-pointer-dereference.patch
* Fri Oct 30 2020 tonyj@suse.com
- Add metrics support for POWER (jsc#SLE-13611)
  new patch: perf-stat-increase-perf-metric-output-resolution.patch
  new patch: perf-vendor-events-power9-add-missing-metrics-to-power9-cpi_breakdown.patch
* Fri Oct 30 2020 tonyj@suse.com
- POWER10 hardware counter support (jsc#SLE-13513)
  new patch: perf-tools-powerpc-add-support-for-extended-register-capability.patch
  new patch: perf-tools-powerpc-add-support-for-extended-regs-in-power10.patch
* Thu Oct 29 2020 tonyj@suse.com
- Supply TOS for LBRs in perf (jsc#SLE-12718)
  new patch: perf-c2c-add-option-to-enable-the-lbr-stitching-approach.patch
  new patch: perf-callchain-save-previous-cursor-nodes-for-lbr-stitching-approach.patch
  new patch: perf-callchain-stitch-lbr-call-stack.patch
  new patch: perf-callchain-use-struct-map_symbol-in-struct-callchain_cursor_node.patch
  new patch: perf-evsel-remove-need-for-symbol_conf-in-evsel_fprintf-c.patch
  new patch: perf-header-support-cpu-pmu-capabilities.patch
  new patch: perf-hist-add-fast-path-for-duplicate-entries-check.patch
  new patch: perf-machine-factor-out-lbr_callchain_add_kernel_ip.patch
  new patch: perf-machine-factor-out-lbr_callchain_add_lbr_ip.patch
  new patch: perf-machine-refine-the-function-for-lbr-call-stack-reconstruction.patch
  new patch: perf-machine-remove-the-indent-in-resolve_lbr_callchain_sample.patch
  new patch: perf-pmu-add-support-for-pmu-capabilities.patch
  new patch: perf-report-add-option-to-enable-the-lbr-stitching-approach.patch
  new patch: perf-report-dump-lbr-callstack-data-by-d-jointly-with-thread-stack.patch
  new patch: perf-script-add-option-to-enable-the-lbr-stitching-approach.patch
  new patch: perf-thread-add-a-knob-for-lbr-stitch-approach.patch
  new patch: perf-thread-save-previous-sample-for-lbr-stitching-approach.patch
  new patch: perf-tools-add-hw_idx-in-struct-branch_stack.patch
  new patch: perf-tools-add-map_groups-to-struct-addr_location.patch
  new patch: perf-unwind-use-struct-map_symbol-in-struct-unwind_entry.patch
- Support perf report sort key for total cycles per block (jsc#SLE-12720)
  new patch: perf-block-cleanup-and-refactor-block-info-functions.patch
  new patch: perf-cacheline-move-cacheline-related-routines-to-separate-files.patch
  new patch: perf-diff-don-t-use-hack-to-skip-column-length-calculation.patch
  new patch: perf-hist-count-the-total-cycles-of-all-samples.patch
  new patch: perf-hist-support-block-formats-with-compare-sort-display.patch
  new patch: perf-report-sort-by-sampled-cycles-percent-per-block-for-stdio.patch
  new patch: perf-report-sort-by-sampled-cycles-percent-per-block-for-tui.patch
  new patch: perf-report-support-percent-limit-for-total-cycles.patch
- Report sparklines and perhaps stddev for the cycle diffs (jsc#SLE-12721)
  new patch: perf-diff-report-noisy-for-cycles-diff.patch
  new patch: perf-sort-remove-needless-headers-from-sort-h-provide-fwd-struct-decls.patch
  new patch: perf-srcline-add-missing-srcline-h-header-to-files-needing-its-defs.patch
- Perf report. Support interactive annotation of code without symbols (jsc#SLE-12723)
  new patch: perf-map_groups-pass-the-object-to-map_groups__find_ams.patch
  new patch: perf-report-support-interactive-annotation-of-code-without-symbols.patch
  new patch: perf-report-top-do-not-offer-annotation-for-symbols-without-samples.patch
  new patch: perf-report-top-tui-support-hotkey-a-for-annotation-of-unresolved-addresses.patch
  new patch: pref-tools-make-struct-addr_map_symbol-contain-struct-map_symbol.patch
- Add --all-kernel / --all-user to perf stat (jsc#SLE-12724)
  new patch: perf-stat-support-all-kernel-all-user.patch
- Jump to assembler/source view from total cycles tui annotation (jsc#SLE-12728)
  new patch: perf-report-jump-to-symbol-source-view-from-total-cycles-view.patch
  new patch: perf-util-move-block-tui-function-to-ui-browsers.patch
- Update Cascade Lake event list (jsc#SLE-12686)
  new patch: perf-vendor-events-intel-update-cascadelakex-events-to-v1-05.patch
* Thu Oct 29 2020 tonyj@suse.com
- Support a hotkey to change the sort order in interactive browser (jsc#SLE-12726)
  new patch: perf-report-allow-specifying-event-to-be-used-as-sort-key-in-group-output.patch
  new patch: perf-report-support-a-new-key-to-reload-the-browser.patch
  new patch: perf-top-set-display-thread-comm-to-help-with-debugging.patch
  new patch: perf-top-support-group-sort-idx-to-change-the-sort-order.patch
  new patch: perf-top-support-hotkey-to-change-sort-order.patch
* Thu Oct 29 2020 tonyj@suse.com
- Misc perf tools updates for AMD Milan CPUs (jsc#SLE-16757)
  new patch: perf-vendor-events-amd-add-itlb-instruction-fetch-hits-event-for-zen1.patch
  new patch: perf-vendor-events-amd-add-l2-prefetch-events-for-zen1.patch
  new patch: perf-vendor-events-amd-add-l3-cache-events-for-family-17h.patch
  new patch: perf-vendor-events-amd-add-recommended-events.patch
  new patch: perf-vendor-events-amd-add-zen2-events.patch
  new patch: perf-vendor-events-amd-enable-family-19h-users-by-matching-zen2-events.patch
  new patch: perf-vendor-events-amd-remove-trailing-commas.patch
  new patch: perf-vendor-events-amd-restrict-model-detection-for-zen1-based-processors.patch
  new patch: perf-vendor-events-amd-update-zen1-events-to-v2.patch
  new patch: perf-vendor-events-intel-add-icelake-v1-00-event-file.patch
  new patch: perf-vendor-events-intel-add-tremontx-event-file-v1-02.patch
* Thu Oct 29 2020 tonyj@suse.com
- Resolve build error due to kernel-source update adding clashing header.
  New patch: perf-tools-tools-include-should-come-before-tools-uapi-include.patch
* Tue Oct 20 2020 tonyj@suse.com
- Json file metrics for POWER9 hv_24x7 nest events (jsc#SLE-13661)
  new patch: libperf-add-build-version-support.patch
  new patch: libperf-add-debug-output-support.patch
  new patch: libperf-add-libperf-to-the-python-so-build.patch
  new patch: libperf-add-nr_entries-to-struct-perf_evlist.patch
  new patch: libperf-add-perf-core-h-header.patch
  new patch: libperf-add-perf_cpu_map-struct.patch
  new patch: libperf-add-perf_cpu_map__dummy_new-function.patch
  new patch: libperf-add-perf_cpu_map__get-perf_cpu_map__put.patch
  new patch: libperf-add-perf_evlist-and-perf_evsel-structs.patch
  new patch: libperf-add-perf_evlist__add-function.patch
  new patch: libperf-add-perf_evlist__init-function.patch
  new patch: libperf-add-perf_evlist__remove-function.patch
  new patch: libperf-add-perf_evsel__init-function.patch
  new patch: libperf-add-perf_thread_map-struct.patch
  new patch: libperf-add-perf_thread_map__get-perf_thread_map__put.patch
  new patch: libperf-add-perf_thread_map__new_dummy-function.patch
  new patch: libperf-include-perf_evlist-in-evlist-object.patch
  new patch: libperf-include-perf_evsel-in-evsel-object.patch
  new patch: libperf-make-libperf-a-part-of-the-perf-build.patch
  new patch: perf-augmented_raw_syscalls-add-handler-for-openat.patch
  new patch: perf-augmented_raw_syscalls-augment-sockaddr-arg-in-connect.patch
  new patch: perf-augmented_raw_syscalls-rename-augmented_args_filename-to-augmented_args_payload.patch
  new patch: perf-augmented_raw_syscalls-support-copying-two-string-syscall-args.patch
  new patch: perf-augmented_raw_syscalls-switch-to-using-bpf_map_type_prog_array.patch
  new patch: perf-bpf-do-not-attach-a-bpf-prog-to-a-tracepoint-if-its-name-starts-with.patch
  new patch: perf-cpu_map-rename-struct-cpu_map-to-struct-perf_cpu_map.patch
  new patch: perf-debug-remove-needless-include-directives-from-debug-h.patch
  new patch: perf-evlist-rename-perf_evlist__add-to-evlist__add.patch
  new patch: perf-evlist-rename-perf_evlist__close-to-evlist__close.patch
  new patch: perf-evlist-rename-perf_evlist__delete-to-evlist__delete.patch
  new patch: perf-evlist-rename-perf_evlist__disable-to-evlist__disable.patch
  new patch: perf-evlist-rename-perf_evlist__enable-to-evlist__enable.patch
  new patch: perf-evlist-rename-perf_evlist__init-to-evlist__init.patch
  new patch: perf-evlist-rename-perf_evlist__new-to-evlist__new.patch
  new patch: perf-evlist-rename-perf_evlist__open-to-evlist__open.patch
  new patch: perf-evlist-rename-perf_evlist__remove-to-evlist__remove.patch
  new patch: perf-evlist-rename-struct-perf_evlist-to-struct-evlist.patch
  new patch: perf-evsel-rename-perf_evsel__apply_filter-to-evsel__apply_filter.patch
  new patch: perf-evsel-rename-perf_evsel__cpus-to-evsel__cpus.patch
  new patch: perf-evsel-rename-perf_evsel__delete-to-evsel__delete.patch
  new patch: perf-evsel-rename-perf_evsel__disable-to-evsel__disable.patch
  new patch: perf-evsel-rename-perf_evsel__enable-to-evsel__enable.patch
  new patch: perf-evsel-rename-perf_evsel__init-to-evsel__init.patch
  new patch: perf-evsel-rename-perf_evsel__new-to-evsel__new.patch
  new patch: perf-evsel-rename-perf_evsel__open-to-evsel__open.patch
  new patch: perf-evsel-rename-struct-perf_evsel-to-struct-evsel.patch
  new patch: perf-evsel-store-backpointer-to-attached-bpf_object.patch
  new patch: perf-expr-add-expr-c-object.patch
  new patch: perf-expr-add-expr_-prefix-for-parse_ctx-and-parse_id.patch
  new patch: perf-expr-add-expr_scanner_ctx-object.patch
  new patch: perf-expr-fix-copy-paste-mistake.patch
  new patch: perf-expr-increase-expr_max_other-to-support-metrics-with-more-than-15-variables.patch
  new patch: perf-expr-make-expr__parse-return-1-on-error.patch
  new patch: perf-expr-move-expr-lexer-to-flex.patch
  new patch: perf-expr-straighten-expr__parse-expr__find_other-interface.patch
  new patch: perf-include-bpf-add-bpf_tail_call-prototype.patch
  new patch: perf-jevents-support-metric-constraint.patch
  new patch: perf-kvm-s390-add-missing-string-h-header.patch
  new patch: perf-list-hide-deprecated-events-by-default.patch
  new patch: perf-metricgroup-factor-out-metricgroup__add_metric_weak_group.patch
  new patch: perf-metricgroup-fix-printing-event-names-of-metric-group-with-multiple-events-incase-of-overlapping-events.patch
  new patch: perf-metricgroup-fix-printing-event-names-of-metric-group-with-multiple-events.patch
  new patch: perf-metricgroup-remove-needless-includes-from-metricgroup-h.patch
  new patch: perf-metricgroup-scale-the-metric-result.patch
  new patch: perf-metricgroup-support-metric-constraint.patch
  new patch: perf-metricgroup-support-multiple-events-for-metricgroup.patch
  new patch: perf-metricgroups-enhance-json-metric-infrastructure-to-handle.patch
  new patch: perf-metrictroup-split-the-metricgroup__add_metric-function.patch
  new patch: perf-pmu-change-convert_scale-from-static-to-global.patch
  new patch: perf-stat-align-the-output-for-interval-aggregation-mode.patch
  new patch: perf-stat-fix-free-memory-access-memory-leaks-in-metrics.patch
  new patch: perf-stat-move-loaded-out-of-struct-perf_counts_values.patch
  new patch: perf-tests-expr-added-test-for-runtime-param-in-metric-expression.patch
  new patch: perf-tests-remove-needless-headers-for-bp_account.patch
  new patch: perf-tools-enable-hz-hz-prinitg-for-metric-only-option.patch
  new patch: perf-tools-remove-debug-h-from-header-files-not-needing-it.patch
  new patch: perf-tools-remove-util-h-from-where-it-is-not-needed.patch
  new patch: perf-tools-rename-struct-thread_map-to-struct-perf_thread_map.patch
  new patch: perf-tools-use-define-api-pure-full-instead-of-pure-parser.patch
  new patch: perf-trace-add-bpf-handler-for-unaugmented-syscalls.patch
  new patch: perf-trace-add-pointer-to-bpf-object-containing-_augmented_syscalls__.patch
  new patch: perf-trace-add-sendfile64-alias-to-the-sendfile-syscall.patch
  new patch: perf-trace-allow-specifying-the-bpf-prog-to-augment-specific-syscalls.patch
  new patch: perf-trace-beauty-add-bpf-augmenter-for-the-rename-syscall.patch
  new patch: perf-trace-beauty-beautify-bind-s-sockaddr-arg.patch
  new patch: perf-trace-beauty-beautify-sendto-s-sockaddr-arg.patch
  new patch: perf-trace-beauty-disable-fd-pathname-when-close-not-enabled.patch
  new patch: perf-trace-beauty-do-not-try-to-use-the-fd-pathname-beautifier-for-bind-connect-fd-arg.patch
  new patch: perf-trace-beauty-make-connect-s-addrlen-be-printed-as-an-int-not-hex.patch
  new patch: perf-trace-forward-error-codes-when-trying-to-read-syscall-info.patch
  new patch: perf-trace-handle-raw_syscalls-sys_enter-just-like-the-bpf_output-augmented-event.patch
  new patch: perf-trace-look-for-default-name-for-entries-in-the-syscalls-prog-array.patch
  new patch: perf-trace-look-up-maps-just-on-the-_augmented_syscalls__-bpf-object.patch
  new patch: perf-trace-mark-syscall-ids-that-are-not-allocated-to-avoid-unnecessary-error-messages.patch
  new patch: perf-trace-order-e-syscalls-table.patch
  new patch: perf-trace-preallocate-the-syscall-table.patch
  new patch: perf-trace-put-the-per-syscall-entry-exit-prog_array-bpf-map-infrastructure-in-place.patch
  new patch: perf-trace-reuse-bpf-augmenters-from-syscalls-with-similar-args-signature.patch
  new patch: perf-util-factor-out-sysctl__nmi_watchdog_enabled.patch
  new patch: perf-vendor-events-power9-add-hv_24x7-socket-chip-level-metric-events.patch
  refresh patch: perf-intel-pt-process-options-for-pebs-event-synthesis.patch
  refresh patch: perf-metrics-fix-parse-errors-in-power8-metrics.patch
  refresh patch: perf-metrics-fix-parse-errors-in-power9-metrics.patch
  refresh patch: perf-report-fix-no-branch-type-statistics-report-issue.patch
  refresh patch: perf-stat-don-t-report-a-null-stalled-cycles-per-insn-metric.patch
  refresh patch: perf-stat-ensure-group-is-defined-on-top-of-the-same-cpu-mask.patch
  refresh patch: perf-tests-fix-out-of-bounds-memory-access.patch
  refresh patch: perf-tools-fix-record-failure-when-mixed-with-arm-spe-event.patch
* Thu Aug 13 2020 tonyj@suse.com
- Add latest git-fixes (bsc#1175256)
  * perf bpf-loader: Add missing '*' for key_scan_pos
    New patch: perf-bpf-loader-add-missing-for-key_scan_pos.patch
  * perf cs-etm: Move definition of 'traceid_list' global variable from header
    file
    New patch: perf-cs-etm-move-definition-of-traceid_list-global-variable-from-header-file.patch
  * perf env: Do not return pointers to local variables
    New patch: perf-env-do-not-return-pointers-to-local-variables.patch
  * perf intel-pt: Fix PEBS sample for XMM registers
    New patch: perf-intel-pt-fix-pebs-sample-for-xmm-registers.patch
  * perf: Make perf able to build with latest libbfd
    New patch: perf-make-perf-able-to-build-with-latest-libbfd.patch
  * perf metrics: Fix parse errors in power8 metrics
    New patch: perf-metrics-fix-parse-errors-in-power8-metrics.patch
  * perf metrics: Fix parse errors in power9 metrics
    New patch: perf-metrics-fix-parse-errors-in-power9-metrics.patch
  * perf metrics: Fix parse errors in skylake metrics
    New patch: perf-metrics-fix-parse-errors-in-skylake-metrics.patch
  * perf parse-events: Fix an incompatible pointer
    New patch: perf-parse-events-fix-an-incompatible-pointer.patch
  * perf probe: Check address correctness by map instead of _etext
    New patch: perf-probe-check-address-correctness-by-map-instead-of-etext.patch
  * perf probe: Do not show the skipped events
    New patch: perf-probe-do-not-show-the-skipped-events.patch
  * perf probe: Fix to check blacklist address correctly
    New patch: perf-probe-fix-to-check-blacklist-address-correctly.patch
  * perf report: Fix NULL pointer dereference in hists__fprintf_nr_sample_events
    New patch: perf-report-fix-null-pointer-dereference-in-hists__fprintf_nr_sample_events.patch
  * perf report TUI: Fix segmentation fault in perf_evsel__hists_browse()
    New patch: perf-report-tui-fix-segmentation-fault-in-perf_evsel__hists_browse.patch
  * perf scripts python: export-to-postgresql.py: Fix struct.pack() int argument
    New patch: perf-scripts-python-export-to-postgresql-py-fix-struct-pack-int-argument.patch
  * perf scripts python: exported-sql-viewer.py: Fix unexpanded 'Find' result
    New patch: perf-scripts-python-exported-sql-viewer-py-fix-unexpanded-find-result.patch
  * perf scripts python: exported-sql-viewer.py: Fix zero id in call graph find
    result
    New patch: perf-scripts-python-exported-sql-viewer-py-fix-zero-id-in-call-graph-find-result.patch
  * perf scripts python: exported-sql-viewer.py: Fix zero id in call tree find
    result
    New patch: perf-scripts-python-exported-sql-viewer-py-fix-zero-id-in-call-tree-find-result.patch
  * perf stat: Ensure group is defined on top of the same cpu mask
    New patch: perf-stat-ensure-group-is-defined-on-top-of-the-same-cpu-mask.patch
  * perf stat: Fix duration_time value for higher intervals
    New patch: perf-stat-fix-duration_time-value-for-higher-intervals.patch
  * perf stat: Fix NULL pointer dereference
    New patch: perf-stat-fix-null-pointer-dereference.patch
  * perf stat: Fix wrong per-thread runtime stat for interval mode
    New patch: perf-stat-fix-wrong-per-thread-runtime-stat-for-interval-mode.patch
  * perf stat: Honour --timeout for forked workloads
    New patch: perf-stat-honour-timeout-for-forked-workloads.patch
  * perf stat: Improve runtime stat for interval mode
    New patch: perf-stat-improve-runtime-stat-for-interval-mode.patch
  * perf stat: Zero all the 'ena' and 'run' array slot stats for interval mode
    New patch: perf-stat-zero-all-the-ena-and-run-array-slot-stats-for-interval-mode.patch
  * perf test session topology: Fix data path
    New patch: perf-test-session-topology-fix-data-path.patch
  * perf tools: Fix reading new topology attribute "core_cpus"
    New patch: perf-tools-fix-reading-new-topology-attribute-core_cpus.patch
  * perf tools: Fix record failure when mixed with ARM SPE event
    New patch: perf-tools-fix-record-failure-when-mixed-with-arm-spe-event.patch
  * perf vendor events intel: Update all the Intel JSON metrics from TMAM
    New patch: perf-vendor-events-intel-update-all-the-intel-json-metrics-from-tmam-3-6.patch
* Fri May 29 2020 tonyj@suse.com
- Add support for new IBM S390 z15 deflate counters (bsc#1169763)
  New patch: perf-vendor-events-s390-add-new-deflate-counters-for-ibm-z15.patch
  New patch: perf-vendor-events-s390-use-s390-machine-name-instead-of-type-8561.patch
* Thu May 21 2020 tonyj@suse.com
- Add latest git-fixes
  * Fix snprintf overflow check
  * Fix off by one in strncpy() size argument
  * Fix binding of AIO user space buffers to nodes
  * Fix no branch type statistics report issue
  New patch: perf-cpumap-fix-snprintf-overflow-check.patch
  New patch: perf-map-fix-off-by-one-in-strncpy-size-argument.patch
  New patch: perf-record-fix-binding-of-aio-user-space-buffers-to-nodes.patch
  New patch: perf-report-fix-no-branch-type-statistics-report-issue.patch
* Fri Mar 27 2020 tonyj@suse.com
- Add latest git-fixes
  * perf bench futex-wake: Restore thread count default to online CPU
  * perf c2c: Display proper cpu count in nodes column
  * perf c2c: Fix report with offline cpus
  * perf callchain: Fix segfault in thread__resolve_callchain_sample()
  * perf diff: Use llabs() with 64-bit values
  * perf hists browser: Restore ESC as "Zoom out" of DSO/thread/etc
  * perf hists: Fix variable name's inconsistency in hists__for_each()
  * perf jevents: Fix resource leak in process_mapfile() and main()
  * perf list: Allow plurals for metric, metricgroup
  * perf map: No need to adjust the long name of modules
  * perf probe: Filter out instances except for inlined subroutine and
  * perf probe: Fix to find range-only function instance
  * perf probe: Fix to list probe event with correct line number
  * perf probe: Fix to probe a function which has no entry pc
  * perf probe: Fix to probe an inline function which has no entry pc
  * perf probe: Fix to show calling lines of inlined functions
  * perf probe: Fix to show function entry line as probe-able
  * perf probe: Fix to show inlined function callsite without entry_pc
  * perf probe: Fix to show ranges of variables in functions without
  * perf probe: Fix wrong address verification
  * perf probe: Skip end-of-sequence and non statement lines
  * perf probe: Skip overlapped location on searching variables
  * perf probe: Walk function lines in lexical blocks
  * perf regs: Make perf_reg_name() return "unknown" instead of NULL
  * perf report: Fix incorrectly added dimensions as switch perf data file
  * perf script: Allow --time with --reltime
  * perf script: Fix brstackinsn for AUXTRACE
  * perf stat: Don't report a null stalled cycles per insn metric
  * perf test: Report failure for mmap events
  * perf tests: Fix out of bounds memory access
  * perf ui gtk: Add missing zalloc object
  * perf vendor events amd: Remove redundant '['
  * perf vendor events arm64: Fix Hisi hip08 DDRC PMU eventname
  * perf vendor events: Remove P8 HW events which are not supported
  * perf vendor events s390: Add JSON transaction for machine type 8561
  * perf vendor events s390: Remove name from L1D_RO_EXCL_WRITES
  New patch: perf-bench-futex-wake-restore-thread-count-default-to-online-cpu-count.patch
  New patch: perf-c2c-display-proper-cpu-count-in-nodes-column.patch
  New patch: perf-c2c-fix-report-with-offline-cpus.patch
  New patch: perf-callchain-fix-segfault-in-thread__resolve_callchain_sample.patch
  New patch: perf-diff-use-llabs-with-64-bit-values.patch
  New patch: perf-hists-browser-restore-esc-as-zoom-out-of-dso-thread-etc.patch
  New patch: perf-hists-fix-variable-name-s-inconsistency-in-hists__for_each-macro.patch
  New patch: perf-jevents-fix-resource-leak-in-process_mapfile-and-main.patch
  New patch: perf-list-allow-plurals-for-metric-metricgroup.patch
  New patch: perf-map-no-need-to-adjust-the-long-name-of-modules.patch
  New patch: perf-probe-filter-out-instances-except-for-inlined-subroutine-and-subprogram.patch
  New patch: perf-probe-fix-to-find-range-only-function-instance.patch
  New patch: perf-probe-fix-to-list-probe-event-with-correct-line-number.patch
  New patch: perf-probe-fix-to-probe-a-function-which-has-no-entry-pc.patch
  New patch: perf-probe-fix-to-probe-an-inline-function-which-has-no-entry-pc.patch
  New patch: perf-probe-fix-to-show-calling-lines-of-inlined-functions.patch
  New patch: perf-probe-fix-to-show-function-entry-line-as-probe-able.patch
  New patch: perf-probe-fix-to-show-inlined-function-callsite-without-entry_pc.patch
  New patch: perf-probe-fix-to-show-ranges-of-variables-in-functions-without-entry_pc.patch
  New patch: perf-probe-fix-wrong-address-verification.patch
  New patch: perf-probe-skip-end-of-sequence-and-non-statement-lines.patch
  New patch: perf-probe-skip-overlapped-location-on-searching-variables.patch
  New patch: perf-probe-walk-function-lines-in-lexical-blocks.patch
  New patch: perf-regs-make-perf_reg_name-return-unknown-instead-of-null.patch
  New patch: perf-report-fix-incorrectly-added-dimensions-as-switch-perf-data-file.patch
  New patch: perf-script-allow-time-with-reltime.patch
  New patch: perf-script-fix-brstackinsn-for-auxtrace.patch
  New patch: perf-stat-don-t-report-a-null-stalled-cycles-per-insn-metric.patch
  New patch: perf-test-report-failure-for-mmap-events.patch
  New patch: perf-tests-fix-out-of-bounds-memory-access.patch
  New patch: perf-ui-gtk-add-missing-zalloc-object.patch
  New patch: perf-vendor-events-amd-remove-redundant.patch
  New patch: perf-vendor-events-arm64-fix-hisi-hip08-ddrc-pmu-eventname.patch
  New patch: perf-vendor-events-remove-p8-hw-events-which-are-not-supported.patch
  New patch: perf-vendor-events-s390-add-json-transaction-for-machine-type-8561.patch
  New patch: perf-vendor-events-s390-remove-name-from-l1d_ro_excl_writes-description.patch
* Mon Nov 25 2019 tonyj@suse.com
- Provide PEBS data via Intel PT trace logs (JIRA#SLE-9874)
  New patch: perf-tools-add-aux_output-attribute-flag.patch
  New patch: perf-tools-add-itrace-option-o-to-synthesize-aux-output-events.patch
  New patch: perf-intel-pt-process-options-for-pebs-event-synthesis.patch
  New patch: perf-tools-add-aux-output-config-term.patch
  New patch: perf-intel-pt-add-brief-documentation-for-pebs-via-intel-pt.patch
* Mon Nov 18 2019 tonyj@suse.com
- fix gtk2 detection (based on Factory change by iri Slaby <jslaby@suse.com>)
* Thu Aug  8 2019 tonyj@suse.com
- Fork for SP2 (v5.3 kernel source)
  Delete patch: perf-annotate-browser-display-titles-in-left-frame.patch
  Delete patch: perf-annotate-do-not-overwrite-sample-period.patch
  Delete patch: perf-annotate-document-show-total-period-option.patch
  Delete patch: perf-annotate-fix-storing-per-line-sym_hist_entry.patch
  Delete patch: perf-annotate-introduce-struct-sym_hist_entry.patch
  Delete patch: perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
  Delete patch: perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
  Delete patch: perf-annotate-stdio-fix-show-total-period.patch
  Delete patch: perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
  Delete patch: perf-annotate-stdio-support-show-nr-samples-option.patch
  Delete patch: perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
  Delete patch: perf-annotate-tui-clarify-calculation-of-column-header-widths.patch
  Delete patch: perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
  Delete patch: perf-annotate-tui-fix-show-total-period.patch
  Delete patch: perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
  Delete patch: perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
  Delete patch: perf-arm-spe-Fix-uninitialized-record-error-variable.patch
  Delete patch: perf-arm64-Generate-system-call-table-from-asm-unist.patch
  Delete patch: perf-arm64-fix-generate-system-call-table-failed-with-tmp-mounted-with-noexec.patch
  Delete patch: perf-arm64-fix-include-path-for-asm-generic-unistd-h.patch
  Delete patch: perf-auxtrace-arm-Fixing-uninitialised-variable.patch
  Delete patch: perf-c2c-fix-c2c-report-for-empty-numa-node.patch
  Delete patch: perf-c2c-fix-spelling-mistakes-in-browser-help-text.patch
  Delete patch: perf-c2c-report-fix-crash-for-empty-browser.patch
  Delete patch: perf-events-parse-Remove-some-needless-local-variabl.patch
  Delete patch: perf-events-parse-Rename-parse_events_parse-argument.patch
  Delete patch: perf-events-parse-Rename-parsing-state-struct-to-cle.patch
  Delete patch: perf-events-parse-Use-just-one-parse-events-state-st.patch
  Delete patch: perf-evlist-remove-evlist-overwrite.patch
  Delete patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap.patch
  Delete patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap_ex.patch
  Delete patch: perf-evlist-remove-stale-mmap-read-for-backward.patch
  Delete patch: perf-evsel-add-read_counter.patch
  Delete patch: perf-evsel-add-verbose-output-for-sys_perf_event_open-fallback.patch
  Delete patch: perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
  Delete patch: perf-evsel-expose-the-perf_missing_features-struct.patch
  Delete patch: perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
  Delete patch: perf-evsel-only-fall-back-group-read-for-leader.patch
  Delete patch: perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
  Delete patch: perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
  Delete patch: perf-header-add-struct-feat_fd-for-write.patch
  Delete patch: perf-header-encapsulate-read-and-swap.patch
  Delete patch: perf-header-fail-on-write_padded-error.patch
  Delete patch: perf-header-fix-wrong-node-write-in-numa_topology-feature.patch
  Delete patch: perf-header-remove-unused-cpu_nr-field-from-struct-cpu_topo.patch
  Delete patch: perf-header-revamp-do_write.patch
  Delete patch: perf-help-fix-a-bug-during-strstart-conversion.patch
  Delete patch: perf-hists-browser-add-parameter-to-disable-lost-event-warning.patch
  Delete patch: perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
  Delete patch: perf-jevents-Make-build-fail-on-JSON-parse-error.patch
  Delete patch: perf-jevents-support-fcmask-and-portmask.patch
  Delete patch: perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
  Delete patch: perf-list-Add-metric-groups-to-perf-list.patch
  Delete patch: perf-mem-allow-all-record-report-options.patch
  Delete patch: perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
  Delete patch: perf-mem-document-a-missing-option.patch
  Delete patch: perf-mem-document-incorrect-and-missing-options.patch
  Delete patch: perf-mmap-add-new-return-value-logic-for-perf_mmap__read_init.patch
  Delete patch: perf-mmap-adopt-push-method-from-builtin-record-c.patch
  Delete patch: perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
  Delete patch: perf-mmap-cleanup-perf_mmap__push.patch
  Delete patch: perf-mmap-discard-legacy-interface-for-mmap-read.patch
  Delete patch: perf-mmap-discard-prev-in-perf_mmap__read.patch
  Delete patch: perf-mmap-don-t-discard-prev-in-backward-mode.patch
  Delete patch: perf-mmap-fix-accessing-unmapped-mmap-in-perf_mmap__read_done.patch
  Delete patch: perf-mmap-fix-perf-backward-recording.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_done.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_event.patch
  Delete patch: perf-mmap-introduce-perf_mmap__read_init.patch
  Delete patch: perf-mmap-move-perf_mmap-and-methods-to-separate-mmap-files.patch
  Delete patch: perf-mmap-recalculate-size-for-overwrite-mode.patch
  Delete patch: perf-mmap-remove-overwrite-and-check_messup-from-mmap-read.patch
  Delete patch: perf-mmap-remove-overwrite-from-arguments-list-of-perf_mmap__push.patch
  Delete patch: perf-pmu-Add-check-for-valid-cpuid-in-perf_pmu__find.patch
  Delete patch: perf-pmu-Pass-pmu-as-a-parameter-to-get_cpuid_str.patch
  Delete patch: perf-pmu-Unbreak-perf-record-for-arm-arm64-with-even.patch
  Delete patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  Delete patch: perf-probe-arm64-Fix-symbol-fixup-issues-due-to-ELF-.patch
  Delete patch: perf-probe-fix-kprobe-blacklist-checking-condition.patch
  Delete patch: perf-probe-support-sdt-markers-having-reference-counter-semaphore.patch
  Delete patch: perf-provide-definition-for-einval-on-32bit.patch
  Delete patch: perf-python-do-not-force-closing-original-perf-descriptor-in-evlist-get_pollfd.patch
  Delete patch: perf-python-make-clang_has_option-work-on-python-3.patch
  Delete patch: perf-python-make-twatch-py-work-with-both-python2-and-python3.patch
  Delete patch: perf-python-remove-mcet-and-fcf-protection-when-building-with-clang.patch
  Delete patch: perf-python-use-wno-redundant-decls-to-build-with-python-python3.patch
  Delete patch: perf-record-enable-arbitrary-event-names-thru-name-modifier.patch
  Delete patch: perf-record-make-record__mmap_read-generic.patch
  Delete patch: perf-report-extend-raw-dump-d-out-with-switch-out-event-type.patch
  Delete patch: perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
  Delete patch: perf-script-add-missing-output-fields-in-a-hint.patch
  Delete patch: perf-script-add-support-to-display-sample-misc-field.patch
  Delete patch: perf-script-allow-adding-and-removing-fields.patch
  Delete patch: perf-script-extend-misc-field-decoding-with-switch-out-event-type.patch
  Delete patch: perf-script-fix-crash-when-processing-recorded-stat-data.patch
  Delete patch: perf-script-fix-crash-with-printing-mixed-trace-point-and-other-events.patch
  Delete patch: perf-script-python-add-perf_sample-dict-to-tracepoint-handlers.patch
  Delete patch: perf-script-python-add-printdate-function-to-sql-exporters.patch
  Delete patch: perf-script-python-add-python3-support-to-check-perf-trace-py.patch
  Delete patch: perf-script-python-add-python3-support-to-event_analyzing_sample-py.patch
  Delete patch: perf-script-python-add-python3-support-to-export-to-postgresql-py.patch
  Delete patch: perf-script-python-add-python3-support-to-exported-sql-viewer-py.patch
  Delete patch: perf-script-python-add-python3-support-to-failed-syscalls-by-pid-py.patch
  Delete patch: perf-script-python-add-python3-support-to-futex-contention-py.patch
  Delete patch: perf-script-python-add-python3-support-to-net_dropmonitor-py.patch
  Delete patch: perf-script-python-add-python3-support-to-netdev-times-py.patch
  Delete patch: perf-script-python-add-python3-support-to-sctop-py.patch
  Delete patch: perf-script-python-add-python3-support-to-stackcollapse-py.patch
  Delete patch: perf-script-python-add-python3-support-to-stat-cpi-py.patch
  Delete patch: perf-script-python-add-python3-support-to-syscall-counts-by-pid-py.patch
  Delete patch: perf-script-python-add-python3-support-to-syscall-counts-py.patch
  Delete patch: perf-script-python-add-python3-support-to-tests-attr-py.patch
  Delete patch: perf-script-python-add-sample_read-to-dict.patch
  Delete patch: perf-script-python-add-trace_context-extension-module-to-sys-modules.patch
  Delete patch: perf-script-python-allocate-memory-only-if-handler-exists.patch
  Delete patch: perf-script-python-refactor-creation-of-perf-sample-dict.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-python-scripts.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-setup-py.patch
  Delete patch: perf-script-python-remove-explicit-shebang-from-tests-attr-c.patch
  Delete patch: perf-script-python-remove-mixed-indentation.patch
  Delete patch: perf-script-python-use-pybytes-for-attr-in-trace-event-python.patch
  Delete patch: perf-script-show-hw-cache-events.patch
  Delete patch: perf-scripting-python-add-ppc64le-to-audit-uname-list.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-core-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-eventclass-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-sched-migration-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-schedgui-py.patch
  Delete patch: perf-scripts-python-add-python-3-support-to-util-py.patch
  Delete patch: perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
  Delete patch: perf-stat-Factor-out-generic-metric-printing.patch
  Delete patch: perf-stat-Only-auto-merge-events-that-are-PMU-aliase.patch
  Delete patch: perf-stat-Support-JSON-metrics-in-perf-stat.patch
  Delete patch: perf-stat-enable-1ms-interval-for-printing-event-counters-values.patch
  Delete patch: perf-stat-use-group-read-for-event-groups.patch
  Delete patch: perf-symbols-Fix-plt-entry-calculation-for-ARM-and-A.patch
  Delete patch: perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patch
  Delete patch: perf-symbols-set-plt-entry-header-sizes-properly-on-sparc.patch
  Delete patch: perf-test-add-test-cases-for-new-data-source-encoding.patch
  Delete patch: perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
  Delete patch: perf-test-powerpc-fix-object-code-reading-test.patch
  Delete patch: perf-test-sdt-handle-realpath-failure.patch
  Delete patch: perf-test-update-mmap-read-functions-for-backward-ring-buffer-test.patch
  Delete patch: perf-tests-Run-dwarf-unwind-test-on-arm32.patch
  Delete patch: perf-tests-attr-fix-no-delay-test.patch
  Delete patch: perf-tests-set-evlist-of-test__backward_ring_buffer-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__basic_mmap-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__sw_clock_freq-to-overwrite.patch
  Delete patch: perf-tests-set-evlist-of-test__task_exit-to-overwrite.patch
  Delete patch: perf-tools-Add-ARM-Statistical-Profiling-Extensions-.patch
  Delete patch: perf-tools-add-cpu_topology-object.patch
  Delete patch: perf-tools-add-numa_topology-object.patch
  Delete patch: perf-tools-add-perf_evsel__read_size-function.patch
  Delete patch: perf-tools-add-python-3-support.patch
  Delete patch: perf-tools-add-support-for-printing-new-mem_info-encodings.patch
  Delete patch: perf-tools-arm64-Add-libdw-DWARF-post-unwind-support.patch
  Delete patch: perf-tools-arm64-Add-support-for-get_cpuid_str-funct.patch
  Delete patch: perf-tools-fix-python-extension-build-for-gcc-8.patch
  Delete patch: perf-tools-handle-topology-headers-with-no-cpu.patch
  Delete patch: perf-tools-really-install-manpages-via-make-install-man.patch
  Delete patch: perf-tools-rename-backward-to-overwrite-in-evlist-mmap-and-record.patch
  Delete patch: perf-top-add-overwrite-fall-back.patch
  Delete patch: perf-top-allow-disabling-the-overwrite-mode.patch
  Delete patch: perf-top-check-per-event-overwrite-term.patch
  Delete patch: perf-top-check-the-latency-of-perf_top__mmap_read.patch
  Delete patch: perf-top-do-not-use-overwrite-mode-by-default.patch
  Delete patch: perf-top-fix-annoying-fallback-message-on-older-kernels.patch
  Delete patch: perf-top-fix-window-dimensions-change-handling.patch
  Delete patch: perf-top-remove-lost-events-checking.patch
  Delete patch: perf-top-switch-default-mode-to-overwrite-mode.patch
  Delete patch: perf-trace-fix-off-by-one-string-allocation-problem.patch
  Delete patch: perf-util-add-const-modifier-to-buf-in-writen-function.patch
  Delete patch: perf-vendor-events-Add-support-for-arch-standard-eve.patch
  Delete patch: perf-vendor-events-Add-support-for-pmu-events-vendor.patch
  Delete patch: perf-vendor-events-Drop-incomplete-multiple-mapfile-.patch
  Delete patch: perf-vendor-events-Drop-support-for-unused-topic-dir.patch
  Delete patch: perf-vendor-events-Fix-error-code-in-json_events.patch
  Delete patch: perf-vendor-events-Support-metric_group-and-no-event.patch
  Delete patch: perf-vendor-events-aarch64-Add-JSON-metrics-for-ARM-.patch
  Delete patch: perf-vendor-events-add-core-event-list-for-skylake-server.patch
  Delete patch: perf-vendor-events-add-goldmont-plus-v1-event-file.patch
  Delete patch: perf-vendor-events-add-skylake-server-uncore-event-list.patch
  Delete patch: perf-vendor-events-arm64-Add-ThunderX2-implementatio.patch
  Delete patch: perf-vendor-events-arm64-Add-armv8-recommended.json.patch
  Delete patch: perf-vendor-events-arm64-Enable-JSON-events-for-Thun.patch
  Delete patch: perf-vendor-events-arm64-Enable-JSON-events-for-eMAG.patch
  Delete patch: perf-vendor-events-arm64-Fixup-ThunderX2-to-use-reco.patch
  Delete patch: perf-vendor-events-arm64-Relocate-Cortex-A53-JSONs-t.patch
  Delete patch: perf-vendor-events-arm64-Relocate-ThunderX2-JSON-to-.patch
  Delete patch: perf-vendor-events-arm64-Update-ThunderX2-implementa.patch
  Delete patch: perf-vendor-events-arm64-add-HiSilicon-hip08-JSON-fi.patch
  Delete patch: perf-vendor-events-arm64-fixup-A53-to-use-recommende.patch
  Delete patch: perf-vendor-events-update-power9-events-9749adc3.patch
  Delete patch: perf-vendor-events-update-power9-events-e795dd42.patch
  Delete patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
  Delete patch: tools-include-Adopt-strstarts-from-the-kernel.patch
- Merge Factory change
  Tue Oct 16 22:51:15 UTC 2018 - Tony Jones <tonyj@suse.com>
  - Update examples paths to resolve build failures.
* Tue Jul 23 2019 tonyj@suse.com
- perf script: Fix crash printing mixed tracepoint/other events (bsc#1142104)
  New patch: perf-script-fix-crash-with-printing-mixed-trace-point-and-other-events.patch
* Thu Mar 28 2019 tonyj@suse.com
- Correct missing static qualifier in previous backport of
  perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
- Git-fixes:
  New patch: perf-python-do-not-force-closing-original-perf-descriptor-in-evlist-get_pollfd.patch
* Sat Mar 23 2019 tonyj@suse.com
- Handle empty node 0 topology for c2c (bsc#1127191)
  New patch: perf-header-encapsulate-read-and-swap.patch
  New patch: perf-util-add-const-modifier-to-buf-in-writen-function.patch
  New patch: perf-header-fail-on-write_padded-error.patch
  New patch: perf-header-revamp-do_write.patch
  New patch: perf-header-add-struct-feat_fd-for-write.patch
  New patch: perf-header-remove-unused-cpu_nr-field-from-struct-cpu_topo.patch
  New patch: perf-header-fix-wrong-node-write-in-numa_topology-feature.patch
  New patch: perf-tools-add-cpu_topology-object.patch
  New patch: perf-tools-add-numa_topology-object.patch
  New patch: perf-c2c-fix-c2c-report-for-empty-numa-node.patch
  New patch: perf-tools-handle-topology-headers-with-no-cpu.patch
  New patch: perf-c2c-fix-spelling-mistakes-in-browser-help-text.patch
  New patch: perf-c2c-report-fix-crash-for-empty-browser.patch
* Fri Mar 22 2019 tonyj@suse.com
- Refresh patches for previous Python3 (Thu Jan 10 23:23:28 UTC 2019)
  submission now that all patches are upstream
  Delete patch: port-netdev-times-script-to-python3.patch
  Delete patch: port-check-perf-trace-script-to-python3.patch
  Delete patch: port-event_analyzing_sample-script-to-python3.patch
  Delete patch: port-failed-syscalls-by-pid-script-to-python3.patch
  Delete patch: port-futex-contention-script-to-python3.patch
  Delete patch: port-net_dropmonitor-script-to-python3.patch
  Delete patch: port-sctop-script-to-python3.patch
  Delete patch: port-stackcollapse-script-to-python3.patch
  Delete patch: port-stat-cpi-script-to-python3.patch
  Delete patch: port-syscall-counts-by-pid-script-to-python3.patch
  Delete patch: port-python-syscall-counts-script-to-python3.patch
  Delete patch: remove-shebang-from-scripts-python.patch
  Delete patch: remove-shebang-from-tests-attr.py.patch
  Delete patch: remove-shebang-from-util-setup.py.patch
  Delete patch: update-tests-attr.py-to-support-python3.patch
  Delete patch: use-pybytes-for-attr-in-trace-event-python.patch
  New patch: perf-script-python-add-printdate-function-to-sql-exporters.patch
  New patch: perf-script-python-add-python3-support-to-export-to-postgresql-py.patch
  New patch: perf-script-python-add-python3-support-to-exported-sql-viewer-py.patch
  New patch: perf-script-python-add-python3-support-to-failed-syscalls-by-pid-py.patch
  New patch: perf-script-python-add-python3-support-to-futex-contention-py.patch  New patch: perf-script-python-add-python3-support-to-net_dropmonitor-py.patch
  New patch: perf-script-python-add-python3-support-to-netdev-times-py.patch
  New patch: perf-script-python-add-python3-support-to-sctop-py.patch
  New patch: perf-script-python-add-python3-support-to-stackcollapse-py.patch
  New patch: perf-script-python-add-python3-support-to-stat-cpi-py.patch
  New patch: perf-script-python-add-python3-support-to-syscall-counts-by-pid-py.patch
  New patch: perf-script-python-add-python3-support-to-syscall-counts-py.patch
  New patch: perf-script-python-add-python3-support-to-tests-attr-py.patch
  New patch: perf-script-python-add-trace_context-extension-module-to-sys-modules.patch
  New patch: perf-script-python-remove-explicit-shebang-from-python-scripts.patch
  New patch: perf-script-python-remove-explicit-shebang-from-setup-py.patch
  New patch: perf-script-python-remove-explicit-shebang-from-tests-attr-c.patch
  New patch: perf-script-python-remove-mixed-indentation.patch
  New patch: perf-script-python-add-python3-support-to-check-perf-trace-py.patch
  New patch: perf-script-python-add-python3-support-to-event_analyzing_sample-py.patch
  New patch: perf-script-python-use-pybytes-for-attr-in-trace-event-python.patch
* Fri Mar 22 2019 tonyj@suse.com
- Fix crash when processing recorded stat data
  New patch: perf-script-fix-crash-when-processing-recorded-stat-data.patch
* Wed Feb 13 2019 tonyj@suse.com
- Add POWER mem/c2c support (FATE#326866, bsc#1124370)
  New patch: perf-mem-c2c-fix-perf_mem_events-to-support-powerpc.patch
  New patch: perf-mem-allow-all-record-report-options.patch
  New patch: perf-mem-document-a-missing-option.patch
  New patch: perf-mem-document-incorrect-and-missing-options.patch
* Fri Feb  1 2019 tonyj@suse.com
- Uprobes: Support for SDT events with reference counter
  (FATE#326782, bsc#1115391)
  New patch: perf-probe-support-sdt-markers-having-reference-counter-semaphore.patch
* Mon Jan 14 2019 tonyj@suse.com
- Add support for VTune (FATE#326324)
  New patch:  perf-record-enable-arbitrary-event-names-thru-name-modifier.patch
  New patch:  perf-report-extend-raw-dump-d-out-with-switch-out-event-type.patch
  New patch:  perf-script-add-missing-output-fields-in-a-hint.patch
  New patch:  perf-script-add-support-to-display-sample-misc-field.patch
  New patch:  perf-script-allow-adding-and-removing-fields.patch
  New patch:  perf-script-extend-misc-field-decoding-with-switch-out-event-type.patch
  New patch:  perf-stat-enable-1ms-interval-for-printing-event-counters-values.patch
* Thu Jan 10 2019 tonyj@suse.com
- Enable python3.  Remove all uses of python2 (bsc#1082197)
  New patch: perf-script-python-allocate-memory-only-if-handler-exists.patch
  New patch: perf-script-python-refactor-creation-of-perf-sample-dict.patch
  New patch: perf-script-python-add-sample_read-to-dict.patch
  New patch: perf-script-python-add-perf_sample-dict-to-tracepoint-handlers.patch
  New patch: perf-python-make-twatch-py-work-with-both-python2-and-python3.patch
  New patch: perf-tools-add-python-3-support.patch
  New patch: perf-tools-fix-python-extension-build-for-gcc-8.patch
  New patch: perf-scripts-python-add-python-3-support-to-util-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-sched-migration-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-schedgui-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-eventclass-py.patch
  New patch: perf-scripts-python-add-python-3-support-to-core-py.patch
  New patch: perf-python-remove-mcet-and-fcf-protection-when-building-with-clang.patch
  New patch: perf-python-use-wno-redundant-decls-to-build-with-python-python3.patch
  New patch: perf-python-make-clang_has_option-work-on-python-3.patch
  New patch: update-tests-attr.py-to-support-python3.patch
  New patch: remove-shebang-from-util-setup.py.patch
  New patch: remove-shebang-from-tests-attr.py.patch
  New patch: remove-shebang-from-scripts-python.patch
  New patch: add-trace_context-extension-module-to-sys-modules.patch
  New patch: use-pybytes-for-attr-in-trace-event-python.patch
  New patch: port-netdev-times-script-to-python3.patch
  New patch: port-check-perf-trace-script-to-python3.patch
  New patch: port-event_analyzing_sample-script-to-python3.patch
  New patch: port-failed-syscalls-by-pid-script-to-python3.patch
  New patch: port-futex-contention-script-to-python3.patch
  New patch: port-net_dropmonitor-script-to-python3.patch
  New patch: port-sctop-script-to-python3.patch
  New patch: port-stackcollapse-script-to-python3.patch
  New patch: port-stat-cpi-script-to-python3.patch
  New patch: port-syscall-counts-by-pid-script-to-python3.patch
  New patch: port-python-syscall-counts-script-to-python3.patch
  New patch: port-sql-scripts-to-python3.patch
* Tue Nov 13 2018 tonyj@suse.com
- Add support for ARMv8.x-A statistical profiling extension (FATE#325865)
- Add support for ARMv8.1-PMU: ARMv8.1 PMU Extensions (FATE#325861)
  New patch: perf-arm64-Generate-system-call-table-from-asm-unist.patch
  New patch: perf-arm-spe-Fix-uninitialized-record-error-variable.patch
  New patch: perf-auxtrace-arm-Fixing-uninitialised-variable.patch
  New patch: perf-events-parse-Remove-some-needless-local-variabl.patch
  New patch: perf-events-parse-Rename-parse_events_parse-argument.patch
  New patch: perf-events-parse-Rename-parsing-state-struct-to-cle.patch
  New patch: perf-events-parse-Use-just-one-parse-events-state-st.patch
  New patch: perf-help-fix-a-bug-during-strstart-conversion.patch
  New patch: perf-list-Add-metric-groups-to-perf-list.patch
  New patch: perf-pmu-Add-check-for-valid-cpuid-in-perf_pmu__find.patch
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-pmu-Pass-pmu-as-a-parameter-to-get_cpuid_str.patch
  New patch: perf-pmu-Unbreak-perf-record-for-arm-arm64-with-even.patch
  New patch: perf-probe-arm64-Fix-symbol-fixup-issues-due-to-ELF-.patch
  New patch: perf-stat-Factor-out-generic-metric-printing.patch
  New patch: perf-stat-Only-auto-merge-events-that-are-PMU-aliase.patch
  New patch: perf-stat-Support-JSON-metrics-in-perf-stat.patch
  New patch: perf-symbols-Fix-plt-entry-calculation-for-ARM-and-A.patch
  New patch: perf-tests-Run-dwarf-unwind-test-on-arm32.patch
  New patch: perf-tools-Add-ARM-Statistical-Profiling-Extensions-.patch
  New patch: perf-tools-arm64-Add-libdw-DWARF-post-unwind-support.patch
  New patch: perf-tools-arm64-Add-support-for-get_cpuid_str-funct.patch
  New patch: perf-vendor-events-arm64-Enable-JSON-events-for-eMAG.patch
  New patch: perf-vendor-events-arm64-Update-ThunderX2-implementa.patch
  New patch: tools-include-Adopt-strstarts-from-the-kernel.patch
- Incorporate git-fixes for FATE#325865/FATE#325861
  New patch: perf-arm64-fix-generate-system-call-table-failed-with-tmp-mounted-with-noexec.patch
  New patch: perf-arm64-fix-include-path-for-asm-generic-unistd-h.patch missing
  New patch: perf-symbols-set-plt-entry-header-sizes-properly-on-sparc.patch missing
- Add Hi1620 Perf hardware enablement (FATE#326417)
  New patch: perf-jevents-Make-build-fail-on-JSON-parse-error.patch
  New patch: perf-vendor-events-aarch64-Add-JSON-metrics-for-ARM-.patch
  New patch: perf-vendor-events-Add-support-for-arch-standard-eve.patch
  New patch: perf-vendor-events-Add-support-for-pmu-events-vendor.patch
  New patch: perf-vendor-events-arm64-Add-armv8-recommended.json.patch
  New patch: perf-vendor-events-arm64-add-HiSilicon-hip08-JSON-fi.patch
  New patch: perf-vendor-events-arm64-Add-ThunderX2-implementatio.patch
  New patch: perf-vendor-events-arm64-Enable-JSON-events-for-Thun.patch
  New patch: perf-vendor-events-arm64-fixup-A53-to-use-recommende.patch
  New patch: perf-vendor-events-arm64-Fixup-ThunderX2-to-use-reco.patch
  New patch: perf-vendor-events-arm64-Relocate-Cortex-A53-JSONs-t.patch
  New patch: perf-vendor-events-arm64-Relocate-ThunderX2-JSON-to-.patch
  New patch: perf-vendor-events-Drop-incomplete-multiple-mapfile-.patch
  New patch: perf-vendor-events-Drop-support-for-unused-topic-dir.patch
  New patch: perf-vendor-events-Fix-error-code-in-json_events.patch
  New patch: perf-vendor-events-Support-metric_group-and-no-event.patch
* Tue Nov  6 2018 tonyj@suse.com
- Add warning to perf top for too slow CPUs (FATE#325579)
  New patch: perf-evlist-remove-evlist-overwrite.patch
  New patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap.patch
  New patch: perf-evlist-remove-overwrite-parameter-from-perf_evlist__mmap_ex.patch
  New patch: perf-evlist-remove-stale-mmap-read-for-backward.patch
  New patch: perf-evsel-add-read_counter.patch
  New patch: perf-evsel-add-verbose-output-for-sys_perf_event_open-fallback.patch
  New patch: perf-evsel-expose-the-perf_missing_features-struct.patch
  New patch: perf-hists-browser-add-parameter-to-disable-lost-event-warning.patch
  New patch: perf-mmap-add-new-return-value-logic-for-perf_mmap__read_init.patch
  New patch: perf-mmap-adopt-push-method-from-builtin-record-c.patch
  New patch: perf-mmap-cleanup-perf_mmap__push.patch
  New patch: perf-mmap-discard-legacy-interface-for-mmap-read.patch
  New patch: perf-mmap-discard-prev-in-perf_mmap__read.patch
  New patch: perf-mmap-don-t-discard-prev-in-backward-mode.patch
  New patch: perf-mmap-fix-perf-backward-recording.patch
  New patch: perf-mmap-introduce-perf_mmap__read_done.patch
  New patch: perf-mmap-introduce-perf_mmap__read_event.patch
  New patch: perf-mmap-introduce-perf_mmap__read_init.patch
  New patch: perf-mmap-move-perf_mmap-and-methods-to-separate-mmap-files.patch
  New patch: perf-mmap-recalculate-size-for-overwrite-mode.patch
  New patch: perf-mmap-remove-overwrite-and-check_messup-from-mmap-read.patch
  New patch: perf-mmap-remove-overwrite-from-arguments-list-of-perf_mmap__push.patch
  New patch: perf-record-make-record__mmap_read-generic.patch
  New patch: perf-stat-use-group-read-for-event-groups.patch
  New patch: perf-test-update-mmap-read-functions-for-backward-ring-buffer-test.patch
  New patch: perf-tests-set-evlist-of-test__backward_ring_buffer-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__basic_mmap-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__sw_clock_freq-to-overwrite.patch
  New patch: perf-tests-set-evlist-of-test__task_exit-to-overwrite.patch
  New patch: perf-tools-add-perf_evsel__read_size-function.patch
  New patch: perf-tools-rename-backward-to-overwrite-in-evlist-mmap-and-record.patch
  New patch: perf-top-add-overwrite-fall-back.patch
  New patch: perf-top-check-per-event-overwrite-term.patch
  New patch: perf-top-check-the-latency-of-perf_top__mmap_read.patch
  New patch: perf-top-fix-window-dimensions-change-handling.patch
  New patch: perf-top-remove-lost-events-checking.patch
  New patch: perf-top-switch-default-mode-to-overwrite-mode.patch
  o
- Incorporate git-fixes for FATE#325579
  New patch: perf-mmap-be-consistent-when-checking-for-an-unmaped-ring-buffer.patch
  New patch: perf-mmap-fix-accessing-unmapped-mmap-in-perf_mmap__read_done.patch
  New patch: perf-top-allow-disabling-the-overwrite-mode.patch
  New patch: perf-top-do-not-use-overwrite-mode-by-default.patch
  New patch: perf-top-fix-annoying-fallback-message-on-older-kernels.patch
  New patch: perf-evsel-only-fall-back-group-read-for-leader.patch
* Mon Aug 27 2018 tonyj@suse.com
- libebl ppc64 dependancy was inadvertantly dropped, regression from
  "Thu Jun 15 22:27:56 - Add ppc64 requires on libebl (bsc#1040770)".
  Re-add dependancy (bsc#1106048)
* Wed Aug  1 2018 tonyj@suse.com
- Support crystall ridge / far / near memory indication in PEBS (FATE#325127)
  New patch: perf-test-add-test-cases-for-new-data-source-encoding.patch
  New patch: perf-tools-add-support-for-printing-new-mem_info-encodings.patch
* Wed Aug  1 2018 tonyj@suse.com
- PMU events are not listed because pvr code is missing for POWER9 (bsc#1075525 )
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Fri Jul 27 2018 tonyj@suse.com
- Merge missing changes from SLE12-SP3 branch
  Thu Jan 18 01:12:14 UTC 2018 - tonyj@suse.com
  - Add necessary power pvr support (bsc#1075525)
    New patch: perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch
    New patch: perf-vendor-events-add-power9-pmu-events.patch
    New patch: perf-vendor-events-add-power9-pvrs-to-mapfile.patch
    New patch: perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch
    New patch: perf-vendor-events-update-power9-events-3c22ba52.patch
    New patch: perf-vendor-events-powerpc-remove-duplicate-events.patch
  Wed Dec  6 19:53:35 UTC 2017 - tonyj@suse.com
  - Add perf scripting support for ppc64le (bsc#1056756)
    New patch: perf-scripting-python-add-ppc64le-to-audit-uname
* Fri Jul 27 2018 tonyj@suse.com
- Resequence patches into Patch-mainline order
- Rename power event patches for consistency and to avoid exportpatch
  name clashes
  perf-vendor-events-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-9749adc3.patch
  perf-vendor-events-powerpc-update-power9-events.patch ->
    perf-vendor-events-update-power9-events-e795dd42.patch
* Wed Jul 25 2018 tonyj@suse.com
- Initial checkin for SLE12-SP4.  Rebase off SLE15.
- Add JSON perf event lists for GLP (FATE#325092)
  new patch: perf-vendor-events-add-goldmont-plus-v1-event-file.patch
- Support perf core/uncore event list for Skylake server (FATE#325122)
  new patch: perf-vendor-events-add-core-event-list-for-skylake-server.patch
  new patch: perf-vendor-events-add-skylake-server-uncore-event-list.patch
  new patch: perf-jevents-support-fcmask-and-portmask.patch
* Tue Jun 12 2018 tonyj@suse.com
- perf script: Show hw-cache events (bsc#1096885)
  new patch: perf-script-show-hw-cache-events.patch
* Mon Apr  9 2018 tonyj@suse.com
- More Power9 event updates (bsc#1056686)
  New patch: perf-vendor-events-update-power9-events.patch
* Tue Apr  3 2018 tonyj@suse.com
- Add libpython support, regression from SLE12 (bsc#1082197)
* Fri Mar  9 2018 tonyj@suse.com
- Fix attr.exclude_kernel setting for default cycles:p (bsc#1083691)
  Regression from commit Mon Nov 27 23:45:48 UTC 2017
  New patch: perf-evsel-fix-attr-exclude_kernel-setting-for-default-cycles-p.patch
  New patch (dependent): perf-evsel-allow-asking-for-max-precise_ip-in-new_cycles.patch
- Git-fixes change (bsc#1070010)
  Fixes: perf-annotate-fix-storing-per-line-sym_hist_entry.patch (Mon Nov 27)
  New patch: perf-annotate-fix-storing-per-line-sym_hist_entry.patch
* Thu Feb 22 2018 tonyj@suse.com
- perf vendor events: Use more flexible pattern matching for CPU
  identification for mapfile.csv (bsc#1081960)
  New patch: perf-pmu-extract-function-to-get-json-alias-map.patch
  New patch: perf-vendor-events-use-more-flexible-pattern-matching-for-cpu-identification-for-mapfile-csv.patch
* Thu Jan 18 2018 tonyj@suse.com
- powerpc: fix 'Object code reading' test (bsc#1073195)
  New patch: perf-test-powerpc-fix-object-code-reading-test.patch
* Mon Nov 27 2017 tonyj@suse.com
- Update power9 events (bsc#1069737)
  New patch: perf-vendor-events-powerpc-update-power9-events.patch
- Memory corruption due to zero length symbols (bsc#1068222)
  New patch: perf-symbols-fix-memory-corruption-because-of-zero-length-symbols.patc
- Incorporate fixes identified by git-fixes and their dependencies (bsc#1070010)
  New patch: perf-annotate-browser-display-titles-in-left-frame.patch
  New patch: perf-annotate-document-show-total-period-option.patch
  New patch: perf-annotate-do-not-overwrite-sample-period.patch
  New patch: perf-annotate-introduce-struct-sym_hist_entry.patch
  New patch: perf-annotate-rename-sum-to-nr_samples-in-struct-sym_hist.patch
  New patch: perf-annotate-stdio-fix-column-header-when-using-show-total-period.patch
  New patch: perf-annotate-stdio-fix-show-total-period.patch
  New patch: perf-annotate-stdio-set-enough-columns-for-show-total-period.patch
  New patch: perf-annotate-stdio-support-show-nr-samples-option.patch
  New patch: perf-annotate-store-the-sample-period-in-each-histogram-bucket.patch
  New patch: perf-annotate-tui-clarify-calculation-of-column-header-widths.patch  New patch: perf-annotate-tui-fix-column-header-when-toggling-period-percent.patch
  New patch: perf-annotate-tui-fix-show-total-period.patch
  New patch: perf-annotate-tui-set-appropriate-column-width-for-period-percent.patch
  New patch: perf-annotate-tui-use-sym_hist_entry-in-disasm_line_samples.patch
  New patch: perf-evsel-set-attr-exclude_kernel-when-probing-max-attr-precise_ip.patch
  New patch: perf-ftrace-move-setup_pager-before-opening-trace_pipe.patch
  New patch: perf-hists-pass-perf_sample-to-_symbol__inc_addr_samples.patch
  New patch: perf-jvmti-fix-linker-error-when-libelf-config-is-disabled.patch
  New patch: perf-probe-fix-kprobe-blacklist-checking-condition.patch
  New patch: perf-report-remove-unnecessary-check-in-annotate_browser_write.patch
  New patch: perf-scripts-python-fix-missing-call_path_id-in-export-to-postgresql-script.patch
  New patch: perf-test-make-list-subcommand-match-main-perf-test-numbering-matching.patch
  New patch: perf-tests-attr-fix-no-delay-test.patch
  New patch: perf-test-sdt-handle-realpath-failure.patch
  New patch: perf-tools-really-install-manpages-via-make-install-man.patch
  New patch: perf-trace-fix-off-by-one-string-allocation-problem.patch
* Fri Sep 15 2017 tonyj@suse.com
- Fix x86 32bit build error
  New patch: perf-provide-definition-for-einval-on-32bit.patch
* Thu Sep  1 2016 tonyj@suse.com
- Fix build error (tips.txt) on Leap42.2
- Fix doc file attributes
* Mon Jun  6 2016 jslaby@suse.com
- disable Werror completely. It breaks build due to shadow variables
  in external (perl) headers.
- add %%{?_smp_mflags}
* Mon Apr  4 2016 tonyj@suse.com
- Package perf-tips as docs.
- Include support for xz compressed images
* Mon Jan 11 2016 tonyj@suse.com
- Support strace/data.
* Sun Oct 11 2015 dmueller@suse.com
- enable numa support for aarch64
* Thu Jul 16 2015 antoine.belvire@laposte.net
- Remove perf-fix-branch-stack-mode-cannot-be-set.patch (upstreamed).
* Sun Jun 28 2015 antoine.belvire@laposte.net
- Fix build with GCC 5
  * perf-fix-branch-stack-mode-cannot-be-set.patch
* Wed May 13 2015 tonyj@suse.com
- Fix ppc64/ppc64le breakage due to libexecdir/libdir
* Mon Mar  9 2015 dimstar@opensuse.org
- Inject libdir=%%{_libdir} into make calls.
* Thu Jan  8 2015 dimstar@opensuse.org
- Remove build hack for kernel not building against glibc 2.20.
* Thu Nov 27 2014 dimstar@opensuse.org
- Build hack: if util/util.h does not (yet) define _DEFAULT_SOURCE,
  we export WERROR=0, which removes -Werror from CFLAGS. Once a
  kernel lands that defines _DEFAULT_SOURCE, we fail the build in
  to remove this hack, making it a (hopefully_ short-livinging one.
* Fri Jun 27 2014 tonyj@suse.com
- Build for s390[x] without libunwind (bnc#882855)
* Tue Mar 25 2014 aj@ajaissle.de
- Fix current build including 'trace event' plugins
- Do not include 'trace event' plugins when on armv7l
- BuildRequire libnuma-devel to enable 'perf bench numa mem', but
  only require if we build for ia64 x86_64 ppc64 ppc64le  ppc %%sparc
- Spec cleanup:
  * Add Url: https://perf.wiki.kernel.org/
  * Drop %%clean-section: We don't need to cleanup the buildroot
  * bash_completion.d/perf doesn't need executable bit
* Fri Jan 24 2014 tonyj@suse.com
- Fix build errors (invoke Makefile.perf directly to pass perfexecdir)
- Add /usr/bin/trace alias for perf (mainline b52bc234)
- Add libperf-gtk.so (loaded via dlsym, mainline fc67297b)
* Wed Dec  4 2013 tonyj@suse.com
- Drop patch perl-5.18-nowarn.patch (mainline)
* Thu Sep  5 2013 mls@suse.de
- add libperl_requires, as we link against libperl and thus
  need a specific version of perl
* Wed Aug 21 2013 tonyj@suse.com
- Resolve build errors
- Drop patch perf-tests-ppc64-fix-compile-errors.patch (mainline)
- Refresh patch perl-5.18-nowarn.patch
* Wed Jul 10 2013 tonyj@suse.com
- Add patch 'perf-tests-ppc64-fix-compile-errors.patch' to resolve
  openSUSE:Factory:PowerPC testsuite build errors
* Tue Jul  9 2013 tonyj@suse.com
- Add audit-devel, gtk2-devel and libunwind-devel to support optional
  functionality.
- Add 'perl-5.18-nowarn.patch' to squelch build errors from perl.h
- Add perl_requires
- Fix --version output (copy submakefiles from kernel-source)
- Pass SUSE rpm optflags into make as EXTRA_CFLAGS not CFLAGS
- Stop building with V=1, make output easier to parse
* Tue Dec 25 2012 tonyj@suse.com
- Add /etc/bash_completion.d/perf to %%files (fix build error)
* Wed May 16 2012 toganm@opensuse.org
- Fix build for factory
  * added flex and bison to buildrequires
* Thu May  5 2011 idoenmez@novell.com
- Also copy arch/lib to fix compilation on x86-64
- Correctly depend on libdw-devel to fix dwarf support
- Add newt-devel dependency to enable text user interface
- Re-enable as-needed support since it works now
* Tue Mar  9 2010 tonyj@novell.com
- 2.6.33 changes
  add perf-bench, perf-buildid-list, perf-diff, perf-kmem, perf-probe and
  perf-trace-perl
  [Still pending, update of libdwarf to version > 20081231]
* Thu Nov  5 2009 tonyj@novell.com
- 2.6.32 changes
  add perf-sched, perf-timechart and perf-trace man pages
* Wed Aug 26 2009 aj@suse.de
- Remove libbfd.patch since it does not apply and use
  SUSE_ASNEEDED=0 instead.
- Set flag for asciidoc version 8.
* Sun Aug  2 2009 tonyj@suse.de
- Initial checkin of Performance Counters for Linux (PCL) userspace.
  This builds tools/perf out of kernel-source package and requires
  kernel >= 2.6.31
